/*

Copyright 2021 Dakshinamurthy Karra (dakshinamurthy.karra@jaliansystems.com)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

static struct nerd_font {
  char* name;
  char* code;
} fonts[] = {
  { "custom-c", "\\ue61e" },
  { "custom-cpp", "\\ue61d" },
  { "custom-electron", "\\ue62e" },
  { "custom-elixir", "\\ue62d" },
  { "custom-elm", "\\ue62c" },
  { "custom-folder", "\\ue5ff" },
  { "custom-folder_config", "\\ue5fc" },
  { "custom-folder_git", "\\ue5fb" },
  { "custom-folder_git_branch", "\\ue5fb" },
  { "custom-folder_github", "\\ue5fd" },
  { "custom-folder_npm", "\\ue5fa" },
  { "custom-folder_open", "\\ue5fe" },
  { "custom-go", "\\ue626" },
  { "custom-msdos", "\\ue629" },
  { "custom-vim", "\\ue62b" },
  { "custom-windows", "\\ue62a" },
  { "dev-android", "\\ue70e" },
  { "dev-angular", "\\ue753" },
  { "dev-appcelerator", "\\ue7ab" },
  { "dev-apple", "\\ue711" },
  { "dev-appstore", "\\ue713" },
  { "dev-aptana", "\\ue799" },
  { "dev-asterisk", "\\ue7ac" },
  { "dev-atlassian", "\\ue75b" },
  { "dev-atom", "\\ue764" },
  { "dev-aws", "\\ue7ad" },
  { "dev-backbone", "\\ue752" },
  { "dev-bing_small", "\\ue700" },
  { "dev-bintray", "\\ue794" },
  { "dev-bitbucket", "\\ue703" },
  { "dev-blackberry", "\\ue723" },
  { "dev-bootstrap", "\\ue747" },
  { "dev-bower", "\\ue74d" },
  { "dev-brackets", "\\ue79d" },
  { "dev-bugsense", "\\ue78d" },
  { "dev-celluloid", "\\ue76b" },
  { "dev-chart", "\\ue760" },
  { "dev-chrome", "\\ue743" },
  { "dev-cisco", "\\ue765" },
  { "dev-clojure", "\\ue768" },
  { "dev-clojure_alt", "\\ue76a" },
  { "dev-cloud9", "\\ue79f" },
  { "dev-coda", "\\ue793" },
  { "dev-code", "\\ue796" },
  { "dev-code_badge", "\\ue7a3" },
  { "dev-codeigniter", "\\ue780" },
  { "dev-codepen", "\\ue716" },
  { "dev-codrops", "\\ue72f" },
  { "dev-coffeescript", "\\ue751" },
  { "dev-compass", "\\ue761" },
  { "dev-composer", "\\ue783" },
  { "dev-creativecommons", "\\ue789" },
  { "dev-creativecommons_badge", "\\ue78a" },
  { "dev-css3", "\\ue749" },
  { "dev-css3_full", "\\ue74a" },
  { "dev-css_tricks", "\\ue701" },
  { "dev-cssdeck", "\\ue72a" },
  { "dev-dart", "\\ue798" },
  { "dev-database", "\\ue706" },
  { "dev-debian", "\\ue77d" },
  { "dev-digital_ocean", "\\ue7ae" },
  { "dev-django", "\\ue71d" },
  { "dev-dlang", "\\ue7af" },
  { "dev-docker", "\\ue7b0" },
  { "dev-doctrine", "\\ue774" },
  { "dev-dojo", "\\ue71c" },
  { "dev-dotnet", "\\ue77f" },
  { "dev-dreamweaver", "\\ue79c" },
  { "dev-dropbox", "\\ue707" },
  { "dev-drupal", "\\ue742" },
  { "dev-eclipse", "\\ue79e" },
  { "dev-ember", "\\ue71b" },
  { "dev-envato", "\\ue75d" },
  { "dev-erlang", "\\ue7b1" },
  { "dev-extjs", "\\ue78e" },
  { "dev-firebase", "\\ue787" },
  { "dev-firefox", "\\ue745" },
  { "dev-fsharp", "\\ue7a7" },
  { "dev-ghost", "\\ue71f" },
  { "dev-ghost_small", "\\ue714" },
  { "dev-git", "\\ue702" },
  { "dev-git_branch", "\\ue725" },
  { "dev-git_commit", "\\ue729" },
  { "dev-git_compare", "\\ue728" },
  { "dev-git_merge", "\\ue727" },
  { "dev-git_pull_request", "\\ue726" },
  { "dev-github", "\\ue70a" },
  { "dev-github_alt", "\\ue708" },
  { "dev-github_badge", "\\ue709" },
  { "dev-github_full", "\\ue717" },
  { "dev-gnu", "\\ue779" },
  { "dev-go", "\\ue724" },
  { "dev-google_cloud_platform", "\\ue7b2" },
  { "dev-google_drive", "\\ue731" },
  { "dev-grails", "\\ue7b3" },
  { "dev-groovy", "\\ue775" },
  { "dev-grunt", "\\ue74c" },
  { "dev-gulp", "\\ue763" },
  { "dev-hackernews", "\\ue71a" },
  { "dev-haskell", "\\ue777" },
  { "dev-heroku", "\\ue77b" },
  { "dev-html5", "\\ue736" },
  { "dev-html5_3d_effects", "\\ue735" },
  { "dev-html5_connectivity", "\\ue734" },
  { "dev-html5_device_access", "\\ue733" },
  { "dev-html5_multimedia", "\\ue732" },
  { "dev-ie", "\\ue744" },
  { "dev-illustrator", "\\ue7b4" },
  { "dev-intellij", "\\ue7b5" },
  { "dev-ionic", "\\ue7a9" },
  { "dev-java", "\\ue738" },
  { "dev-javascript", "\\ue74e" },
  { "dev-javascript_badge", "\\ue781" },
  { "dev-javascript_shield", "\\ue74f" },
  { "dev-jekyll_small", "\\ue70d" },
  { "dev-jenkins", "\\ue767" },
  { "dev-jira", "\\ue75c" },
  { "dev-joomla", "\\ue741" },
  { "dev-jquery", "\\ue750" },
  { "dev-jquery_ui", "\\ue754" },
  { "dev-komodo", "\\ue792" },
  { "dev-krakenjs", "\\ue785" },
  { "dev-krakenjs_badge", "\\ue784" },
  { "dev-laravel", "\\ue73f" },
  { "dev-less", "\\ue758" },
  { "dev-linux", "\\ue712" },
  { "dev-magento", "\\ue740" },
  { "dev-mailchimp", "\\ue79a" },
  { "dev-markdown", "\\ue73e" },
  { "dev-materializecss", "\\ue7b6" },
  { "dev-meteor", "\\ue7a5" },
  { "dev-meteorfull", "\\ue7a6" },
  { "dev-mitlicence", "\\ue78b" },
  { "dev-modernizr", "\\ue720" },
  { "dev-mongodb", "\\ue7a4" },
  { "dev-mootools", "\\ue790" },
  { "dev-mootools_badge", "\\ue78f" },
  { "dev-mozilla", "\\ue786" },
  { "dev-msql_server", "\\ue77c" },
  { "dev-mysql", "\\ue704" },
  { "dev-nancy", "\\ue766" },
  { "dev-netbeans", "\\ue79b" },
  { "dev-netmagazine", "\\ue72e" },
  { "dev-nginx", "\\ue776" },
  { "dev-nodejs", "\\ue719" },
  { "dev-nodejs_small", "\\ue718" },
  { "dev-npm", "\\ue71e" },
  { "dev-onedrive", "\\ue762" },
  { "dev-openshift", "\\ue7b7" },
  { "dev-opensource", "\\ue771" },
  { "dev-opera", "\\ue746" },
  { "dev-perl", "\\ue769" },
  { "dev-phonegap", "\\ue730" },
  { "dev-photoshop", "\\ue7b8" },
  { "dev-php", "\\ue73d" },
  { "dev-postgresql", "\\ue76e" },
  { "dev-prolog", "\\ue7a1" },
  { "dev-python", "\\ue73c" },
  { "dev-rackspace", "\\ue7b9" },
  { "dev-raphael", "\\ue75f" },
  { "dev-rasberry_pi", "\\ue722" },
  { "dev-react", "\\ue7ba" },
  { "dev-redhat", "\\ue7bb" },
  { "dev-redis", "\\ue76d" },
  { "dev-requirejs", "\\ue770" },
  { "dev-responsive", "\\ue797" },
  { "dev-ruby", "\\ue739" },
  { "dev-ruby_on_rails", "\\ue73b" },
  { "dev-ruby_rough", "\\ue791" },
  { "dev-rust", "\\ue7a8" },
  { "dev-safari", "\\ue748" },
  { "dev-sass", "\\ue74b" },
  { "dev-scala", "\\ue737" },
  { "dev-scriptcs", "\\ue7bc" },
  { "dev-scrum", "\\ue7a0" },
  { "dev-senchatouch", "\\ue78c" },
  { "dev-sizzlejs", "\\ue788" },
  { "dev-smashing_magazine", "\\ue72d" },
  { "dev-snap_svg", "\\ue75e" },
  { "dev-sqllite", "\\ue7c4" },
  { "dev-stackoverflow", "\\ue710" },
  { "dev-streamline", "\\ue705" },
  { "dev-stylus", "\\ue759" },
  { "dev-sublime", "\\ue7aa" },
  { "dev-swift", "\\ue755" },
  { "dev-symfony", "\\ue756" },
  { "dev-symfony_badge", "\\ue757" },
  { "dev-techcrunch", "\\ue72c" },
  { "dev-terminal", "\\ue795" },
  { "dev-terminal_badge", "\\ue7a2" },
  { "dev-travis", "\\ue77e" },
  { "dev-trello", "\\ue75a" },
  { "dev-typo3", "\\ue772" },
  { "dev-ubuntu", "\\ue73a" },
  { "dev-uikit", "\\ue773" },
  { "dev-unity_small", "\\ue721" },
  { "dev-vim", "\\ue7c5" },
  { "dev-visualstudio", "\\ue70c" },
  { "dev-w3c", "\\ue76c" },
  { "dev-webplatform", "\\ue76f" },
  { "dev-windows", "\\ue70f" },
  { "dev-wordpress", "\\ue70b" },
  { "dev-yahoo", "\\ue715" },
  { "dev-yahoo_small", "\\ue72b" },
  { "dev-yeoman", "\\ue77a" },
  { "dev-yii", "\\ue782" },
  { "dev-zend", "\\ue778" },
  { "fa-500px", "\\uf26e" },
  { "fa-address_book", "\\uf2b9" },
  { "fa-address_book_o", "\\uf2ba" },
  { "fa-address_card", "\\uf2bb" },
  { "fa-address_card_o", "\\uf2bc" },
  { "fa-adjust", "\\uf042" },
  { "fa-adn", "\\uf170" },
  { "fa-align_center", "\\uf037" },
  { "fa-align_justify", "\\uf039" },
  { "fa-align_left", "\\uf036" },
  { "fa-align_right", "\\uf038" },
  { "fa-amazon", "\\uf270" },
  { "fa-ambulance", "\\uf0f9" },
  { "fa-american_sign_language_interpreting", "\\uf2a3" },
  { "fa-anchor", "\\uf13d" },
  { "fa-android", "\\uf17b" },
  { "fa-angellist", "\\uf209" },
  { "fa-angle_double_down", "\\uf103" },
  { "fa-angle_double_left", "\\uf100" },
  { "fa-angle_double_right", "\\uf101" },
  { "fa-angle_double_up", "\\uf102" },
  { "fa-angle_down", "\\uf107" },
  { "fa-angle_left", "\\uf104" },
  { "fa-angle_right", "\\uf105" },
  { "fa-angle_up", "\\uf106" },
  { "fa-apple", "\\uf179" },
  { "fa-archive", "\\uf187" },
  { "fa-area_chart", "\\uf1fe" },
  { "fa-arrow_circle_down", "\\uf0ab" },
  { "fa-arrow_circle_left", "\\uf0a8" },
  { "fa-arrow_circle_o_down", "\\uf01a" },
  { "fa-arrow_circle_o_left", "\\uf190" },
  { "fa-arrow_circle_o_right", "\\uf18e" },
  { "fa-arrow_circle_o_up", "\\uf01b" },
  { "fa-arrow_circle_right", "\\uf0a9" },
  { "fa-arrow_circle_up", "\\uf0aa" },
  { "fa-arrow_down", "\\uf063" },
  { "fa-arrow_left", "\\uf060" },
  { "fa-arrow_right", "\\uf061" },
  { "fa-arrow_up", "\\uf062" },
  { "fa-arrows", "\\uf047" },
  { "fa-arrows_alt", "\\uf0b2" },
  { "fa-arrows_h", "\\uf07e" },
  { "fa-arrows_v", "\\uf07d" },
  { "fa-asl_interpreting", "\\uf2a3" },
  { "fa-assistive_listening_systems", "\\uf2a2" },
  { "fa-asterisk", "\\uf069" },
  { "fa-at", "\\uf1fa" },
  { "fa-audio_description", "\\uf29e" },
  { "fa-automobile", "\\uf1b9" },
  { "fa-backward", "\\uf04a" },
  { "fa-balance_scale", "\\uf24e" },
  { "fa-ban", "\\uf05e" },
  { "fa-bandcamp", "\\uf2d5" },
  { "fa-bank", "\\uf19c" },
  { "fa-bar_chart", "\\uf080" },
  { "fa-bar_chart_o", "\\uf080" },
  { "fa-barcode", "\\uf02a" },
  { "fa-bars", "\\uf0c9" },
  { "fa-bath", "\\uf2cd" },
  { "fa-bathtub", "\\uf2cd" },
  { "fa-battery", "\\uf240" },
  { "fa-battery_0", "\\uf244" },
  { "fa-battery_1", "\\uf243" },
  { "fa-battery_2", "\\uf242" },
  { "fa-battery_3", "\\uf241" },
  { "fa-battery_4", "\\uf240" },
  { "fa-battery_empty", "\\uf244" },
  { "fa-battery_full", "\\uf240" },
  { "fa-battery_half", "\\uf242" },
  { "fa-battery_quarter", "\\uf243" },
  { "fa-battery_three_quarters", "\\uf241" },
  { "fa-bed", "\\uf236" },
  { "fa-beer", "\\uf0fc" },
  { "fa-behance", "\\uf1b4" },
  { "fa-behance_square", "\\uf1b5" },
  { "fa-bell", "\\uf0f3" },
  { "fa-bell_o", "\\uf0a2" },
  { "fa-bell_slash", "\\uf1f6" },
  { "fa-bell_slash_o", "\\uf1f7" },
  { "fa-bicycle", "\\uf206" },
  { "fa-binoculars", "\\uf1e5" },
  { "fa-birthday_cake", "\\uf1fd" },
  { "fa-bitbucket", "\\uf171" },
  { "fa-bitbucket_square", "\\uf172" },
  { "fa-bitcoin", "\\uf15a" },
  { "fa-black_tie", "\\uf27e" },
  { "fa-blind", "\\uf29d" },
  { "fa-bluetooth", "\\uf293" },
  { "fa-bluetooth_b", "\\uf294" },
  { "fa-bold", "\\uf032" },
  { "fa-bolt", "\\uf0e7" },
  { "fa-bomb", "\\uf1e2" },
  { "fa-book", "\\uf02d" },
  { "fa-bookmark", "\\uf02e" },
  { "fa-bookmark_o", "\\uf097" },
  { "fa-braille", "\\uf2a1" },
  { "fa-briefcase", "\\uf0b1" },
  { "fa-btc", "\\uf15a" },
  { "fa-bug", "\\uf188" },
  { "fa-building", "\\uf1ad" },
  { "fa-building_o", "\\uf0f7" },
  { "fa-bullhorn", "\\uf0a1" },
  { "fa-bullseye", "\\uf140" },
  { "fa-bus", "\\uf207" },
  { "fa-buysellads", "\\uf20d" },
  { "fa-cab", "\\uf1ba" },
  { "fa-calculator", "\\uf1ec" },
  { "fa-calendar", "\\uf073" },
  { "fa-calendar_check_o", "\\uf274" },
  { "fa-calendar_minus_o", "\\uf272" },
  { "fa-calendar_o", "\\uf133" },
  { "fa-calendar_plus_o", "\\uf271" },
  { "fa-calendar_times_o", "\\uf273" },
  { "fa-camera", "\\uf030" },
  { "fa-camera_retro", "\\uf083" },
  { "fa-car", "\\uf1b9" },
  { "fa-caret_down", "\\uf0d7" },
  { "fa-caret_left", "\\uf0d9" },
  { "fa-caret_right", "\\uf0da" },
  { "fa-caret_square_o_down", "\\uf150" },
  { "fa-caret_square_o_left", "\\uf191" },
  { "fa-caret_square_o_right", "\\uf152" },
  { "fa-caret_square_o_up", "\\uf151" },
  { "fa-caret_up", "\\uf0d8" },
  { "fa-cart_arrow_down", "\\uf218" },
  { "fa-cart_plus", "\\uf217" },
  { "fa-cc", "\\uf20a" },
  { "fa-cc_amex", "\\uf1f3" },
  { "fa-cc_diners_club", "\\uf24c" },
  { "fa-cc_discover", "\\uf1f2" },
  { "fa-cc_jcb", "\\uf24b" },
  { "fa-cc_mastercard", "\\uf1f1" },
  { "fa-cc_paypal", "\\uf1f4" },
  { "fa-cc_stripe", "\\uf1f5" },
  { "fa-cc_visa", "\\uf1f0" },
  { "fa-certificate", "\\uf0a3" },
  { "fa-chain", "\\uf0c1" },
  { "fa-chain_broken", "\\uf127" },
  { "fa-check", "\\uf00c" },
  { "fa-check_circle", "\\uf058" },
  { "fa-check_circle_o", "\\uf05d" },
  { "fa-check_square", "\\uf14a" },
  { "fa-check_square_o", "\\uf046" },
  { "fa-chevron_circle_down", "\\uf13a" },
  { "fa-chevron_circle_left", "\\uf137" },
  { "fa-chevron_circle_right", "\\uf138" },
  { "fa-chevron_circle_up", "\\uf139" },
  { "fa-chevron_down", "\\uf078" },
  { "fa-chevron_left", "\\uf053" },
  { "fa-chevron_right", "\\uf054" },
  { "fa-chevron_up", "\\uf077" },
  { "fa-child", "\\uf1ae" },
  { "fa-chrome", "\\uf268" },
  { "fa-circle", "\\uf111" },
  { "fa-circle_o", "\\uf10c" },
  { "fa-circle_o_notch", "\\uf1ce" },
  { "fa-circle_thin", "\\uf1db" },
  { "fa-clipboard", "\\uf0ea" },
  { "fa-clock_o", "\\uf017" },
  { "fa-clone", "\\uf24d" },
  { "fa-close", "\\uf00d" },
  { "fa-cloud", "\\uf0c2" },
  { "fa-cloud_download", "\\uf0ed" },
  { "fa-cloud_upload", "\\uf0ee" },
  { "fa-cny", "\\uf157" },
  { "fa-code", "\\uf121" },
  { "fa-code_fork", "\\uf126" },
  { "fa-codepen", "\\uf1cb" },
  { "fa-codiepie", "\\uf284" },
  { "fa-coffee", "\\uf0f4" },
  { "fa-cog", "\\uf013" },
  { "fa-cogs", "\\uf085" },
  { "fa-columns", "\\uf0db" },
  { "fa-comment", "\\uf075" },
  { "fa-comment_o", "\\uf0e5" },
  { "fa-commenting", "\\uf27a" },
  { "fa-commenting_o", "\\uf27b" },
  { "fa-comments", "\\uf086" },
  { "fa-comments_o", "\\uf0e6" },
  { "fa-compass", "\\uf14e" },
  { "fa-compress", "\\uf066" },
  { "fa-connectdevelop", "\\uf20e" },
  { "fa-contao", "\\uf26d" },
  { "fa-copy", "\\uf0c5" },
  { "fa-copyright", "\\uf1f9" },
  { "fa-creative_commons", "\\uf25e" },
  { "fa-credit_card", "\\uf09d" },
  { "fa-credit_card_alt", "\\uf283" },
  { "fa-crop", "\\uf125" },
  { "fa-crosshairs", "\\uf05b" },
  { "fa-css3", "\\uf13c" },
  { "fa-cube", "\\uf1b2" },
  { "fa-cubes", "\\uf1b3" },
  { "fa-cut", "\\uf0c4" },
  { "fa-cutlery", "\\uf0f5" },
  { "fa-dashboard", "\\uf0e4" },
  { "fa-dashcube", "\\uf210" },
  { "fa-database", "\\uf1c0" },
  { "fa-deaf", "\\uf2a4" },
  { "fa-deafness", "\\uf2a4" },
  { "fa-dedent", "\\uf03b" },
  { "fa-delicious", "\\uf1a5" },
  { "fa-desktop", "\\uf108" },
  { "fa-deviantart", "\\uf1bd" },
  { "fa-diamond", "\\uf219" },
  { "fa-digg", "\\uf1a6" },
  { "fa-dollar", "\\uf155" },
  { "fa-dot_circle_o", "\\uf192" },
  { "fa-download", "\\uf019" },
  { "fa-dribbble", "\\uf17d" },
  { "fa-drivers_license", "\\uf2c2" },
  { "fa-drivers_license_o", "\\uf2c3" },
  { "fa-dropbox", "\\uf16b" },
  { "fa-drupal", "\\uf1a9" },
  { "fa-edge", "\\uf282" },
  { "fa-edit", "\\uf044" },
  { "fa-eercast", "\\uf2da" },
  { "fa-eject", "\\uf052" },
  { "fa-ellipsis_h", "\\uf141" },
  { "fa-ellipsis_v", "\\uf142" },
  { "fa-empire", "\\uf1d1" },
  { "fa-envelope", "\\uf0e0" },
  { "fa-envelope_o", "\\uf003" },
  { "fa-envelope_open", "\\uf2b6" },
  { "fa-envelope_open_o", "\\uf2b7" },
  { "fa-envelope_square", "\\uf199" },
  { "fa-envira", "\\uf299" },
  { "fa-eraser", "\\uf12d" },
  { "fa-etsy", "\\uf2d7" },
  { "fa-eur", "\\uf153" },
  { "fa-euro", "\\uf153" },
  { "fa-exchange", "\\uf0ec" },
  { "fa-exclamation", "\\uf12a" },
  { "fa-exclamation_circle", "\\uf06a" },
  { "fa-exclamation_triangle", "\\uf071" },
  { "fa-expand", "\\uf065" },
  { "fa-expeditedssl", "\\uf23e" },
  { "fa-external_link", "\\uf08e" },
  { "fa-external_link_square", "\\uf14c" },
  { "fa-eye", "\\uf06e" },
  { "fa-eye_slash", "\\uf070" },
  { "fa-eyedropper", "\\uf1fb" },
  { "fa-fa", "\\uf2b4" },
  { "fa-facebook", "\\uf09a" },
  { "fa-facebook_f", "\\uf09a" },
  { "fa-facebook_official", "\\uf230" },
  { "fa-facebook_square", "\\uf082" },
  { "fa-fast_backward", "\\uf049" },
  { "fa-fast_forward", "\\uf050" },
  { "fa-fax", "\\uf1ac" },
  { "fa-feed", "\\uf09e" },
  { "fa-female", "\\uf182" },
  { "fa-fighter_jet", "\\uf0fb" },
  { "fa-file", "\\uf15b" },
  { "fa-file_archive_o", "\\uf1c6" },
  { "fa-file_audio_o", "\\uf1c7" },
  { "fa-file_code_o", "\\uf1c9" },
  { "fa-file_excel_o", "\\uf1c3" },
  { "fa-file_image_o", "\\uf1c5" },
  { "fa-file_movie_o", "\\uf1c8" },
  { "fa-file_o", "\\uf016" },
  { "fa-file_pdf_o", "\\uf1c1" },
  { "fa-file_photo_o", "\\uf1c5" },
  { "fa-file_picture_o", "\\uf1c5" },
  { "fa-file_powerpoint_o", "\\uf1c4" },
  { "fa-file_sound_o", "\\uf1c7" },
  { "fa-file_text", "\\uf15c" },
  { "fa-file_text_o", "\\uf0f6" },
  { "fa-file_video_o", "\\uf1c8" },
  { "fa-file_word_o", "\\uf1c2" },
  { "fa-file_zip_o", "\\uf1c6" },
  { "fa-files_o", "\\uf0c5" },
  { "fa-film", "\\uf008" },
  { "fa-filter", "\\uf0b0" },
  { "fa-fire", "\\uf06d" },
  { "fa-fire_extinguisher", "\\uf134" },
  { "fa-firefox", "\\uf269" },
  { "fa-first_order", "\\uf2b0" },
  { "fa-flag", "\\uf024" },
  { "fa-flag_checkered", "\\uf11e" },
  { "fa-flag_o", "\\uf11d" },
  { "fa-flash", "\\uf0e7" },
  { "fa-flask", "\\uf0c3" },
  { "fa-flickr", "\\uf16e" },
  { "fa-floppy_o", "\\uf0c7" },
  { "fa-folder", "\\uf07b" },
  { "fa-folder_o", "\\uf114" },
  { "fa-folder_open", "\\uf07c" },
  { "fa-folder_open_o", "\\uf115" },
  { "fa-font", "\\uf031" },
  { "fa-font_awesome", "\\uf2b4" },
  { "fa-fonticons", "\\uf280" },
  { "fa-fort_awesome", "\\uf286" },
  { "fa-forumbee", "\\uf211" },
  { "fa-forward", "\\uf04e" },
  { "fa-foursquare", "\\uf180" },
  { "fa-free_code_camp", "\\uf2c5" },
  { "fa-frown_o", "\\uf119" },
  { "fa-futbol_o", "\\uf1e3" },
  { "fa-gamepad", "\\uf11b" },
  { "fa-gavel", "\\uf0e3" },
  { "fa-gbp", "\\uf154" },
  { "fa-ge", "\\uf1d1" },
  { "fa-gear", "\\uf013" },
  { "fa-gears", "\\uf085" },
  { "fa-genderless", "\\uf22d" },
  { "fa-get_pocket", "\\uf265" },
  { "fa-gg", "\\uf260" },
  { "fa-gg_circle", "\\uf261" },
  { "fa-gift", "\\uf06b" },
  { "fa-git", "\\uf1d3" },
  { "fa-git_square", "\\uf1d2" },
  { "fa-github", "\\uf09b" },
  { "fa-github_alt", "\\uf113" },
  { "fa-github_square", "\\uf092" },
  { "fa-gitlab", "\\uf296" },
  { "fa-gittip", "\\uf184" },
  { "fa-glass", "\\uf000" },
  { "fa-glide", "\\uf2a5" },
  { "fa-glide_g", "\\uf2a6" },
  { "fa-globe", "\\uf0ac" },
  { "fa-google", "\\uf1a0" },
  { "fa-google_plus", "\\uf0d5" },
  { "fa-google_plus_circle", "\\uf2b3" },
  { "fa-google_plus_official", "\\uf2b3" },
  { "fa-google_plus_square", "\\uf0d4" },
  { "fa-google_wallet", "\\uf1ee" },
  { "fa-graduation_cap", "\\uf19d" },
  { "fa-gratipay", "\\uf184" },
  { "fa-grav", "\\uf2d6" },
  { "fa-group", "\\uf0c0" },
  { "fa-h_square", "\\uf0fd" },
  { "fa-hacker_news", "\\uf1d4" },
  { "fa-hand_grab_o", "\\uf255" },
  { "fa-hand_lizard_o", "\\uf258" },
  { "fa-hand_o_down", "\\uf0a7" },
  { "fa-hand_o_left", "\\uf0a5" },
  { "fa-hand_o_right", "\\uf0a4" },
  { "fa-hand_o_up", "\\uf0a6" },
  { "fa-hand_paper_o", "\\uf256" },
  { "fa-hand_peace_o", "\\uf25b" },
  { "fa-hand_pointer_o", "\\uf25a" },
  { "fa-hand_rock_o", "\\uf255" },
  { "fa-hand_scissors_o", "\\uf257" },
  { "fa-hand_spock_o", "\\uf259" },
  { "fa-hand_stop_o", "\\uf256" },
  { "fa-handshake_o", "\\uf2b5" },
  { "fa-hard_of_hearing", "\\uf2a4" },
  { "fa-hashtag", "\\uf292" },
  { "fa-hdd_o", "\\uf0a0" },
  { "fa-header", "\\uf1dc" },
  { "fa-headphones", "\\uf025" },
  { "fa-heart", "\\uf004" },
  { "fa-heart_o", "\\uf08a" },
  { "fa-heartbeat", "\\uf21e" },
  { "fa-history", "\\uf1da" },
  { "fa-home", "\\uf015" },
  { "fa-hospital_o", "\\uf0f8" },
  { "fa-hotel", "\\uf236" },
  { "fa-hourglass", "\\uf254" },
  { "fa-hourglass_1", "\\uf251" },
  { "fa-hourglass_2", "\\uf252" },
  { "fa-hourglass_3", "\\uf253" },
  { "fa-hourglass_end", "\\uf253" },
  { "fa-hourglass_half", "\\uf252" },
  { "fa-hourglass_o", "\\uf250" },
  { "fa-hourglass_start", "\\uf251" },
  { "fa-houzz", "\\uf27c" },
  { "fa-html5", "\\uf13b" },
  { "fa-i_cursor", "\\uf246" },
  { "fa-id_badge", "\\uf2c1" },
  { "fa-id_card", "\\uf2c2" },
  { "fa-id_card_o", "\\uf2c3" },
  { "fa-ils", "\\uf20b" },
  { "fa-image", "\\uf03e" },
  { "fa-imdb", "\\uf2d8" },
  { "fa-inbox", "\\uf01c" },
  { "fa-indent", "\\uf03c" },
  { "fa-industry", "\\uf275" },
  { "fa-info", "\\uf129" },
  { "fa-info_circle", "\\uf05a" },
  { "fa-inr", "\\uf156" },
  { "fa-instagram", "\\uf16d" },
  { "fa-institution", "\\uf19c" },
  { "fa-internet_explorer", "\\uf26b" },
  { "fa-intersex", "\\uf224" },
  { "fa-ioxhost", "\\uf208" },
  { "fa-italic", "\\uf033" },
  { "fa-joomla", "\\uf1aa" },
  { "fa-jpy", "\\uf157" },
  { "fa-jsfiddle", "\\uf1cc" },
  { "fa-key", "\\uf084" },
  { "fa-keyboard_o", "\\uf11c" },
  { "fa-krw", "\\uf159" },
  { "fa-language", "\\uf1ab" },
  { "fa-laptop", "\\uf109" },
  { "fa-lastfm", "\\uf202" },
  { "fa-lastfm_square", "\\uf203" },
  { "fa-leaf", "\\uf06c" },
  { "fa-leanpub", "\\uf212" },
  { "fa-legal", "\\uf0e3" },
  { "fa-lemon_o", "\\uf094" },
  { "fa-level_down", "\\uf149" },
  { "fa-level_up", "\\uf148" },
  { "fa-life_bouy", "\\uf1cd" },
  { "fa-life_buoy", "\\uf1cd" },
  { "fa-life_ring", "\\uf1cd" },
  { "fa-life_saver", "\\uf1cd" },
  { "fa-lightbulb_o", "\\uf0eb" },
  { "fa-line_chart", "\\uf201" },
  { "fa-link", "\\uf0c1" },
  { "fa-linkedin", "\\uf0e1" },
  { "fa-linkedin_square", "\\uf08c" },
  { "fa-linode", "\\uf2b8" },
  { "fa-linux", "\\uf17c" },
  { "fa-list", "\\uf03a" },
  { "fa-list_alt", "\\uf022" },
  { "fa-list_ol", "\\uf0cb" },
  { "fa-list_ul", "\\uf0ca" },
  { "fa-location_arrow", "\\uf124" },
  { "fa-lock", "\\uf023" },
  { "fa-long_arrow_down", "\\uf175" },
  { "fa-long_arrow_left", "\\uf177" },
  { "fa-long_arrow_right", "\\uf178" },
  { "fa-long_arrow_up", "\\uf176" },
  { "fa-low_vision", "\\uf2a8" },
  { "fa-magic", "\\uf0d0" },
  { "fa-magnet", "\\uf076" },
  { "fa-mail_forward", "\\uf064" },
  { "fa-mail_reply", "\\uf112" },
  { "fa-mail_reply_all", "\\uf122" },
  { "fa-male", "\\uf183" },
  { "fa-map", "\\uf279" },
  { "fa-map_marker", "\\uf041" },
  { "fa-map_o", "\\uf278" },
  { "fa-map_pin", "\\uf276" },
  { "fa-map_signs", "\\uf277" },
  { "fa-mars", "\\uf222" },
  { "fa-mars_double", "\\uf227" },
  { "fa-mars_stroke", "\\uf229" },
  { "fa-mars_stroke_h", "\\uf22b" },
  { "fa-mars_stroke_v", "\\uf22a" },
  { "fa-maxcdn", "\\uf136" },
  { "fa-meanpath", "\\uf20c" },
  { "fa-medium", "\\uf23a" },
  { "fa-medkit", "\\uf0fa" },
  { "fa-meetup", "\\uf2e0" },
  { "fa-meh_o", "\\uf11a" },
  { "fa-mercury", "\\uf223" },
  { "fa-microchip", "\\uf2db" },
  { "fa-microphone", "\\uf130" },
  { "fa-microphone_slash", "\\uf131" },
  { "fa-minus", "\\uf068" },
  { "fa-minus_circle", "\\uf056" },
  { "fa-minus_square", "\\uf146" },
  { "fa-minus_square_o", "\\uf147" },
  { "fa-mixcloud", "\\uf289" },
  { "fa-mobile", "\\uf10b" },
  { "fa-mobile_phone", "\\uf10b" },
  { "fa-modx", "\\uf285" },
  { "fa-money", "\\uf0d6" },
  { "fa-moon_o", "\\uf186" },
  { "fa-mortar_board", "\\uf19d" },
  { "fa-motorcycle", "\\uf21c" },
  { "fa-mouse_pointer", "\\uf245" },
  { "fa-music", "\\uf001" },
  { "fa-navicon", "\\uf0c9" },
  { "fa-neuter", "\\uf22c" },
  { "fa-newspaper_o", "\\uf1ea" },
  { "fa-object_group", "\\uf247" },
  { "fa-object_ungroup", "\\uf248" },
  { "fa-odnoklassniki", "\\uf263" },
  { "fa-odnoklassniki_square", "\\uf264" },
  { "fa-opencart", "\\uf23d" },
  { "fa-openid", "\\uf19b" },
  { "fa-opera", "\\uf26a" },
  { "fa-optin_monster", "\\uf23c" },
  { "fa-outdent", "\\uf03b" },
  { "fa-pagelines", "\\uf18c" },
  { "fa-paint_brush", "\\uf1fc" },
  { "fa-paper_plane", "\\uf1d8" },
  { "fa-paper_plane_o", "\\uf1d9" },
  { "fa-paperclip", "\\uf0c6" },
  { "fa-paragraph", "\\uf1dd" },
  { "fa-paste", "\\uf0ea" },
  { "fa-pause", "\\uf04c" },
  { "fa-pause_circle", "\\uf28b" },
  { "fa-pause_circle_o", "\\uf28c" },
  { "fa-paw", "\\uf1b0" },
  { "fa-paypal", "\\uf1ed" },
  { "fa-pencil", "\\uf040" },
  { "fa-pencil_square", "\\uf14b" },
  { "fa-pencil_square_o", "\\uf044" },
  { "fa-percent", "\\uf295" },
  { "fa-phone", "\\uf095" },
  { "fa-phone_square", "\\uf098" },
  { "fa-photo", "\\uf03e" },
  { "fa-picture_o", "\\uf03e" },
  { "fa-pie_chart", "\\uf200" },
  { "fa-pied_piper", "\\uf2ae" },
  { "fa-pied_piper_alt", "\\uf1a8" },
  { "fa-pied_piper_pp", "\\uf1a7" },
  { "fa-pinterest", "\\uf0d2" },
  { "fa-pinterest_p", "\\uf231" },
  { "fa-pinterest_square", "\\uf0d3" },
  { "fa-plane", "\\uf072" },
  { "fa-play", "\\uf04b" },
  { "fa-play_circle", "\\uf144" },
  { "fa-play_circle_o", "\\uf01d" },
  { "fa-plug", "\\uf1e6" },
  { "fa-plus", "\\uf067" },
  { "fa-plus_circle", "\\uf055" },
  { "fa-plus_square", "\\uf0fe" },
  { "fa-plus_square_o", "\\uf196" },
  { "fa-podcast", "\\uf2ce" },
  { "fa-power_off", "\\uf011" },
  { "fa-print", "\\uf02f" },
  { "fa-product_hunt", "\\uf288" },
  { "fa-puzzle_piece", "\\uf12e" },
  { "fa-qq", "\\uf1d6" },
  { "fa-qrcode", "\\uf029" },
  { "fa-question", "\\uf128" },
  { "fa-question_circle", "\\uf059" },
  { "fa-question_circle_o", "\\uf29c" },
  { "fa-quora", "\\uf2c4" },
  { "fa-quote_left", "\\uf10d" },
  { "fa-quote_right", "\\uf10e" },
  { "fa-ra", "\\uf1d0" },
  { "fa-random", "\\uf074" },
  { "fa-ravelry", "\\uf2d9" },
  { "fa-rebel", "\\uf1d0" },
  { "fa-recycle", "\\uf1b8" },
  { "fa-reddit", "\\uf1a1" },
  { "fa-reddit_alien", "\\uf281" },
  { "fa-reddit_square", "\\uf1a2" },
  { "fa-refresh", "\\uf021" },
  { "fa-registered", "\\uf25d" },
  { "fa-remove", "\\uf00d" },
  { "fa-renren", "\\uf18b" },
  { "fa-reorder", "\\uf0c9" },
  { "fa-repeat", "\\uf01e" },
  { "fa-reply", "\\uf112" },
  { "fa-reply_all", "\\uf122" },
  { "fa-resistance", "\\uf1d0" },
  { "fa-retweet", "\\uf079" },
  { "fa-rmb", "\\uf157" },
  { "fa-road", "\\uf018" },
  { "fa-rocket", "\\uf135" },
  { "fa-rotate_left", "\\uf0e2" },
  { "fa-rotate_right", "\\uf01e" },
  { "fa-rouble", "\\uf158" },
  { "fa-rss", "\\uf09e" },
  { "fa-rss_square", "\\uf143" },
  { "fa-rub", "\\uf158" },
  { "fa-ruble", "\\uf158" },
  { "fa-rupee", "\\uf156" },
  { "fa-s15", "\\uf2cd" },
  { "fa-safari", "\\uf267" },
  { "fa-save", "\\uf0c7" },
  { "fa-scissors", "\\uf0c4" },
  { "fa-scribd", "\\uf28a" },
  { "fa-search", "\\uf002" },
  { "fa-search_minus", "\\uf010" },
  { "fa-search_plus", "\\uf00e" },
  { "fa-sellsy", "\\uf213" },
  { "fa-send", "\\uf1d8" },
  { "fa-send_o", "\\uf1d9" },
  { "fa-server", "\\uf233" },
  { "fa-share", "\\uf064" },
  { "fa-share_alt", "\\uf1e0" },
  { "fa-share_alt_square", "\\uf1e1" },
  { "fa-share_square", "\\uf14d" },
  { "fa-share_square_o", "\\uf045" },
  { "fa-shekel", "\\uf20b" },
  { "fa-sheqel", "\\uf20b" },
  { "fa-shield", "\\uf132" },
  { "fa-ship", "\\uf21a" },
  { "fa-shirtsinbulk", "\\uf214" },
  { "fa-shopping_bag", "\\uf290" },
  { "fa-shopping_basket", "\\uf291" },
  { "fa-shopping_cart", "\\uf07a" },
  { "fa-shower", "\\uf2cc" },
  { "fa-sign_in", "\\uf090" },
  { "fa-sign_language", "\\uf2a7" },
  { "fa-sign_out", "\\uf08b" },
  { "fa-signal", "\\uf012" },
  { "fa-signing", "\\uf2a7" },
  { "fa-simplybuilt", "\\uf215" },
  { "fa-sitemap", "\\uf0e8" },
  { "fa-skyatlas", "\\uf216" },
  { "fa-skype", "\\uf17e" },
  { "fa-slack", "\\uf198" },
  { "fa-sliders", "\\uf1de" },
  { "fa-slideshare", "\\uf1e7" },
  { "fa-smile_o", "\\uf118" },
  { "fa-snapchat", "\\uf2ab" },
  { "fa-snapchat_ghost", "\\uf2ac" },
  { "fa-snapchat_square", "\\uf2ad" },
  { "fa-snowflake_o", "\\uf2dc" },
  { "fa-soccer_ball_o", "\\uf1e3" },
  { "fa-sort", "\\uf0dc" },
  { "fa-sort_alpha_asc", "\\uf15d" },
  { "fa-sort_alpha_desc", "\\uf15e" },
  { "fa-sort_amount_asc", "\\uf160" },
  { "fa-sort_amount_desc", "\\uf161" },
  { "fa-sort_asc", "\\uf0de" },
  { "fa-sort_desc", "\\uf0dd" },
  { "fa-sort_down", "\\uf0dd" },
  { "fa-sort_numeric_asc", "\\uf162" },
  { "fa-sort_numeric_desc", "\\uf163" },
  { "fa-sort_up", "\\uf0de" },
  { "fa-soundcloud", "\\uf1be" },
  { "fa-space_shuttle", "\\uf197" },
  { "fa-spinner", "\\uf110" },
  { "fa-spoon", "\\uf1b1" },
  { "fa-spotify", "\\uf1bc" },
  { "fa-square", "\\uf0c8" },
  { "fa-square_o", "\\uf096" },
  { "fa-stack_exchange", "\\uf18d" },
  { "fa-stack_overflow", "\\uf16c" },
  { "fa-star", "\\uf005" },
  { "fa-star_half", "\\uf089" },
  { "fa-star_half_empty", "\\uf123" },
  { "fa-star_half_full", "\\uf123" },
  { "fa-star_half_o", "\\uf123" },
  { "fa-star_o", "\\uf006" },
  { "fa-steam", "\\uf1b6" },
  { "fa-steam_square", "\\uf1b7" },
  { "fa-step_backward", "\\uf048" },
  { "fa-step_forward", "\\uf051" },
  { "fa-stethoscope", "\\uf0f1" },
  { "fa-sticky_note", "\\uf249" },
  { "fa-sticky_note_o", "\\uf24a" },
  { "fa-stop", "\\uf04d" },
  { "fa-stop_circle", "\\uf28d" },
  { "fa-stop_circle_o", "\\uf28e" },
  { "fa-street_view", "\\uf21d" },
  { "fa-strikethrough", "\\uf0cc" },
  { "fa-stumbleupon", "\\uf1a4" },
  { "fa-stumbleupon_circle", "\\uf1a3" },
  { "fa-subscript", "\\uf12c" },
  { "fa-subway", "\\uf239" },
  { "fa-suitcase", "\\uf0f2" },
  { "fa-sun_o", "\\uf185" },
  { "fa-superpowers", "\\uf2dd" },
  { "fa-superscript", "\\uf12b" },
  { "fa-support", "\\uf1cd" },
  { "fa-table", "\\uf0ce" },
  { "fa-tablet", "\\uf10a" },
  { "fa-tachometer", "\\uf0e4" },
  { "fa-tag", "\\uf02b" },
  { "fa-tags", "\\uf02c" },
  { "fa-tasks", "\\uf0ae" },
  { "fa-taxi", "\\uf1ba" },
  { "fa-telegram", "\\uf2c6" },
  { "fa-television", "\\uf26c" },
  { "fa-tencent_weibo", "\\uf1d5" },
  { "fa-terminal", "\\uf120" },
  { "fa-text_height", "\\uf034" },
  { "fa-text_width", "\\uf035" },
  { "fa-th", "\\uf00a" },
  { "fa-th_large", "\\uf009" },
  { "fa-th_list", "\\uf00b" },
  { "fa-themeisle", "\\uf2b2" },
  { "fa-thermometer", "\\uf2c7" },
  { "fa-thermometer_0", "\\uf2cb" },
  { "fa-thermometer_1", "\\uf2ca" },
  { "fa-thermometer_2", "\\uf2c9" },
  { "fa-thermometer_3", "\\uf2c8" },
  { "fa-thermometer_4", "\\uf2c7" },
  { "fa-thermometer_empty", "\\uf2cb" },
  { "fa-thermometer_full", "\\uf2c7" },
  { "fa-thermometer_half", "\\uf2c9" },
  { "fa-thermometer_quarter", "\\uf2ca" },
  { "fa-thermometer_three_quarters", "\\uf2c8" },
  { "fa-thumb_tack", "\\uf08d" },
  { "fa-thumbs_down", "\\uf165" },
  { "fa-thumbs_o_down", "\\uf088" },
  { "fa-thumbs_o_up", "\\uf087" },
  { "fa-thumbs_up", "\\uf164" },
  { "fa-ticket", "\\uf145" },
  { "fa-times", "\\uf00d" },
  { "fa-times_circle", "\\uf057" },
  { "fa-times_circle_o", "\\uf05c" },
  { "fa-times_rectangle", "\\uf2d3" },
  { "fa-times_rectangle_o", "\\uf2d4" },
  { "fa-tint", "\\uf043" },
  { "fa-toggle_down", "\\uf150" },
  { "fa-toggle_left", "\\uf191" },
  { "fa-toggle_off", "\\uf204" },
  { "fa-toggle_on", "\\uf205" },
  { "fa-toggle_right", "\\uf152" },
  { "fa-toggle_up", "\\uf151" },
  { "fa-trademark", "\\uf25c" },
  { "fa-train", "\\uf238" },
  { "fa-transgender", "\\uf224" },
  { "fa-transgender_alt", "\\uf225" },
  { "fa-trash", "\\uf1f8" },
  { "fa-trash_o", "\\uf014" },
  { "fa-tree", "\\uf1bb" },
  { "fa-trello", "\\uf181" },
  { "fa-tripadvisor", "\\uf262" },
  { "fa-trophy", "\\uf091" },
  { "fa-truck", "\\uf0d1" },
  { "fa-try", "\\uf195" },
  { "fa-tty", "\\uf1e4" },
  { "fa-tumblr", "\\uf173" },
  { "fa-tumblr_square", "\\uf174" },
  { "fa-turkish_lira", "\\uf195" },
  { "fa-tv", "\\uf26c" },
  { "fa-twitch", "\\uf1e8" },
  { "fa-twitter", "\\uf099" },
  { "fa-twitter_square", "\\uf081" },
  { "fa-umbrella", "\\uf0e9" },
  { "fa-underline", "\\uf0cd" },
  { "fa-undo", "\\uf0e2" },
  { "fa-universal_access", "\\uf29a" },
  { "fa-university", "\\uf19c" },
  { "fa-unlink", "\\uf127" },
  { "fa-unlock", "\\uf09c" },
  { "fa-unlock_alt", "\\uf13e" },
  { "fa-unsorted", "\\uf0dc" },
  { "fa-upload", "\\uf093" },
  { "fa-usb", "\\uf287" },
  { "fa-usd", "\\uf155" },
  { "fa-user", "\\uf007" },
  { "fa-user_circle", "\\uf2bd" },
  { "fa-user_circle_o", "\\uf2be" },
  { "fa-user_md", "\\uf0f0" },
  { "fa-user_o", "\\uf2c0" },
  { "fa-user_plus", "\\uf234" },
  { "fa-user_secret", "\\uf21b" },
  { "fa-user_times", "\\uf235" },
  { "fa-users", "\\uf0c0" },
  { "fa-vcard", "\\uf2bb" },
  { "fa-vcard_o", "\\uf2bc" },
  { "fa-venus", "\\uf221" },
  { "fa-venus_double", "\\uf226" },
  { "fa-venus_mars", "\\uf228" },
  { "fa-viacoin", "\\uf237" },
  { "fa-viadeo", "\\uf2a9" },
  { "fa-viadeo_square", "\\uf2aa" },
  { "fa-video_camera", "\\uf03d" },
  { "fa-vimeo", "\\uf27d" },
  { "fa-vimeo_square", "\\uf194" },
  { "fa-vine", "\\uf1ca" },
  { "fa-vk", "\\uf189" },
  { "fa-volume_control_phone", "\\uf2a0" },
  { "fa-volume_down", "\\uf027" },
  { "fa-volume_off", "\\uf026" },
  { "fa-volume_up", "\\uf028" },
  { "fa-warning", "\\uf071" },
  { "fa-wechat", "\\uf1d7" },
  { "fa-weibo", "\\uf18a" },
  { "fa-weixin", "\\uf1d7" },
  { "fa-whatsapp", "\\uf232" },
  { "fa-wheelchair", "\\uf193" },
  { "fa-wheelchair_alt", "\\uf29b" },
  { "fa-wifi", "\\uf1eb" },
  { "fa-wikipedia_w", "\\uf266" },
  { "fa-window_close", "\\uf2d3" },
  { "fa-window_close_o", "\\uf2d4" },
  { "fa-window_maximize", "\\uf2d0" },
  { "fa-window_minimize", "\\uf2d1" },
  { "fa-window_restore", "\\uf2d2" },
  { "fa-windows", "\\uf17a" },
  { "fa-won", "\\uf159" },
  { "fa-wordpress", "\\uf19a" },
  { "fa-wpbeginner", "\\uf297" },
  { "fa-wpexplorer", "\\uf2de" },
  { "fa-wpforms", "\\uf298" },
  { "fa-wrench", "\\uf0ad" },
  { "fa-xing", "\\uf168" },
  { "fa-xing_square", "\\uf169" },
  { "fa-y_combinator", "\\uf23b" },
  { "fa-y_combinator_square", "\\uf1d4" },
  { "fa-yahoo", "\\uf19e" },
  { "fa-yc", "\\uf23b" },
  { "fa-yc_square", "\\uf1d4" },
  { "fa-yelp", "\\uf1e9" },
  { "fa-yen", "\\uf157" },
  { "fa-yoast", "\\uf2b1" },
  { "fa-youtube", "\\uf167" },
  { "fa-youtube_play", "\\uf16a" },
  { "fa-youtube_square", "\\uf166" },
  { "fae-apple_fruit", "\\ue29e" },
  { "fae-atom", "\\ue27f" },
  { "fae-bacteria", "\\ue280" },
  { "fae-banana", "\\ue281" },
  { "fae-bath", "\\ue282" },
  { "fae-bed", "\\ue283" },
  { "fae-benzene", "\\ue284" },
  { "fae-bigger", "\\ue285" },
  { "fae-biohazard", "\\ue286" },
  { "fae-blogger_circle", "\\ue287" },
  { "fae-blogger_square", "\\ue288" },
  { "fae-bones", "\\ue289" },
  { "fae-book_open", "\\ue28a" },
  { "fae-book_open_o", "\\ue28b" },
  { "fae-brain", "\\ue28c" },
  { "fae-bread", "\\ue28d" },
  { "fae-butterfly", "\\ue28e" },
  { "fae-carot", "\\ue28f" },
  { "fae-cc_by", "\\ue290" },
  { "fae-cc_cc", "\\ue291" },
  { "fae-cc_nc", "\\ue292" },
  { "fae-cc_nc_eu", "\\ue293" },
  { "fae-cc_nc_jp", "\\ue294" },
  { "fae-cc_nd", "\\ue295" },
  { "fae-cc_remix", "\\ue296" },
  { "fae-cc_sa", "\\ue297" },
  { "fae-cc_share", "\\ue298" },
  { "fae-cc_zero", "\\ue299" },
  { "fae-checklist_o", "\\ue29a" },
  { "fae-cherry", "\\ue29b" },
  { "fae-chess_bishop", "\\ue29c" },
  { "fae-chess_horse", "\\ue25f" },
  { "fae-chess_king", "\\ue260" },
  { "fae-chess_pawn", "\\ue261" },
  { "fae-chess_queen", "\\ue262" },
  { "fae-chess_tower", "\\ue263" },
  { "fae-cheese", "\\ue264" },
  { "fae-chicken_thigh", "\\ue29f" },
  { "fae-chilli", "\\ue265" },
  { "fae-chip", "\\ue266" },
  { "fae-cicling", "\\ue267" },
  { "fae-cloud", "\\ue268" },
  { "fae-cockroach", "\\ue269" },
  { "fae-coffe_beans", "\\ue26a" },
  { "fae-coins", "\\ue26b" },
  { "fae-comb", "\\ue26c" },
  { "fae-comet", "\\ue26d" },
  { "fae-crown", "\\ue26e" },
  { "fae-cup_coffe", "\\ue26f" },
  { "fae-dice", "\\ue270" },
  { "fae-disco", "\\ue271" },
  { "fae-dna", "\\ue272" },
  { "fae-donut", "\\ue273" },
  { "fae-dress", "\\ue274" },
  { "fae-drop", "\\ue275" },
  { "fae-ello", "\\ue276" },
  { "fae-envelope_open", "\\ue277" },
  { "fae-envelope_open_o", "\\ue278" },
  { "fae-equal", "\\ue279" },
  { "fae-equal_bigger", "\\ue27a" },
  { "fae-feedly", "\\ue27b" },
  { "fae-file_export", "\\ue27c" },
  { "fae-file_import", "\\ue27d" },
  { "fae-fingerprint", "\\ue23f" },
  { "fae-floppy", "\\ue240" },
  { "fae-footprint", "\\ue241" },
  { "fae-freecodecamp", "\\ue242" },
  { "fae-galaxy", "\\ue243" },
  { "fae-galery", "\\ue244" },
  { "fae-gift_card", "\\ue2a0" },
  { "fae-glass", "\\ue245" },
  { "fae-google_drive", "\\ue246" },
  { "fae-google_play", "\\ue247" },
  { "fae-gps", "\\ue248" },
  { "fae-grav", "\\ue249" },
  { "fae-guitar", "\\ue24a" },
  { "fae-gut", "\\ue24b" },
  { "fae-halter", "\\ue24c" },
  { "fae-hamburger", "\\ue24d" },
  { "fae-hat", "\\ue24e" },
  { "fae-hexagon", "\\ue24f" },
  { "fae-high_heel", "\\ue250" },
  { "fae-hotdog", "\\ue251" },
  { "fae-ice_cream", "\\ue252" },
  { "fae-id_card", "\\ue253" },
  { "fae-imdb", "\\ue254" },
  { "fae-infinity", "\\ue255" },
  { "fae-injection", "\\ue2a1" },
  { "fae-isle", "\\ue2a2" },
  { "fae-java", "\\ue256" },
  { "fae-layers", "\\ue257" },
  { "fae-lips", "\\ue258" },
  { "fae-lipstick", "\\ue259" },
  { "fae-liver", "\\ue25a" },
  { "fae-lollipop", "\\ue2a3" },
  { "fae-loyalty_card", "\\ue2a4" },
  { "fae-lung", "\\ue25b" },
  { "fae-makeup_brushes", "\\ue25c" },
  { "fae-maximize", "\\ue25d" },
  { "fae-meat", "\\ue2a5" },
  { "fae-medicine", "\\ue221" },
  { "fae-microscope", "\\ue222" },
  { "fae-milk_bottle", "\\ue223" },
  { "fae-minimize", "\\ue224" },
  { "fae-molecule", "\\ue225" },
  { "fae-moon_cloud", "\\ue226" },
  { "fae-mountains", "\\ue2a6" },
  { "fae-mushroom", "\\ue227" },
  { "fae-mustache", "\\ue228" },
  { "fae-mysql", "\\ue229" },
  { "fae-nintendo", "\\ue22a" },
  { "fae-orange", "\\ue2a7" },
  { "fae-palette_color", "\\ue22b" },
  { "fae-peach", "\\ue2a8" },
  { "fae-pear", "\\ue2a9" },
  { "fae-pi", "\\ue22c" },
  { "fae-pizza", "\\ue22d" },
  { "fae-planet", "\\ue22e" },
  { "fae-plant", "\\ue22f" },
  { "fae-playstation", "\\ue230" },
  { "fae-poison", "\\ue231" },
  { "fae-popcorn", "\\ue232" },
  { "fae-popsicle", "\\ue233" },
  { "fae-pulse", "\\ue234" },
  { "fae-python", "\\ue235" },
  { "fae-quora_circle", "\\ue236" },
  { "fae-quora_square", "\\ue237" },
  { "fae-radioactive", "\\ue238" },
  { "fae-raining", "\\ue239" },
  { "fae-real_heart", "\\ue23a" },
  { "fae-refrigerator", "\\ue23b" },
  { "fae-restore", "\\ue23c" },
  { "fae-ring", "\\ue23d" },
  { "fae-ruby", "\\ue23e" },
  { "fae-ruby_o", "\\ue21e" },
  { "fae-ruler", "\\ue21f" },
  { "fae-shirt", "\\ue218" },
  { "fae-slash", "\\ue216" },
  { "fae-smaller", "\\ue200" },
  { "fae-snowing", "\\ue201" },
  { "fae-soda", "\\ue202" },
  { "fae-sofa", "\\ue203" },
  { "fae-soup", "\\ue204" },
  { "fae-spermatozoon", "\\ue205" },
  { "fae-spin_double", "\\ue206" },
  { "fae-stomach", "\\ue207" },
  { "fae-storm", "\\ue208" },
  { "fae-sun_cloud", "\\ue21d" },
  { "fae-sushi", "\\ue21a" },
  { "fae-tacos", "\\ue219" },
  { "fae-telegram", "\\ue217" },
  { "fae-telegram_circle", "\\ue215" },
  { "fae-telescope", "\\ue209" },
  { "fae-thermometer", "\\ue20a" },
  { "fae-thermometer_high", "\\ue20b" },
  { "fae-thermometer_low", "\\ue20c" },
  { "fae-thin_close", "\\ue20d" },
  { "fae-toilet", "\\ue20e" },
  { "fae-tools", "\\ue20f" },
  { "fae-tooth", "\\ue210" },
  { "fae-tree", "\\ue21c" },
  { "fae-triangle_ruler", "\\ue21b" },
  { "fae-umbrella", "\\ue220" },
  { "fae-uterus", "\\ue211" },
  { "fae-virus", "\\ue214" },
  { "fae-w3c", "\\ue212" },
  { "fae-walking", "\\ue213" },
  { "fae-wallet", "\\ue25e" },
  { "fae-wind", "\\ue27e" },
  { "fae-xbox", "\\ue29d" },
  { "iec-power", "\\u23fb" },
  { "iec-power_off", "\\u2b58" },
  { "iec-power_on", "\\u23fd" },
  { "iec-sleep_mode", "\\u23fe" },
  { "iec-toggle_power", "\\u23fc" },
  { "indent-dotted_guide", "\\ue621" },
  { "indent-line", "\\ue621" },
  { "indentation-line", "\\ue621" },
  { "linux-alpine", "\\uf300" },
  { "linux-aosc", "\\uf301" },
  { "linux-apple", "\\uf302" },
  { "linux-archlinux", "\\uf303" },
  { "linux-centos", "\\uf304" },
  { "linux-coreos", "\\uf305" },
  { "linux-debian", "\\uf306" },
  { "linux-devuan", "\\uf307" },
  { "linux-docker", "\\uf308" },
  { "linux-elementary", "\\uf309" },
  { "linux-fedora", "\\uf30a" },
  { "linux-fedora_inverse", "\\uf30b" },
  { "linux-freebsd", "\\uf30c" },
  { "linux-gentoo", "\\uf30d" },
  { "linux-linuxmint", "\\uf30e" },
  { "linux-linuxmint_inverse", "\\uf30f" },
  { "linux-mageia", "\\uf310" },
  { "linux-mandriva", "\\uf311" },
  { "linux-manjaro", "\\uf312" },
  { "linux-nixos", "\\uf313" },
  { "linux-opensuse", "\\uf314" },
  { "linux-raspberry_pi", "\\uf315" },
  { "linux-redhat", "\\uf316" },
  { "linux-sabayon", "\\uf317" },
  { "linux-slackware", "\\uf318" },
  { "linux-slackware_inverse", "\\uf319" },
  { "linux-tux", "\\uf31a" },
  { "linux-ubuntu", "\\uf31b" },
  { "linux-ubuntu_inverse", "\\uf31c" },
  { "mdi-access_point", "\\uf501" },
  { "mdi-access_point_network", "\\uf502" },
  { "mdi-account", "\\uf503" },
  { "mdi-account_alert", "\\uf504" },
  { "mdi-account_box", "\\uf505" },
  { "mdi-account_box_outline", "\\uf506" },
  { "mdi-account_card_details", "\\ufad1" },
  { "mdi-account_check", "\\uf507" },
  { "mdi-account_circle", "\\uf508" },
  { "mdi-account_convert", "\\uf509" },
  { "mdi-account_edit", "\\ufbba" },
  { "mdi-account_key", "\\uf50a" },
  { "mdi-account_location", "\\uf50b" },
  { "mdi-account_minus", "\\uf50c" },
  { "mdi-account_multiple", "\\uf50d" },
  { "mdi-account_multiple_minus", "\\ufad2" },
  { "mdi-account_multiple_outline", "\\uf50e" },
  { "mdi-account_multiple_plus", "\\uf50f" },
  { "mdi-account_multiple_plus_outline", "\\ufcfe" },
  { "mdi-account_network", "\\uf510" },
  { "mdi-account_off", "\\uf511" },
  { "mdi-account_outline", "\\uf512" },
  { "mdi-account_plus", "\\uf513" },
  { "mdi-account_plus_outline", "\\ufcff" },
  { "mdi-account_remove", "\\uf514" },
  { "mdi-account_search", "\\uf515" },
  { "mdi-account_settings", "\\ufb2f" },
  { "mdi-account_settings_variant", "\\ufb30" },
  { "mdi-account_star", "\\uf516" },
  { "mdi-account_switch", "\\uf518" },
  { "mdi-adjust", "\\uf519" },
  { "mdi-air_conditioner", "\\uf51a" },
  { "mdi-airballoon", "\\uf51b" },
  { "mdi-airplane", "\\uf51c" },
  { "mdi-airplane_landing", "\\ufad3" },
  { "mdi-airplane_off", "\\uf51d" },
  { "mdi-airplane_takeoff", "\\ufad4" },
  { "mdi-airplay", "\\uf51e" },
  { "mdi-alarm", "\\uf51f" },
  { "mdi-alarm_bell", "\\ufc8c" },
  { "mdi-alarm_check", "\\uf520" },
  { "mdi-alarm_light", "\\ufc8d" },
  { "mdi-alarm_multiple", "\\uf521" },
  { "mdi-alarm_off", "\\uf522" },
  { "mdi-alarm_plus", "\\uf523" },
  { "mdi-alarm_snooze", "\\ufb8c" },
  { "mdi-album", "\\uf524" },
  { "mdi-alert", "\\uf525" },
  { "mdi-alert_box", "\\uf526" },
  { "mdi-alert_circle", "\\uf527" },
  { "mdi-alert_circle_outline", "\\ufad5" },
  { "mdi-alert_decagram", "\\ufbbb" },
  { "mdi-alert_octagon", "\\uf528" },
  { "mdi-alert_octagram", "\\ufc65" },
  { "mdi-alert_outline", "\\uf529" },
  { "mdi-all_inclusive", "\\ufbbc" },
  { "mdi-allo", "\\ufd00" },
  { "mdi-alpha", "\\uf52a" },
  { "mdi-alphabetical", "\\uf52b" },
  { "mdi-altimeter", "\\ufad6" },
  { "mdi-amazon", "\\uf52c" },
  { "mdi-amazon_clouddrive", "\\uf52d" },
  { "mdi-ambulance", "\\uf52e" },
  { "mdi-amplifier", "\\uf52f" },
  { "mdi-anchor", "\\uf530" },
  { "mdi-android", "\\uf531" },
  { "mdi-android_debug_bridge", "\\uf532" },
  { "mdi-android_head", "\\ufc8e" },
  { "mdi-android_studio", "\\uf533" },
  { "mdi-angular", "\\ufbb0" },
  { "mdi-angularjs", "\\ufbbd" },
  { "mdi-animation", "\\ufad7" },
  { "mdi-apple", "\\uf534" },
  { "mdi-apple_finder", "\\uf535" },
  { "mdi-apple_ios", "\\uf536" },
  { "mdi-apple_keyboard_caps", "\\ufb31" },
  { "mdi-apple_keyboard_command", "\\ufb32" },
  { "mdi-apple_keyboard_control", "\\ufb33" },
  { "mdi-apple_keyboard_option", "\\ufb34" },
  { "mdi-apple_keyboard_shift", "\\ufb35" },
  { "mdi-apple_mobileme", "\\uf537" },
  { "mdi-apple_safari", "\\uf538" },
  { "mdi-application", "\\ufb13" },
  { "mdi-approval", "\\ufc8f" },
  { "mdi-apps", "\\uf53a" },
  { "mdi-archive", "\\uf53b" },
  { "mdi-arrange_bring_forward", "\\uf53c" },
  { "mdi-arrange_bring_to_front", "\\uf53d" },
  { "mdi-arrange_send_backward", "\\uf53e" },
  { "mdi-arrange_send_to_back", "\\uf53f" },
  { "mdi-arrow_all", "\\uf540" },
  { "mdi-arrow_bottom_left", "\\uf541" },
  { "mdi-arrow_bottom_right", "\\uf542" },
  { "mdi-arrow_collapse", "\\ufb14" },
  { "mdi-arrow_collapse_all", "\\uf543" },
  { "mdi-arrow_collapse_down", "\\ufc90" },
  { "mdi-arrow_collapse_left", "\\ufc91" },
  { "mdi-arrow_collapse_right", "\\ufc92" },
  { "mdi-arrow_collapse_up", "\\ufc93" },
  { "mdi-arrow_down", "\\uf544" },
  { "mdi-arrow_down_bold", "\\ufc2c" },
  { "mdi-arrow_down_bold_box", "\\ufc2d" },
  { "mdi-arrow_down_bold_box_outline", "\\ufc2e" },
  { "mdi-arrow_down_bold_circle", "\\uf546" },
  { "mdi-arrow_down_bold_circle_outline", "\\uf547" },
  { "mdi-arrow_down_bold_hexagon_outline", "\\uf548" },
  { "mdi-arrow_down_box", "\\ufbbe" },
  { "mdi-arrow_down_drop_circle", "\\uf549" },
  { "mdi-arrow_down_drop_circle_outline", "\\uf54a" },
  { "mdi-arrow_down_thick", "\\uf545" },
  { "mdi-arrow_expand", "\\ufb15" },
  { "mdi-arrow_expand_all", "\\uf54b" },
  { "mdi-arrow_expand_down", "\\ufc94" },
  { "mdi-arrow_expand_left", "\\ufc95" },
  { "mdi-arrow_expand_right", "\\ufc96" },
  { "mdi-arrow_expand_up", "\\ufc97" },
  { "mdi-arrow_left", "\\uf54c" },
  { "mdi-arrow_left_bold", "\\ufc2f" },
  { "mdi-arrow_left_bold_box", "\\ufc30" },
  { "mdi-arrow_left_bold_box_outline", "\\ufc31" },
  { "mdi-arrow_left_bold_circle", "\\uf54e" },
  { "mdi-arrow_left_bold_circle_outline", "\\uf54f" },
  { "mdi-arrow_left_bold_hexagon_outline", "\\uf550" },
  { "mdi-arrow_left_box", "\\ufbbf" },
  { "mdi-arrow_left_drop_circle", "\\uf551" },
  { "mdi-arrow_left_drop_circle_outline", "\\uf552" },
  { "mdi-arrow_left_thick", "\\uf54d" },
  { "mdi-arrow_right", "\\uf553" },
  { "mdi-arrow_right_bold", "\\ufc32" },
  { "mdi-arrow_right_bold_box", "\\ufc33" },
  { "mdi-arrow_right_bold_box_outline", "\\ufc34" },
  { "mdi-arrow_right_bold_circle", "\\uf555" },
  { "mdi-arrow_right_bold_circle_outline", "\\uf556" },
  { "mdi-arrow_right_bold_hexagon_outline", "\\uf557" },
  { "mdi-arrow_right_box", "\\ufbc0" },
  { "mdi-arrow_right_drop_circle", "\\uf558" },
  { "mdi-arrow_right_drop_circle_outline", "\\uf559" },
  { "mdi-arrow_right_thick", "\\uf554" },
  { "mdi-arrow_top_left", "\\uf55a" },
  { "mdi-arrow_top_right", "\\uf55b" },
  { "mdi-arrow_up", "\\uf55c" },
  { "mdi-arrow_up_bold", "\\ufc35" },
  { "mdi-arrow_up_bold_box", "\\ufc36" },
  { "mdi-arrow_up_bold_box_outline", "\\ufc37" },
  { "mdi-arrow_up_bold_circle", "\\uf55e" },
  { "mdi-arrow_up_bold_circle_outline", "\\uf55f" },
  { "mdi-arrow_up_bold_hexagon_outline", "\\uf560" },
  { "mdi-arrow_up_box", "\\ufbc1" },
  { "mdi-arrow_up_drop_circle", "\\uf561" },
  { "mdi-arrow_up_drop_circle_outline", "\\uf562" },
  { "mdi-arrow_up_thick", "\\uf55d" },
  { "mdi-artist", "\\ufd01" },
  { "mdi-assistant", "\\uf563" },
  { "mdi-asterisk", "\\ufbc2" },
  { "mdi-at", "\\uf564" },
  { "mdi-atlassian", "\\ufd02" },
  { "mdi-atom", "\\ufc66" },
  { "mdi-attachment", "\\uf565" },
  { "mdi-audiobook", "\\uf566" },
  { "mdi-auto_fix", "\\uf567" },
  { "mdi-auto_upload", "\\uf568" },
  { "mdi-autorenew", "\\uf569" },
  { "mdi-av_timer", "\\uf56a" },
  { "mdi-azure", "\\ufd03" },
  { "mdi-baby", "\\uf56b" },
  { "mdi-baby_buggy", "\\ufb8d" },
  { "mdi-backburger", "\\uf56c" },
  { "mdi-backspace", "\\uf56d" },
  { "mdi-backup_restore", "\\uf56e" },
  { "mdi-bandcamp", "\\ufb73" },
  { "mdi-bank", "\\uf56f" },
  { "mdi-barcode", "\\uf570" },
  { "mdi-barcode_scan", "\\uf571" },
  { "mdi-barley", "\\uf572" },
  { "mdi-barrel", "\\uf573" },
  { "mdi-basecamp", "\\uf574" },
  { "mdi-basket", "\\uf575" },
  { "mdi-basket_fill", "\\uf576" },
  { "mdi-basket_unfill", "\\uf577" },
  { "mdi-basketball", "\\ufd04" },
  { "mdi-battery", "\\uf578" },
  { "mdi-battery_10", "\\uf579" },
  { "mdi-battery_20", "\\uf57a" },
  { "mdi-battery_30", "\\uf57b" },
  { "mdi-battery_40", "\\uf57c" },
  { "mdi-battery_50", "\\uf57d" },
  { "mdi-battery_60", "\\uf57e" },
  { "mdi-battery_70", "\\uf57f" },
  { "mdi-battery_80", "\\uf580" },
  { "mdi-battery_90", "\\uf581" },
  { "mdi-battery_alert", "\\uf582" },
  { "mdi-battery_charging", "\\uf583" },
  { "mdi-battery_charging_100", "\\uf584" },
  { "mdi-battery_charging_20", "\\uf585" },
  { "mdi-battery_charging_30", "\\uf586" },
  { "mdi-battery_charging_40", "\\uf587" },
  { "mdi-battery_charging_60", "\\uf588" },
  { "mdi-battery_charging_80", "\\uf589" },
  { "mdi-battery_charging_90", "\\uf58a" },
  { "mdi-battery_charging_wireless", "\\ufd05" },
  { "mdi-battery_charging_wireless_10", "\\ufd06" },
  { "mdi-battery_charging_wireless_20", "\\ufd07" },
  { "mdi-battery_charging_wireless_30", "\\ufd08" },
  { "mdi-battery_charging_wireless_40", "\\ufd09" },
  { "mdi-battery_charging_wireless_50", "\\ufd0a" },
  { "mdi-battery_charging_wireless_60", "\\ufd0b" },
  { "mdi-battery_charging_wireless_70", "\\ufd0c" },
  { "mdi-battery_charging_wireless_80", "\\ufd0d" },
  { "mdi-battery_charging_wireless_90", "\\ufd0e" },
  { "mdi-battery_charging_wireless_alert", "\\ufd0f" },
  { "mdi-battery_charging_wireless_outline", "\\ufd10" },
  { "mdi-battery_minus", "\\uf58b" },
  { "mdi-battery_negative", "\\uf58c" },
  { "mdi-battery_outline", "\\uf58d" },
  { "mdi-battery_plus", "\\uf58e" },
  { "mdi-battery_positive", "\\uf58f" },
  { "mdi-battery_unknown", "\\uf590" },
  { "mdi-beach", "\\uf591" },
  { "mdi-beaker", "\\ufb8e" },
  { "mdi-beats", "\\uf596" },
  { "mdi-beer", "\\uf597" },
  { "mdi-behance", "\\uf598" },
  { "mdi-bell", "\\uf599" },
  { "mdi-bell_off", "\\uf59a" },
  { "mdi-bell_outline", "\\uf59b" },
  { "mdi-bell_plus", "\\uf59c" },
  { "mdi-bell_ring", "\\uf59d" },
  { "mdi-bell_ring_outline", "\\uf59e" },
  { "mdi-bell_sleep", "\\uf59f" },
  { "mdi-beta", "\\uf5a0" },
  { "mdi-bible", "\\uf5a1" },
  { "mdi-bike", "\\uf5a2" },
  { "mdi-bing", "\\uf5a3" },
  { "mdi-binoculars", "\\uf5a4" },
  { "mdi-bio", "\\uf5a5" },
  { "mdi-biohazard", "\\uf5a6" },
  { "mdi-bitbucket", "\\uf5a7" },
  { "mdi-bitcoin", "\\ufd11" },
  { "mdi-black_mesa", "\\uf5a8" },
  { "mdi-blackberry", "\\uf5a9" },
  { "mdi-blender", "\\uf5aa" },
  { "mdi-blinds", "\\uf5ab" },
  { "mdi-block_helper", "\\uf5ac" },
  { "mdi-blogger", "\\uf5ad" },
  { "mdi-bluetooth", "\\uf5ae" },
  { "mdi-bluetooth_audio", "\\uf5af" },
  { "mdi-bluetooth_connect", "\\uf5b0" },
  { "mdi-bluetooth_off", "\\uf5b1" },
  { "mdi-bluetooth_settings", "\\uf5b2" },
  { "mdi-bluetooth_transfer", "\\uf5b3" },
  { "mdi-blur", "\\uf5b4" },
  { "mdi-blur_linear", "\\uf5b5" },
  { "mdi-blur_off", "\\uf5b6" },
  { "mdi-blur_radial", "\\uf5b7" },
  { "mdi-bomb", "\\ufb8f" },
  { "mdi-bomb_off", "\\ufbc3" },
  { "mdi-bone", "\\uf5b8" },
  { "mdi-book", "\\uf5b9" },
  { "mdi-book_minus", "\\ufad8" },
  { "mdi-book_multiple", "\\uf5ba" },
  { "mdi-book_multiple_variant", "\\uf5bb" },
  { "mdi-book_open", "\\uf5bc" },
  { "mdi-book_open_page_variant", "\\ufad9" },
  { "mdi-book_open_variant", "\\uf5bd" },
  { "mdi-book_plus", "\\ufada" },
  { "mdi-book_secure", "\\ufc98" },
  { "mdi-book_unsecure", "\\ufc99" },
  { "mdi-book_variant", "\\uf5be" },
  { "mdi-bookmark", "\\uf5bf" },
  { "mdi-bookmark_check", "\\uf5c0" },
  { "mdi-bookmark_music", "\\uf5c1" },
  { "mdi-bookmark_outline", "\\uf5c2" },
  { "mdi-bookmark_plus", "\\uf5c4" },
  { "mdi-bookmark_plus_outline", "\\uf5c3" },
  { "mdi-bookmark_remove", "\\uf5c5" },
  { "mdi-boombox", "\\ufadb" },
  { "mdi-bootstrap", "\\ufbc4" },
  { "mdi-border_all", "\\uf5c6" },
  { "mdi-border_bottom", "\\uf5c7" },
  { "mdi-border_color", "\\uf5c8" },
  { "mdi-border_horizontal", "\\uf5c9" },
  { "mdi-border_inside", "\\uf5ca" },
  { "mdi-border_left", "\\uf5cb" },
  { "mdi-border_none", "\\uf5cc" },
  { "mdi-border_outside", "\\uf5cd" },
  { "mdi-border_right", "\\uf5ce" },
  { "mdi-border_style", "\\uf5cf" },
  { "mdi-border_top", "\\uf5d0" },
  { "mdi-border_vertical", "\\uf5d1" },
  { "mdi-bow_tie", "\\ufb76" },
  { "mdi-bowl", "\\ufb16" },
  { "mdi-bowling", "\\uf5d2" },
  { "mdi-box", "\\uf5d3" },
  { "mdi-box_cutter", "\\uf5d4" },
  { "mdi-box_shadow", "\\ufb36" },
  { "mdi-bridge", "\\ufb17" },
  { "mdi-briefcase", "\\uf5d5" },
  { "mdi-briefcase_check", "\\uf5d6" },
  { "mdi-briefcase_download", "\\uf5d7" },
  { "mdi-briefcase_outline", "\\ufd12" },
  { "mdi-briefcase_upload", "\\uf5d8" },
  { "mdi-brightness_1", "\\uf5d9" },
  { "mdi-brightness_2", "\\uf5da" },
  { "mdi-brightness_3", "\\uf5db" },
  { "mdi-brightness_4", "\\uf5dc" },
  { "mdi-brightness_5", "\\uf5dd" },
  { "mdi-brightness_6", "\\uf5de" },
  { "mdi-brightness_7", "\\uf5df" },
  { "mdi-brightness_auto", "\\uf5e0" },
  { "mdi-broom", "\\uf5e1" },
  { "mdi-brush", "\\uf5e2" },
  { "mdi-buffer", "\\ufb18" },
  { "mdi-bug", "\\uf5e3" },
  { "mdi-bulletin_board", "\\uf5e4" },
  { "mdi-bullhorn", "\\uf5e5" },
  { "mdi-bullseye", "\\ufadc" },
  { "mdi-bus", "\\uf5e6" },
  { "mdi-bus_articulated_end", "\\ufc9a" },
  { "mdi-bus_articulated_front", "\\ufc9b" },
  { "mdi-bus_double_decker", "\\ufc9c" },
  { "mdi-bus_school", "\\ufc9d" },
  { "mdi-bus_side", "\\ufc9e" },
  { "mdi-cached", "\\uf5e7" },
  { "mdi-cake", "\\uf5e8" },
  { "mdi-cake_layered", "\\uf5e9" },
  { "mdi-cake_variant", "\\uf5ea" },
  { "mdi-calculator", "\\uf5eb" },
  { "mdi-calendar", "\\uf5ec" },
  { "mdi-calendar_blank", "\\uf5ed" },
  { "mdi-calendar_check", "\\uf5ee" },
  { "mdi-calendar_clock", "\\uf5ef" },
  { "mdi-calendar_multiple", "\\uf5f0" },
  { "mdi-calendar_multiple_check", "\\uf5f1" },
  { "mdi-calendar_plus", "\\uf5f2" },
  { "mdi-calendar_question", "\\ufb90" },
  { "mdi-calendar_range", "\\ufb77" },
  { "mdi-calendar_remove", "\\uf5f3" },
  { "mdi-calendar_text", "\\uf5f4" },
  { "mdi-calendar_today", "\\uf5f5" },
  { "mdi-call_made", "\\uf5f6" },
  { "mdi-call_merge", "\\uf5f7" },
  { "mdi-call_missed", "\\uf5f8" },
  { "mdi-call_received", "\\uf5f9" },
  { "mdi-call_split", "\\uf5fa" },
  { "mdi-camcorder", "\\uf5fb" },
  { "mdi-camcorder_box", "\\uf5fc" },
  { "mdi-camcorder_box_off", "\\uf5fd" },
  { "mdi-camcorder_off", "\\uf5fe" },
  { "mdi-camera", "\\uf5ff" },
  { "mdi-camera_burst", "\\ufb91" },
  { "mdi-camera_enhance", "\\uf600" },
  { "mdi-camera_front", "\\uf601" },
  { "mdi-camera_front_variant", "\\uf602" },
  { "mdi-camera_gopro", "\\ufc9f" },
  { "mdi-camera_iris", "\\uf603" },
  { "mdi-camera_metering_center", "\\ufca0" },
  { "mdi-camera_metering_matrix", "\\ufca1" },
  { "mdi-camera_metering_partial", "\\ufca2" },
  { "mdi-camera_metering_spot", "\\ufca3" },
  { "mdi-camera_off", "\\ufade" },
  { "mdi-camera_party_mode", "\\uf604" },
  { "mdi-camera_rear", "\\uf605" },
  { "mdi-camera_rear_variant", "\\uf606" },
  { "mdi-camera_switch", "\\uf607" },
  { "mdi-camera_timer", "\\uf608" },
  { "mdi-cancel", "\\ufc38" },
  { "mdi-candle", "\\ufae1" },
  { "mdi-candycane", "\\uf609" },
  { "mdi-cannabis", "\\ufca4" },
  { "mdi-car", "\\uf60a" },
  { "mdi-car_battery", "\\uf60b" },
  { "mdi-car_connected", "\\uf60c" },
  { "mdi-car_convertible", "\\ufca5" },
  { "mdi-car_estate", "\\ufca6" },
  { "mdi-car_hatchback", "\\ufca7" },
  { "mdi-car_pickup", "\\ufca8" },
  { "mdi-car_side", "\\ufca9" },
  { "mdi-car_sports", "\\ufcaa" },
  { "mdi-car_wash", "\\uf60d" },
  { "mdi-caravan", "\\ufcab" },
  { "mdi-cards", "\\ufb37" },
  { "mdi-cards_outline", "\\ufb38" },
  { "mdi-cards_playing_outline", "\\ufb39" },
  { "mdi-cards_variant", "\\ufbc5" },
  { "mdi-carrot", "\\uf60e" },
  { "mdi-cart", "\\uf60f" },
  { "mdi-cart_off", "\\ufb6a" },
  { "mdi-cart_outline", "\\uf610" },
  { "mdi-cart_plus", "\\uf611" },
  { "mdi-case_sensitive_alt", "\\uf612" },
  { "mdi-cash", "\\uf613" },
  { "mdi-cash_100", "\\uf614" },
  { "mdi-cash_multiple", "\\uf615" },
  { "mdi-cash_usd", "\\uf616" },
  { "mdi-cast", "\\uf617" },
  { "mdi-cast_connected", "\\uf618" },
  { "mdi-cast_off", "\\ufc88" },
  { "mdi-castle", "\\uf619" },
  { "mdi-cat", "\\uf61a" },
  { "mdi-cctv", "\\ufcac" },
  { "mdi-ceiling_light", "\\ufc67" },
  { "mdi-cellphone", "\\uf61b" },
  { "mdi-cellphone_android", "\\uf61c" },
  { "mdi-cellphone_basic", "\\uf61d" },
  { "mdi-cellphone_dock", "\\uf61e" },
  { "mdi-cellphone_iphone", "\\uf61f" },
  { "mdi-cellphone_link", "\\uf620" },
  { "mdi-cellphone_link_off", "\\uf621" },
  { "mdi-cellphone_settings", "\\uf622" },
  { "mdi-cellphone_wireless", "\\ufd13" },
  { "mdi-certificate", "\\uf623" },
  { "mdi-chair_school", "\\uf624" },
  { "mdi-chart_arc", "\\uf625" },
  { "mdi-chart_areaspline", "\\uf626" },
  { "mdi-chart_bar", "\\uf627" },
  { "mdi-chart_bar_stacked", "\\ufc68" },
  { "mdi-chart_bubble", "\\ufae2" },
  { "mdi-chart_donut", "\\ufcad" },
  { "mdi-chart_donut_variant", "\\ufcae" },
  { "mdi-chart_gantt", "\\ufb6b" },
  { "mdi-chart_histogram", "\\uf628" },
  { "mdi-chart_line", "\\uf629" },
  { "mdi-chart_line_stacked", "\\ufc69" },
  { "mdi-chart_line_variant", "\\ufcaf" },
  { "mdi-chart_pie", "\\uf62a" },
  { "mdi-chart_scatterplot_hexbin", "\\ufb6c" },
  { "mdi-chart_timeline", "\\ufb6d" },
  { "mdi-check", "\\uf62b" },
  { "mdi-check_all", "\\uf62c" },
  { "mdi-check_circle", "\\ufadf" },
  { "mdi-check_circle_outline", "\\ufae0" },
  { "mdi-checkbox_blank", "\\uf62d" },
  { "mdi-checkbox_blank_circle", "\\uf62e" },
  { "mdi-checkbox_blank_circle_outline", "\\uf62f" },
  { "mdi-checkbox_blank_outline", "\\uf630" },
  { "mdi-checkbox_marked", "\\uf631" },
  { "mdi-checkbox_marked_circle", "\\uf632" },
  { "mdi-checkbox_marked_circle_outline", "\\uf633" },
  { "mdi-checkbox_marked_outline", "\\uf634" },
  { "mdi-checkbox_multiple_blank", "\\uf635" },
  { "mdi-checkbox_multiple_blank_circle", "\\ufb3a" },
  { "mdi-checkbox_multiple_blank_circle_outline", "\\ufb3b" },
  { "mdi-checkbox_multiple_blank_outline", "\\uf636" },
  { "mdi-checkbox_multiple_marked", "\\uf637" },
  { "mdi-checkbox_multiple_marked_circle", "\\ufb3c" },
  { "mdi-checkbox_multiple_marked_circle_outline", "\\ufb3d" },
  { "mdi-checkbox_multiple_marked_outline", "\\uf638" },
  { "mdi-checkerboard", "\\uf639" },
  { "mdi-chemical_weapon", "\\uf63a" },
  { "mdi-chevron_double_down", "\\uf63b" },
  { "mdi-chevron_double_left", "\\uf63c" },
  { "mdi-chevron_double_right", "\\uf63d" },
  { "mdi-chevron_double_up", "\\uf63e" },
  { "mdi-chevron_down", "\\uf63f" },
  { "mdi-chevron_left", "\\uf640" },
  { "mdi-chevron_right", "\\uf641" },
  { "mdi-chevron_up", "\\uf642" },
  { "mdi-chili_hot", "\\ufcb0" },
  { "mdi-chili_medium", "\\ufcb1" },
  { "mdi-chili_mild", "\\ufcb2" },
  { "mdi-chip", "\\ufb19" },
  { "mdi-church", "\\uf643" },
  { "mdi-circle", "\\ufc63" },
  { "mdi-circle_outline", "\\ufc64" },
  { "mdi-cisco_webex", "\\uf644" },
  { "mdi-city", "\\uf645" },
  { "mdi-clipboard", "\\uf646" },
  { "mdi-clipboard_account", "\\uf647" },
  { "mdi-clipboard_alert", "\\uf648" },
  { "mdi-clipboard_arrow_down", "\\uf649" },
  { "mdi-clipboard_arrow_left", "\\uf64a" },
  { "mdi-clipboard_check", "\\uf64b" },
  { "mdi-clipboard_flow", "\\ufbc6" },
  { "mdi-clipboard_outline", "\\uf64c" },
  { "mdi-clipboard_plus", "\\ufc4f" },
  { "mdi-clipboard_text", "\\uf64d" },
  { "mdi-clippy", "\\uf64e" },
  { "mdi-clock", "\\uf64f" },
  { "mdi-clock_alert", "\\ufacd" },
  { "mdi-clock_end", "\\uf650" },
  { "mdi-clock_fast", "\\uf651" },
  { "mdi-clock_in", "\\uf652" },
  { "mdi-clock_out", "\\uf653" },
  { "mdi-clock_start", "\\uf654" },
  { "mdi-close", "\\uf655" },
  { "mdi-close_box", "\\uf656" },
  { "mdi-close_box_outline", "\\uf657" },
  { "mdi-close_circle", "\\uf658" },
  { "mdi-close_circle_outline", "\\uf659" },
  { "mdi-close_network", "\\uf65a" },
  { "mdi-close_octagon", "\\uf65b" },
  { "mdi-close_octagon_outline", "\\uf65c" },
  { "mdi-close_outline", "\\ufbc7" },
  { "mdi-closed_caption", "\\uf65d" },
  { "mdi-cloud", "\\uf65e" },
  { "mdi-cloud_braces", "\\ufcb3" },
  { "mdi-cloud_check", "\\uf65f" },
  { "mdi-cloud_circle", "\\uf660" },
  { "mdi-cloud_download", "\\uf661" },
  { "mdi-cloud_off_outline", "\\uf663" },
  { "mdi-cloud_outline", "\\uf662" },
  { "mdi-cloud_print", "\\uf664" },
  { "mdi-cloud_print_outline", "\\uf665" },
  { "mdi-cloud_sync", "\\ufb3e" },
  { "mdi-cloud_tags", "\\ufcb4" },
  { "mdi-cloud_upload", "\\uf666" },
  { "mdi-clover", "\\ufd14" },
  { "mdi-code_array", "\\uf667" },
  { "mdi-code_braces", "\\uf668" },
  { "mdi-code_brackets", "\\uf669" },
  { "mdi-code_equal", "\\uf66a" },
  { "mdi-code_greater_than", "\\uf66b" },
  { "mdi-code_greater_than_or_equal", "\\uf66c" },
  { "mdi-code_less_than", "\\uf66d" },
  { "mdi-code_less_than_or_equal", "\\uf66e" },
  { "mdi-code_not_equal", "\\uf66f" },
  { "mdi-code_not_equal_variant", "\\uf670" },
  { "mdi-code_parentheses", "\\uf671" },
  { "mdi-code_string", "\\uf672" },
  { "mdi-code_tags", "\\uf673" },
  { "mdi-code_tags_check", "\\ufb92" },
  { "mdi-codepen", "\\uf674" },
  { "mdi-coffee", "\\uf675" },
  { "mdi-coffee_outline", "\\ufbc8" },
  { "mdi-coffee_to_go", "\\uf676" },
  { "mdi-coin", "\\uf677" },
  { "mdi-coins", "\\ufb93" },
  { "mdi-collage", "\\ufb3f" },
  { "mdi-color_helper", "\\uf678" },
  { "mdi-comment", "\\uf679" },
  { "mdi-comment_account", "\\uf67a" },
  { "mdi-comment_account_outline", "\\uf67b" },
  { "mdi-comment_alert", "\\uf67c" },
  { "mdi-comment_alert_outline", "\\uf67d" },
  { "mdi-comment_check", "\\uf67e" },
  { "mdi-comment_check_outline", "\\uf67f" },
  { "mdi-comment_multiple_outline", "\\uf680" },
  { "mdi-comment_outline", "\\uf681" },
  { "mdi-comment_plus_outline", "\\uf682" },
  { "mdi-comment_processing", "\\uf683" },
  { "mdi-comment_processing_outline", "\\uf684" },
  { "mdi-comment_question", "\\ufd15" },
  { "mdi-comment_question_outline", "\\uf685" },
  { "mdi-comment_remove", "\\ufadd" },
  { "mdi-comment_remove_outline", "\\uf686" },
  { "mdi-comment_text", "\\uf687" },
  { "mdi-comment_text_outline", "\\uf688" },
  { "mdi-compare", "\\uf689" },
  { "mdi-compass", "\\uf68a" },
  { "mdi-compass_outline", "\\uf68b" },
  { "mdi-console", "\\uf68c" },
  { "mdi-console_line", "\\ufcb5" },
  { "mdi-contact_mail", "\\uf68d" },
  { "mdi-contacts", "\\ufbc9" },
  { "mdi-content_copy", "\\uf68e" },
  { "mdi-content_cut", "\\uf68f" },
  { "mdi-content_duplicate", "\\uf690" },
  { "mdi-content_paste", "\\uf691" },
  { "mdi-content_save", "\\uf692" },
  { "mdi-content_save_all", "\\uf693" },
  { "mdi-content_save_outline", "\\ufd16" },
  { "mdi-content_save_settings", "\\ufb1a" },
  { "mdi-contrast", "\\uf694" },
  { "mdi-contrast_box", "\\uf695" },
  { "mdi-contrast_circle", "\\uf696" },
  { "mdi-cookie", "\\uf697" },
  { "mdi-copyright", "\\ufae5" },
  { "mdi-corn", "\\ufcb6" },
  { "mdi-counter", "\\uf698" },
  { "mdi-cow", "\\uf699" },
  { "mdi-creation", "\\uf6c8" },
  { "mdi-credit_card", "\\uf69a" },
  { "mdi-credit_card_multiple", "\\uf69b" },
  { "mdi-credit_card_off", "\\ufae3" },
  { "mdi-credit_card_plus", "\\ufb74" },
  { "mdi-credit_card_scan", "\\uf69c" },
  { "mdi-crop", "\\uf69d" },
  { "mdi-crop_free", "\\uf69e" },
  { "mdi-crop_landscape", "\\uf69f" },
  { "mdi-crop_portrait", "\\uf6a0" },
  { "mdi-crop_rotate", "\\ufb94" },
  { "mdi-crop_square", "\\uf6a1" },
  { "mdi-crosshairs", "\\uf6a2" },
  { "mdi-crosshairs_gps", "\\uf6a3" },
  { "mdi-crown", "\\uf6a4" },
  { "mdi-cube", "\\uf6a5" },
  { "mdi-cube_outline", "\\uf6a6" },
  { "mdi-cube_send", "\\uf6a7" },
  { "mdi-cube_unfolded", "\\uf6a8" },
  { "mdi-cup", "\\uf6a9" },
  { "mdi-cup_off", "\\ufae4" },
  { "mdi-cup_water", "\\uf6aa" },
  { "mdi-currency_btc", "\\uf6ab" },
  { "mdi-currency_chf", "\\ufcb7" },
  { "mdi-currency_cny", "\\ufcb8" },
  { "mdi-currency_eth", "\\ufcb9" },
  { "mdi-currency_eur", "\\uf6ac" },
  { "mdi-currency_gbp", "\\uf6ad" },
  { "mdi-currency_inr", "\\uf6ae" },
  { "mdi-currency_jpy", "\\ufcba" },
  { "mdi-currency_krw", "\\ufcbb" },
  { "mdi-currency_ngn", "\\uf6af" },
  { "mdi-currency_rub", "\\uf6b0" },
  { "mdi-currency_sign", "\\ufcbc" },
  { "mdi-currency_try", "\\uf6b1" },
  { "mdi-currency_twd", "\\ufcbd" },
  { "mdi-currency_usd", "\\uf6b2" },
  { "mdi-currency_usd_off", "\\ufb78" },
  { "mdi-cursor_default", "\\uf6b3" },
  { "mdi-cursor_default_outline", "\\uf6b4" },
  { "mdi-cursor_move", "\\uf6b5" },
  { "mdi-cursor_pointer", "\\uf6b6" },
  { "mdi-cursor_text", "\\ufae6" },
  { "mdi-database", "\\uf6b7" },
  { "mdi-database_minus", "\\uf6b8" },
  { "mdi-database_plus", "\\uf6b9" },
  { "mdi-debug_step_into", "\\uf6ba" },
  { "mdi-debug_step_out", "\\uf6bb" },
  { "mdi-debug_step_over", "\\uf6bc" },
  { "mdi-decagram", "\\ufc6a" },
  { "mdi-decagram_outline", "\\ufc6b" },
  { "mdi-decimal_decrease", "\\uf6bd" },
  { "mdi-decimal_increase", "\\uf6be" },
  { "mdi-delete", "\\uf6bf" },
  { "mdi-delete_circle", "\\ufb81" },
  { "mdi-delete_empty", "\\ufbca" },
  { "mdi-delete_forever", "\\ufae7" },
  { "mdi-delete_restore", "\\ufd17" },
  { "mdi-delete_sweep", "\\ufae8" },
  { "mdi-delete_variant", "\\uf6c0" },
  { "mdi-delta", "\\uf6c1" },
  { "mdi-deskphone", "\\uf6c2" },
  { "mdi-desktop_classic", "\\ufcbe" },
  { "mdi-desktop_mac", "\\uf6c3" },
  { "mdi-desktop_tower", "\\uf6c4" },
  { "mdi-details", "\\uf6c5" },
  { "mdi-developer_board", "\\ufb95" },
  { "mdi-deviantart", "\\uf6c6" },
  { "mdi-dialpad", "\\ufb1b" },
  { "mdi-diamond", "\\uf6c7" },
  { "mdi-dice_1", "\\uf6c9" },
  { "mdi-dice_2", "\\uf6ca" },
  { "mdi-dice_3", "\\uf6cb" },
  { "mdi-dice_4", "\\uf6cc" },
  { "mdi-dice_5", "\\uf6cd" },
  { "mdi-dice_6", "\\uf6ce" },
  { "mdi-dice_d10", "\\ufc6d" },
  { "mdi-dice_d20", "\\ufae9" },
  { "mdi-dice_d4", "\\ufaea" },
  { "mdi-dice_d6", "\\ufaeb" },
  { "mdi-dice_d8", "\\ufaec" },
  { "mdi-dice_multiple", "\\ufc6c" },
  { "mdi-dictionary", "\\ufb1c" },
  { "mdi-dip_switch", "\\ufcbf" },
  { "mdi-directions", "\\uf6cf" },
  { "mdi-directions_fork", "\\ufb40" },
  { "mdi-discord", "\\ufb6e" },
  { "mdi-disk", "\\ufaed" },
  { "mdi-disk_alert", "\\uf6d0" },
  { "mdi-disqus", "\\uf6d1" },
  { "mdi-disqus_outline", "\\uf6d2" },
  { "mdi-division", "\\uf6d3" },
  { "mdi-division_box", "\\uf6d4" },
  { "mdi-dna", "\\ufb82" },
  { "mdi-dns", "\\uf6d5" },
  { "mdi-do_not_disturb", "\\ufb96" },
  { "mdi-do_not_disturb_off", "\\ufb97" },
  { "mdi-dolby", "\\ufbb1" },
  { "mdi-domain", "\\uf6d6" },
  { "mdi-donkey", "\\ufcc0" },
  { "mdi-door", "\\ufd18" },
  { "mdi-door_closed", "\\ufd19" },
  { "mdi-door_open", "\\ufd1a" },
  { "mdi-dots_horizontal", "\\uf6d7" },
  { "mdi-dots_horizontal_circle", "\\ufcc1" },
  { "mdi-dots_vertical", "\\uf6d8" },
  { "mdi-dots_vertical_circle", "\\ufcc2" },
  { "mdi-douban", "\\ufb98" },
  { "mdi-download", "\\uf6d9" },
  { "mdi-download_network", "\\ufbf2" },
  { "mdi-drag", "\\uf6da" },
  { "mdi-drag_horizontal", "\\uf6db" },
  { "mdi-drag_vertical", "\\uf6dc" },
  { "mdi-drawing", "\\uf6dd" },
  { "mdi-drawing_box", "\\uf6de" },
  { "mdi-dribbble", "\\uf6df" },
  { "mdi-dribbble_box", "\\uf6e0" },
  { "mdi-drone", "\\uf6e1" },
  { "mdi-dropbox", "\\uf6e2" },
  { "mdi-drupal", "\\uf6e3" },
  { "mdi-duck", "\\uf6e4" },
  { "mdi-dumbbell", "\\uf6e5" },
  { "mdi-ear_hearing", "\\ufcc3" },
  { "mdi-earth", "\\uf6e6" },
  { "mdi-earth_box", "\\ufbcb" },
  { "mdi-earth_box_off", "\\ufbcc" },
  { "mdi-earth_off", "\\uf6e7" },
  { "mdi-edge", "\\uf6e8" },
  { "mdi-eject", "\\uf6e9" },
  { "mdi-elephant", "\\ufcc4" },
  { "mdi-elevation_decline", "\\uf6ea" },
  { "mdi-elevation_rise", "\\uf6eb" },
  { "mdi-elevator", "\\uf6ec" },
  { "mdi-email", "\\uf6ed" },
  { "mdi-email_alert", "\\ufbcd" },
  { "mdi-email_open", "\\uf6ee" },
  { "mdi-email_open_outline", "\\ufaee" },
  { "mdi-email_outline", "\\uf6ef" },
  { "mdi-email_secure", "\\uf6f0" },
  { "mdi-email_variant", "\\ufaef" },
  { "mdi-emby", "\\ufbb2" },
  { "mdi-emoticon", "\\uf6f1" },
  { "mdi-emoticon_cool", "\\uf6f2" },
  { "mdi-emoticon_dead", "\\ufb99" },
  { "mdi-emoticon_devil", "\\uf6f3" },
  { "mdi-emoticon_excited", "\\ufb9a" },
  { "mdi-emoticon_happy", "\\uf6f4" },
  { "mdi-emoticon_neutral", "\\uf6f5" },
  { "mdi-emoticon_poop", "\\uf6f6" },
  { "mdi-emoticon_sad", "\\uf6f7" },
  { "mdi-emoticon_tongue", "\\uf6f8" },
  { "mdi-engine", "\\uf6f9" },
  { "mdi-engine_outline", "\\uf6fa" },
  { "mdi-equal", "\\uf6fb" },
  { "mdi-equal_box", "\\uf6fc" },
  { "mdi-eraser", "\\uf6fd" },
  { "mdi-eraser_variant", "\\ufb41" },
  { "mdi-escalator", "\\uf6fe" },
  { "mdi-ethernet", "\\uf6ff" },
  { "mdi-ethernet_cable", "\\uf700" },
  { "mdi-ethernet_cable_off", "\\uf701" },
  { "mdi-etsy", "\\uf702" },
  { "mdi-ev_station", "\\ufaf0" },
  { "mdi-eventbrite", "\\ufcc5" },
  { "mdi-evernote", "\\uf703" },
  { "mdi-exclamation", "\\uf704" },
  { "mdi-exit_to_app", "\\uf705" },
  { "mdi-export", "\\uf706" },
  { "mdi-eye", "\\uf707" },
  { "mdi-eye_off", "\\uf708" },
  { "mdi-eye_off_outline", "\\ufbcf" },
  { "mdi-eye_outline", "\\ufbce" },
  { "mdi-eyedropper", "\\uf709" },
  { "mdi-eyedropper_variant", "\\uf70a" },
  { "mdi-face", "\\ufb42" },
  { "mdi-face_profile", "\\ufb43" },
  { "mdi-facebook", "\\uf70b" },
  { "mdi-facebook_box", "\\uf70c" },
  { "mdi-facebook_messenger", "\\uf70d" },
  { "mdi-factory", "\\uf70e" },
  { "mdi-fan", "\\uf70f" },
  { "mdi-fan_off", "\\ufd1b" },
  { "mdi-fast_forward", "\\uf710" },
  { "mdi-fast_forward_outline", "\\ufbd0" },
  { "mdi-fax", "\\uf711" },
  { "mdi-feather", "\\ufbd1" },
  { "mdi-ferry", "\\uf712" },
  { "mdi-file", "\\uf713" },
  { "mdi-file_account", "\\ufc39" },
  { "mdi-file_chart", "\\uf714" },
  { "mdi-file_check", "\\uf715" },
  { "mdi-file_cloud", "\\uf716" },
  { "mdi-file_delimited", "\\uf717" },
  { "mdi-file_document", "\\uf718" },
  { "mdi-file_document_box", "\\uf719" },
  { "mdi-file_excel", "\\uf71a" },
  { "mdi-file_excel_box", "\\uf71b" },
  { "mdi-file_export", "\\uf71c" },
  { "mdi-file_find", "\\uf71d" },
  { "mdi-file_hidden", "\\ufb12" },
  { "mdi-file_image", "\\uf71e" },
  { "mdi-file_import", "\\uf71f" },
  { "mdi-file_lock", "\\uf720" },
  { "mdi-file_multiple", "\\uf721" },
  { "mdi-file_music", "\\uf722" },
  { "mdi-file_outline", "\\uf723" },
  { "mdi-file_pdf", "\\uf724" },
  { "mdi-file_pdf_box", "\\uf725" },
  { "mdi-file_percent", "\\ufd1c" },
  { "mdi-file_plus", "\\ufc50" },
  { "mdi-file_powerpoint", "\\uf726" },
  { "mdi-file_powerpoint_box", "\\uf727" },
  { "mdi-file_presentation_box", "\\uf728" },
  { "mdi-file_restore", "\\ufb6f" },
  { "mdi-file_send", "\\uf729" },
  { "mdi-file_tree", "\\ufb44" },
  { "mdi-file_video", "\\uf72a" },
  { "mdi-file_word", "\\uf72b" },
  { "mdi-file_word_box", "\\uf72c" },
  { "mdi-file_xml", "\\uf72d" },
  { "mdi-film", "\\uf72e" },
  { "mdi-filmstrip", "\\uf72f" },
  { "mdi-filmstrip_off", "\\uf730" },
  { "mdi-filter", "\\uf731" },
  { "mdi-filter_outline", "\\uf732" },
  { "mdi-filter_remove", "\\uf733" },
  { "mdi-filter_remove_outline", "\\uf734" },
  { "mdi-filter_variant", "\\uf735" },
  { "mdi-finance", "\\ufd1d" },
  { "mdi-find_replace", "\\ufbd2" },
  { "mdi-fingerprint", "\\uf736" },
  { "mdi-fire", "\\uf737" },
  { "mdi-firefox", "\\uf738" },
  { "mdi-fish", "\\uf739" },
  { "mdi-flag", "\\uf73a" },
  { "mdi-flag_checkered", "\\uf73b" },
  { "mdi-flag_outline", "\\uf73c" },
  { "mdi-flag_triangle", "\\uf73e" },
  { "mdi-flag_variant", "\\uf73f" },
  { "mdi-flag_variant_outline", "\\uf73d" },
  { "mdi-flash", "\\uf740" },
  { "mdi-flash_auto", "\\uf741" },
  { "mdi-flash_circle", "\\ufd1e" },
  { "mdi-flash_off", "\\uf742" },
  { "mdi-flash_outline", "\\ufbd3" },
  { "mdi-flash_red_eye", "\\ufb79" },
  { "mdi-flashlight", "\\uf743" },
  { "mdi-flashlight_off", "\\uf744" },
  { "mdi-flask", "\\uf592" },
  { "mdi-flask_empty", "\\uf593" },
  { "mdi-flask_empty_outline", "\\uf594" },
  { "mdi-flask_outline", "\\uf595" },
  { "mdi-flattr", "\\uf745" },
  { "mdi-flip_to_back", "\\uf746" },
  { "mdi-flip_to_front", "\\uf747" },
  { "mdi-floor_plan", "\\ufd1f" },
  { "mdi-floppy", "\\uf748" },
  { "mdi-flower", "\\uf749" },
  { "mdi-folder", "\\uf74a" },
  { "mdi-folder_account", "\\uf74b" },
  { "mdi-folder_download", "\\uf74c" },
  { "mdi-folder_google_drive", "\\uf74d" },
  { "mdi-folder_image", "\\uf74e" },
  { "mdi-folder_lock", "\\uf74f" },
  { "mdi-folder_lock_open", "\\uf750" },
  { "mdi-folder_move", "\\uf751" },
  { "mdi-folder_multiple", "\\uf752" },
  { "mdi-folder_multiple_image", "\\uf753" },
  { "mdi-folder_multiple_outline", "\\uf754" },
  { "mdi-folder_open", "\\ufc6e" },
  { "mdi-folder_outline", "\\uf755" },
  { "mdi-folder_plus", "\\uf756" },
  { "mdi-folder_remove", "\\uf757" },
  { "mdi-folder_star", "\\ufb9b" },
  { "mdi-folder_upload", "\\uf758" },
  { "mdi-font_awesome", "\\uf539" },
  { "mdi-food", "\\uf759" },
  { "mdi-food_apple", "\\uf75a" },
  { "mdi-food_croissant", "\\ufcc6" },
  { "mdi-food_fork_drink", "\\ufaf1" },
  { "mdi-food_off", "\\ufaf2" },
  { "mdi-food_variant", "\\uf75b" },
  { "mdi-football", "\\uf75c" },
  { "mdi-football_australian", "\\uf75d" },
  { "mdi-football_helmet", "\\uf75e" },
  { "mdi-forklift", "\\ufcc7" },
  { "mdi-format_align_bottom", "\\ufc51" },
  { "mdi-format_align_center", "\\uf75f" },
  { "mdi-format_align_justify", "\\uf760" },
  { "mdi-format_align_left", "\\uf761" },
  { "mdi-format_align_middle", "\\ufc52" },
  { "mdi-format_align_right", "\\uf762" },
  { "mdi-format_align_top", "\\ufc53" },
  { "mdi-format_annotation_plus", "\\ufb45" },
  { "mdi-format_bold", "\\uf763" },
  { "mdi-format_clear", "\\uf764" },
  { "mdi-format_color_fill", "\\uf765" },
  { "mdi-format_color_text", "\\ufb9c" },
  { "mdi-format_float_center", "\\uf766" },
  { "mdi-format_float_left", "\\uf767" },
  { "mdi-format_float_none", "\\uf768" },
  { "mdi-format_float_right", "\\uf769" },
  { "mdi-format_font", "\\ufbd4" },
  { "mdi-format_header_1", "\\uf76a" },
  { "mdi-format_header_2", "\\uf76b" },
  { "mdi-format_header_3", "\\uf76c" },
  { "mdi-format_header_4", "\\uf76d" },
  { "mdi-format_header_5", "\\uf76e" },
  { "mdi-format_header_6", "\\uf76f" },
  { "mdi-format_header_decrease", "\\uf770" },
  { "mdi-format_header_equal", "\\uf771" },
  { "mdi-format_header_increase", "\\uf772" },
  { "mdi-format_header_pound", "\\uf773" },
  { "mdi-format_horizontal_align_center", "\\ufb1d" },
  { "mdi-format_horizontal_align_left", "\\ufb1e" },
  { "mdi-format_horizontal_align_right", "\\ufb1f" },
  { "mdi-format_indent_decrease", "\\uf774" },
  { "mdi-format_indent_increase", "\\uf775" },
  { "mdi-format_italic", "\\uf776" },
  { "mdi-format_line_spacing", "\\uf777" },
  { "mdi-format_line_style", "\\ufac7" },
  { "mdi-format_line_weight", "\\ufac8" },
  { "mdi-format_list_bulleted", "\\uf778" },
  { "mdi-format_list_bulleted_type", "\\uf779" },
  { "mdi-format_list_checks", "\\ufc54" },
  { "mdi-format_list_numbers", "\\uf77a" },
  { "mdi-format_page_break", "\\ufbd5" },
  { "mdi-format_paint", "\\uf77b" },
  { "mdi-format_paragraph", "\\uf77c" },
  { "mdi-format_pilcrow", "\\ufbd6" },
  { "mdi-format_quote_close", "\\uf77d" },
  { "mdi-format_quote_open", "\\ufc55" },
  { "mdi-format_rotate_90", "\\ufba8" },
  { "mdi-format_section", "\\ufb9d" },
  { "mdi-format_size", "\\uf77e" },
  { "mdi-format_strikethrough", "\\uf77f" },
  { "mdi-format_strikethrough_variant", "\\uf780" },
  { "mdi-format_subscript", "\\uf781" },
  { "mdi-format_superscript", "\\uf782" },
  { "mdi-format_text", "\\uf783" },
  { "mdi-format_textdirection_l_to_r", "\\uf784" },
  { "mdi-format_textdirection_r_to_l", "\\uf785" },
  { "mdi-format_title", "\\ufaf3" },
  { "mdi-format_underline", "\\uf786" },
  { "mdi-format_vertical_align_bottom", "\\ufb20" },
  { "mdi-format_vertical_align_center", "\\ufb21" },
  { "mdi-format_vertical_align_top", "\\ufb22" },
  { "mdi-format_wrap_inline", "\\uf787" },
  { "mdi-format_wrap_square", "\\uf788" },
  { "mdi-format_wrap_tight", "\\uf789" },
  { "mdi-format_wrap_top_bottom", "\\uf78a" },
  { "mdi-forum", "\\uf78b" },
  { "mdi-forum_outline", "\\ufd20" },
  { "mdi-forward", "\\uf78c" },
  { "mdi-foursquare", "\\uf78d" },
  { "mdi-fridge", "\\uf78e" },
  { "mdi-fridge_filled", "\\uf78f" },
  { "mdi-fridge_filled_bottom", "\\uf790" },
  { "mdi-fridge_filled_top", "\\uf791" },
  { "mdi-fuel", "\\ufcc8" },
  { "mdi-fullscreen", "\\uf792" },
  { "mdi-fullscreen_exit", "\\uf793" },
  { "mdi-function", "\\uf794" },
  { "mdi-gamepad", "\\uf795" },
  { "mdi-gamepad_variant", "\\uf796" },
  { "mdi-garage", "\\ufbd7" },
  { "mdi-garage_open", "\\ufbd8" },
  { "mdi-gas_cylinder", "\\ufb46" },
  { "mdi-gas_station", "\\uf797" },
  { "mdi-gate", "\\uf798" },
  { "mdi-gauge", "\\uf799" },
  { "mdi-gavel", "\\uf79a" },
  { "mdi-gender_female", "\\uf79b" },
  { "mdi-gender_male", "\\uf79c" },
  { "mdi-gender_male_female", "\\uf79d" },
  { "mdi-gender_transgender", "\\uf79e" },
  { "mdi-gesture", "\\ufcc9" },
  { "mdi-gesture_double_tap", "\\ufc3a" },
  { "mdi-gesture_swipe_down", "\\ufc3b" },
  { "mdi-gesture_swipe_left", "\\ufc3c" },
  { "mdi-gesture_swipe_right", "\\ufc3d" },
  { "mdi-gesture_swipe_up", "\\ufc3e" },
  { "mdi-gesture_tap", "\\ufc3f" },
  { "mdi-gesture_two_double_tap", "\\ufc40" },
  { "mdi-gesture_two_tap", "\\ufc41" },
  { "mdi-ghost", "\\uf79f" },
  { "mdi-gift", "\\uf7a0" },
  { "mdi-git", "\\uf7a1" },
  { "mdi-github_box", "\\uf7a2" },
  { "mdi-github_circle", "\\uf7a3" },
  { "mdi-github_face", "\\ufbd9" },
  { "mdi-glass_flute", "\\uf7a4" },
  { "mdi-glass_mug", "\\uf7a5" },
  { "mdi-glass_stange", "\\uf7a6" },
  { "mdi-glass_tulip", "\\uf7a7" },
  { "mdi-glassdoor", "\\uf7a8" },
  { "mdi-glasses", "\\uf7a9" },
  { "mdi-gmail", "\\uf7aa" },
  { "mdi-gnome", "\\uf7ab" },
  { "mdi-golf", "\\ufd21" },
  { "mdi-gondola", "\\ufb84" },
  { "mdi-google", "\\uf7ac" },
  { "mdi-google_analytics", "\\ufcca" },
  { "mdi-google_assistant", "\\ufccb" },
  { "mdi-google_cardboard", "\\uf7ad" },
  { "mdi-google_chrome", "\\uf7ae" },
  { "mdi-google_circles", "\\uf7af" },
  { "mdi-google_circles_communities", "\\uf7b0" },
  { "mdi-google_circles_extended", "\\uf7b1" },
  { "mdi-google_circles_group", "\\uf7b2" },
  { "mdi-google_controller", "\\uf7b3" },
  { "mdi-google_controller_off", "\\uf7b4" },
  { "mdi-google_drive", "\\uf7b5" },
  { "mdi-google_earth", "\\uf7b6" },
  { "mdi-google_glass", "\\uf7b7" },
  { "mdi-google_home", "\\ufd22" },
  { "mdi-google_keep", "\\ufbda" },
  { "mdi-google_maps", "\\ufaf4" },
  { "mdi-google_nearby", "\\uf7b8" },
  { "mdi-google_pages", "\\uf7b9" },
  { "mdi-google_photos", "\\ufbdb" },
  { "mdi-google_physical_web", "\\uf7ba" },
  { "mdi-google_play", "\\uf7bb" },
  { "mdi-google_plus", "\\uf7bc" },
  { "mdi-google_plus_box", "\\uf7bd" },
  { "mdi-google_translate", "\\uf7be" },
  { "mdi-google_wallet", "\\uf7bf" },
  { "mdi-gradient", "\\ufb9e" },
  { "mdi-grease_pencil", "\\ufb47" },
  { "mdi-grid", "\\uf7c0" },
  { "mdi-grid_large", "\\ufc56" },
  { "mdi-grid_off", "\\uf7c1" },
  { "mdi-group", "\\uf7c2" },
  { "mdi-guitar_acoustic", "\\ufc6f" },
  { "mdi-guitar_electric", "\\uf7c3" },
  { "mdi-guitar_pick", "\\uf7c4" },
  { "mdi-guitar_pick_outline", "\\uf7c5" },
  { "mdi-guy_fawkes_mask", "\\ufd23" },
  { "mdi-hackernews", "\\ufb23" },
  { "mdi-hamburger", "\\ufb83" },
  { "mdi-hand_pointing_right", "\\uf7c6" },
  { "mdi-hanger", "\\uf7c7" },
  { "mdi-hangouts", "\\uf7c8" },
  { "mdi-harddisk", "\\uf7c9" },
  { "mdi-headphones", "\\uf7ca" },
  { "mdi-headphones_box", "\\uf7cb" },
  { "mdi-headphones_off", "\\ufccc" },
  { "mdi-headphones_settings", "\\uf7cc" },
  { "mdi-headset", "\\uf7cd" },
  { "mdi-headset_dock", "\\uf7ce" },
  { "mdi-headset_off", "\\uf7cf" },
  { "mdi-heart", "\\uf7d0" },
  { "mdi-heart_box", "\\uf7d1" },
  { "mdi-heart_box_outline", "\\uf7d2" },
  { "mdi-heart_broken", "\\uf7d3" },
  { "mdi-heart_half", "\\ufbdd" },
  { "mdi-heart_half_full", "\\ufbdc" },
  { "mdi-heart_half_outline", "\\ufbde" },
  { "mdi-heart_off", "\\ufc57" },
  { "mdi-heart_outline", "\\uf7d4" },
  { "mdi-heart_pulse", "\\ufaf5" },
  { "mdi-help", "\\uf7d5" },
  { "mdi-help_box", "\\ufc89" },
  { "mdi-help_circle", "\\uf7d6" },
  { "mdi-help_circle_outline", "\\ufb24" },
  { "mdi-help_network", "\\ufbf3" },
  { "mdi-hexagon", "\\uf7d7" },
  { "mdi-hexagon_multiple", "\\ufbdf" },
  { "mdi-hexagon_outline", "\\uf7d8" },
  { "mdi-high_definition", "\\ufccd" },
  { "mdi-highway", "\\ufaf6" },
  { "mdi-history", "\\uf7d9" },
  { "mdi-hololens", "\\uf7da" },
  { "mdi-home", "\\uf7db" },
  { "mdi-home_account", "\\ufd24" },
  { "mdi-home_assistant", "\\ufcce" },
  { "mdi-home_automation", "\\ufccf" },
  { "mdi-home_circle", "\\ufcd0" },
  { "mdi-home_heart", "\\ufd25" },
  { "mdi-home_map_marker", "\\ufaf7" },
  { "mdi-home_modern", "\\uf7dc" },
  { "mdi-home_outline", "\\ufb9f" },
  { "mdi-home_variant", "\\uf7dd" },
  { "mdi-hook", "\\ufbe0" },
  { "mdi-hook_off", "\\ufbe1" },
  { "mdi-hops", "\\uf7de" },
  { "mdi-hospital", "\\uf7df" },
  { "mdi-hospital_building", "\\uf7e0" },
  { "mdi-hospital_marker", "\\uf7e1" },
  { "mdi-hot_tub", "\\ufd26" },
  { "mdi-hotel", "\\uf7e2" },
  { "mdi-houzz", "\\uf7e3" },
  { "mdi-houzz_box", "\\uf7e4" },
  { "mdi-hulu", "\\ufd27" },
  { "mdi-human", "\\uf7e5" },
  { "mdi-human_child", "\\uf7e6" },
  { "mdi-human_female", "\\ufb48" },
  { "mdi-human_greeting", "\\ufb49" },
  { "mdi-human_handsdown", "\\ufb4a" },
  { "mdi-human_handsup", "\\ufb4b" },
  { "mdi-human_male", "\\ufb4c" },
  { "mdi-human_male_female", "\\uf7e7" },
  { "mdi-human_pregnant", "\\uface" },
  { "mdi-humble_bundle", "\\ufc42" },
  { "mdi-ice_cream", "\\ufd28" },
  { "mdi-image", "\\uf7e8" },
  { "mdi-image_album", "\\uf7e9" },
  { "mdi-image_area", "\\uf7ea" },
  { "mdi-image_area_close", "\\uf7eb" },
  { "mdi-image_broken", "\\uf7ec" },
  { "mdi-image_broken_variant", "\\uf7ed" },
  { "mdi-image_filter", "\\uf7ee" },
  { "mdi-image_filter_black_white", "\\uf7ef" },
  { "mdi-image_filter_center_focus", "\\uf7f0" },
  { "mdi-image_filter_center_focus_weak", "\\uf7f1" },
  { "mdi-image_filter_drama", "\\uf7f2" },
  { "mdi-image_filter_frames", "\\uf7f3" },
  { "mdi-image_filter_hdr", "\\uf7f4" },
  { "mdi-image_filter_none", "\\uf7f5" },
  { "mdi-image_filter_tilt_shift", "\\uf7f6" },
  { "mdi-image_filter_vintage", "\\uf7f7" },
  { "mdi-image_multiple", "\\uf7f8" },
  { "mdi-image_off", "\\ufd29" },
  { "mdi-import", "\\uf7f9" },
  { "mdi-inbox", "\\ufb85" },
  { "mdi-inbox_arrow_down", "\\uf7fa" },
  { "mdi-inbox_arrow_up", "\\uf8d0" },
  { "mdi-incognito", "\\ufaf8" },
  { "mdi-infinity", "\\ufbe2" },
  { "mdi-information", "\\uf7fb" },
  { "mdi-information_outline", "\\uf7fc" },
  { "mdi-information_variant", "\\ufb4d" },
  { "mdi-instagram", "\\uf7fd" },
  { "mdi-instapaper", "\\uf7fe" },
  { "mdi-internet_explorer", "\\uf7ff" },
  { "mdi-invert_colors", "\\uf800" },
  { "mdi-itunes", "\\ufb75" },
  { "mdi-jeepney", "\\uf801" },
  { "mdi-jira", "\\uf802" },
  { "mdi-jsfiddle", "\\uf803" },
  { "mdi-json", "\\ufb25" },
  { "mdi-karate", "\\ufd2a" },
  { "mdi-keg", "\\uf804" },
  { "mdi-kettle", "\\ufaf9" },
  { "mdi-key", "\\uf805" },
  { "mdi-key_change", "\\uf806" },
  { "mdi-key_minus", "\\uf807" },
  { "mdi-key_plus", "\\uf808" },
  { "mdi-key_remove", "\\uf809" },
  { "mdi-key_variant", "\\uf80a" },
  { "mdi-keyboard", "\\uf80b" },
  { "mdi-keyboard_backspace", "\\uf80c" },
  { "mdi-keyboard_caps", "\\uf80d" },
  { "mdi-keyboard_close", "\\uf80e" },
  { "mdi-keyboard_off", "\\uf80f" },
  { "mdi-keyboard_return", "\\uf810" },
  { "mdi-keyboard_tab", "\\uf811" },
  { "mdi-keyboard_variant", "\\uf812" },
  { "mdi-kickstarter", "\\ufc43" },
  { "mdi-kodi", "\\uf813" },
  { "mdi-label", "\\uf814" },
  { "mdi-label_outline", "\\uf815" },
  { "mdi-ladybug", "\\ufd2b" },
  { "mdi-lambda", "\\ufb26" },
  { "mdi-lamp", "\\ufbb3" },
  { "mdi-lan", "\\uf816" },
  { "mdi-lan_connect", "\\uf817" },
  { "mdi-lan_disconnect", "\\uf818" },
  { "mdi-lan_pending", "\\uf819" },
  { "mdi-language_c", "\\ufb70" },
  { "mdi-language_cpp", "\\ufb71" },
  { "mdi-language_csharp", "\\uf81a" },
  { "mdi-language_css3", "\\uf81b" },
  { "mdi-language_go", "\\ufcd1" },
  { "mdi-language_html5", "\\uf81c" },
  { "mdi-language_javascript", "\\uf81d" },
  { "mdi-language_php", "\\uf81e" },
  { "mdi-language_python", "\\uf81f" },
  { "mdi-language_python_text", "\\uf820" },
  { "mdi-language_r", "\\ufcd2" },
  { "mdi-language_swift", "\\ufbe3" },
  { "mdi-language_typescript", "\\ufbe4" },
  { "mdi-laptop", "\\uf821" },
  { "mdi-laptop_chromebook", "\\uf822" },
  { "mdi-laptop_mac", "\\uf823" },
  { "mdi-laptop_off", "\\ufbe5" },
  { "mdi-laptop_windows", "\\uf824" },
  { "mdi-lastfm", "\\uf825" },
  { "mdi-lastpass", "\\uf945" },
  { "mdi-launch", "\\uf826" },
  { "mdi-lava_lamp", "\\ufcd3" },
  { "mdi-layers", "\\uf827" },
  { "mdi-layers_off", "\\uf828" },
  { "mdi-lead_pencil", "\\ufb4e" },
  { "mdi-leaf", "\\uf829" },
  { "mdi-led_off", "\\uf82a" },
  { "mdi-led_on", "\\uf82b" },
  { "mdi-led_outline", "\\uf82c" },
  { "mdi-led_strip", "\\ufcd4" },
  { "mdi-led_variant_off", "\\uf82d" },
  { "mdi-led_variant_on", "\\uf82e" },
  { "mdi-led_variant_outline", "\\uf82f" },
  { "mdi-library", "\\uf830" },
  { "mdi-library_books", "\\uf831" },
  { "mdi-library_music", "\\uf832" },
  { "mdi-library_plus", "\\uf833" },
  { "mdi-lightbulb", "\\uf834" },
  { "mdi-lightbulb_on", "\\ufbe6" },
  { "mdi-lightbulb_on_outline", "\\ufbe7" },
  { "mdi-lightbulb_outline", "\\uf835" },
  { "mdi-link", "\\uf836" },
  { "mdi-link_off", "\\uf837" },
  { "mdi-link_variant", "\\uf838" },
  { "mdi-link_variant_off", "\\uf839" },
  { "mdi-linkedin", "\\uf83a" },
  { "mdi-linkedin_box", "\\uf83b" },
  { "mdi-linux", "\\uf83c" },
  { "mdi-loading", "\\ufc70" },
  { "mdi-lock", "\\uf83d" },
  { "mdi-lock_open", "\\uf83e" },
  { "mdi-lock_open_outline", "\\uf83f" },
  { "mdi-lock_outline", "\\uf840" },
  { "mdi-lock_pattern", "\\ufbe8" },
  { "mdi-lock_plus", "\\ufafa" },
  { "mdi-lock_reset", "\\ufc71" },
  { "mdi-locker", "\\ufcd5" },
  { "mdi-locker_multiple", "\\ufcd6" },
  { "mdi-login", "\\uf841" },
  { "mdi-login_variant", "\\ufafb" },
  { "mdi-logout", "\\uf842" },
  { "mdi-logout_variant", "\\ufafc" },
  { "mdi-looks", "\\uf843" },
  { "mdi-loop", "\\ufbe9" },
  { "mdi-loupe", "\\uf844" },
  { "mdi-lumx", "\\uf845" },
  { "mdi-magnet", "\\uf846" },
  { "mdi-magnet_on", "\\uf847" },
  { "mdi-magnify", "\\uf848" },
  { "mdi-magnify_minus", "\\uf849" },
  { "mdi-magnify_minus_outline", "\\ufbea" },
  { "mdi-magnify_plus", "\\uf84a" },
  { "mdi-magnify_plus_outline", "\\ufbeb" },
  { "mdi-mail_ru", "\\uf84b" },
  { "mdi-mailbox", "\\ufbec" },
  { "mdi-map", "\\uf84c" },
  { "mdi-map_marker", "\\uf84d" },
  { "mdi-map_marker_circle", "\\uf84e" },
  { "mdi-map_marker_minus", "\\ufb4f" },
  { "mdi-map_marker_multiple", "\\uf84f" },
  { "mdi-map_marker_off", "\\uf850" },
  { "mdi-map_marker_outline", "\\ufcd7" },
  { "mdi-map_marker_plus", "\\ufb50" },
  { "mdi-map_marker_radius", "\\uf851" },
  { "mdi-margin", "\\uf852" },
  { "mdi-markdown", "\\uf853" },
  { "mdi-marker", "\\ufb51" },
  { "mdi-marker_check", "\\uf854" },
  { "mdi-martini", "\\uf855" },
  { "mdi-material_ui", "\\uf856" },
  { "mdi-math_compass", "\\uf857" },
  { "mdi-matrix", "\\ufb27" },
  { "mdi-maxcdn", "\\uf858" },
  { "mdi-medical_bag", "\\ufbed" },
  { "mdi-medium", "\\uf859" },
  { "mdi-memory", "\\uf85a" },
  { "mdi-menu", "\\uf85b" },
  { "mdi-menu_down", "\\uf85c" },
  { "mdi-menu_down_outline", "\\ufbb4" },
  { "mdi-menu_left", "\\uf85d" },
  { "mdi-menu_right", "\\uf85e" },
  { "mdi-menu_up", "\\uf85f" },
  { "mdi-menu_up_outline", "\\ufbb5" },
  { "mdi-message", "\\uf860" },
  { "mdi-message_alert", "\\uf861" },
  { "mdi-message_bulleted", "\\ufba0" },
  { "mdi-message_bulleted_off", "\\ufba1" },
  { "mdi-message_draw", "\\uf862" },
  { "mdi-message_image", "\\uf863" },
  { "mdi-message_outline", "\\uf864" },
  { "mdi-message_plus", "\\ufb52" },
  { "mdi-message_processing", "\\uf865" },
  { "mdi-message_reply", "\\uf866" },
  { "mdi-message_reply_text", "\\uf867" },
  { "mdi-message_settings", "\\ufbee" },
  { "mdi-message_settings_variant", "\\ufbef" },
  { "mdi-message_text", "\\uf868" },
  { "mdi-message_text_outline", "\\uf869" },
  { "mdi-message_video", "\\uf86a" },
  { "mdi-meteor", "\\ufb28" },
  { "mdi-metronome", "\\ufcd8" },
  { "mdi-metronome_tick", "\\ufcd9" },
  { "mdi-micro_sd", "\\ufcda" },
  { "mdi-microphone", "\\uf86b" },
  { "mdi-microphone_off", "\\uf86c" },
  { "mdi-microphone_outline", "\\uf86d" },
  { "mdi-microphone_settings", "\\uf86e" },
  { "mdi-microphone_variant", "\\uf86f" },
  { "mdi-microphone_variant_off", "\\uf870" },
  { "mdi-microscope", "\\ufb53" },
  { "mdi-microsoft", "\\uf871" },
  { "mdi-minecraft", "\\uf872" },
  { "mdi-minus", "\\uf873" },
  { "mdi-minus_box", "\\uf874" },
  { "mdi-minus_box_outline", "\\ufbf0" },
  { "mdi-minus_circle", "\\uf875" },
  { "mdi-minus_circle_outline", "\\uf876" },
  { "mdi-minus_network", "\\uf877" },
  { "mdi-mixcloud", "\\ufb29" },
  { "mdi-mixer", "\\ufcdb" },
  { "mdi-monitor", "\\uf878" },
  { "mdi-monitor_multiple", "\\uf879" },
  { "mdi-more", "\\uf87a" },
  { "mdi-motorbike", "\\uf87b" },
  { "mdi-mouse", "\\uf87c" },
  { "mdi-mouse_off", "\\uf87d" },
  { "mdi-mouse_variant", "\\uf87e" },
  { "mdi-mouse_variant_off", "\\uf87f" },
  { "mdi-move_resize", "\\ufb54" },
  { "mdi-move_resize_variant", "\\ufb55" },
  { "mdi-movie", "\\uf880" },
  { "mdi-movie_roll", "\\ufcdc" },
  { "mdi-multiplication", "\\uf881" },
  { "mdi-multiplication_box", "\\uf882" },
  { "mdi-mushroom", "\\ufcdd" },
  { "mdi-mushroom_outline", "\\ufcde" },
  { "mdi-music", "\\ufc58" },
  { "mdi-music_box", "\\uf883" },
  { "mdi-music_box_outline", "\\uf884" },
  { "mdi-music_circle", "\\uf885" },
  { "mdi-music_note", "\\uf886" },
  { "mdi-music_note_bluetooth", "\\ufafd" },
  { "mdi-music_note_bluetooth_off", "\\ufafe" },
  { "mdi-music_note_eighth", "\\uf887" },
  { "mdi-music_note_half", "\\uf888" },
  { "mdi-music_note_off", "\\uf889" },
  { "mdi-music_note_quarter", "\\uf88a" },
  { "mdi-music_note_sixteenth", "\\uf88b" },
  { "mdi-music_note_whole", "\\uf88c" },
  { "mdi-music_off", "\\ufc59" },
  { "mdi-nature", "\\uf88d" },
  { "mdi-nature_people", "\\uf88e" },
  { "mdi-navigation", "\\uf88f" },
  { "mdi-near_me", "\\ufacc" },
  { "mdi-needle", "\\uf890" },
  { "mdi-nest_protect", "\\uf891" },
  { "mdi-nest_thermostat", "\\uf892" },
  { "mdi-netflix", "\\ufc44" },
  { "mdi-network", "\\ufbf1" },
  { "mdi-new_box", "\\uf893" },
  { "mdi-newspaper", "\\uf894" },
  { "mdi-nfc", "\\uf895" },
  { "mdi-nfc_tap", "\\uf896" },
  { "mdi-nfc_variant", "\\uf897" },
  { "mdi-ninja", "\\ufc72" },
  { "mdi-nintendo_switch", "\\ufcdf" },
  { "mdi-nodejs", "\\uf898" },
  { "mdi-note", "\\uf899" },
  { "mdi-note_multiple", "\\ufbb6" },
  { "mdi-note_multiple_outline", "\\ufbb7" },
  { "mdi-note_outline", "\\uf89a" },
  { "mdi-note_plus", "\\uf89b" },
  { "mdi-note_plus_outline", "\\uf89c" },
  { "mdi-note_text", "\\uf89d" },
  { "mdi-notebook", "\\ufd2c" },
  { "mdi-notification_clear_all", "\\uf89e" },
  { "mdi-npm", "\\ufbf5" },
  { "mdi-nuke", "\\ufba2" },
  { "mdi-null", "\\ufce0" },
  { "mdi-numeric", "\\uf89f" },
  { "mdi-numeric_0_box", "\\uf8a0" },
  { "mdi-numeric_0_box_multiple_outline", "\\uf8a1" },
  { "mdi-numeric_0_box_outline", "\\uf8a2" },
  { "mdi-numeric_1_box", "\\uf8a3" },
  { "mdi-numeric_1_box_multiple_outline", "\\uf8a4" },
  { "mdi-numeric_1_box_outline", "\\uf8a5" },
  { "mdi-numeric_2_box", "\\uf8a6" },
  { "mdi-numeric_2_box_multiple_outline", "\\uf8a7" },
  { "mdi-numeric_2_box_outline", "\\uf8a8" },
  { "mdi-numeric_3_box", "\\uf8a9" },
  { "mdi-numeric_3_box_multiple_outline", "\\uf8aa" },
  { "mdi-numeric_3_box_outline", "\\uf8ab" },
  { "mdi-numeric_4_box", "\\uf8ac" },
  { "mdi-numeric_4_box_multiple_outline", "\\uf8ad" },
  { "mdi-numeric_4_box_outline", "\\uf8ae" },
  { "mdi-numeric_5_box", "\\uf8af" },
  { "mdi-numeric_5_box_multiple_outline", "\\uf8b0" },
  { "mdi-numeric_5_box_outline", "\\uf8b1" },
  { "mdi-numeric_6_box", "\\uf8b2" },
  { "mdi-numeric_6_box_multiple_outline", "\\uf8b3" },
  { "mdi-numeric_6_box_outline", "\\uf8b4" },
  { "mdi-numeric_7_box", "\\uf8b5" },
  { "mdi-numeric_7_box_multiple_outline", "\\uf8b6" },
  { "mdi-numeric_7_box_outline", "\\uf8b7" },
  { "mdi-numeric_8_box", "\\uf8b8" },
  { "mdi-numeric_8_box_multiple_outline", "\\uf8b9" },
  { "mdi-numeric_8_box_outline", "\\uf8ba" },
  { "mdi-numeric_9_box", "\\uf8bb" },
  { "mdi-numeric_9_box_multiple_outline", "\\uf8bc" },
  { "mdi-numeric_9_box_outline", "\\uf8bd" },
  { "mdi-numeric_9_plus_box", "\\uf8be" },
  { "mdi-numeric_9_plus_box_multiple_outline", "\\uf8bf" },
  { "mdi-numeric_9_plus_box_outline", "\\uf8c0" },
  { "mdi-nut", "\\ufbf6" },
  { "mdi-nutrition", "\\uf8c1" },
  { "mdi-oar", "\\ufb7a" },
  { "mdi-octagon", "\\uf8c2" },
  { "mdi-octagon_outline", "\\uf8c3" },
  { "mdi-octagram", "\\ufbf7" },
  { "mdi-octagram_outline", "\\ufc73" },
  { "mdi-odnoklassniki", "\\uf8c4" },
  { "mdi-office", "\\uf8c5" },
  { "mdi-oil", "\\uf8c6" },
  { "mdi-oil_temperature", "\\uf8c7" },
  { "mdi-omega", "\\uf8c8" },
  { "mdi-onedrive", "\\uf8c9" },
  { "mdi-onenote", "\\ufc45" },
  { "mdi-opacity", "\\ufacb" },
  { "mdi-open_in_app", "\\uf8ca" },
  { "mdi-open_in_new", "\\uf8cb" },
  { "mdi-openid", "\\uf8cc" },
  { "mdi-opera", "\\uf8cd" },
  { "mdi-orbit", "\\uf517" },
  { "mdi-ornament", "\\uf8ce" },
  { "mdi-ornament_variant", "\\uf8cf" },
  { "mdi-owl", "\\uf8d1" },
  { "mdi-package", "\\uf8d2" },
  { "mdi-package_down", "\\uf8d3" },
  { "mdi-package_up", "\\uf8d4" },
  { "mdi-package_variant", "\\uf8d5" },
  { "mdi-package_variant_closed", "\\uf8d6" },
  { "mdi-page_first", "\\ufaff" },
  { "mdi-page_last", "\\ufb00" },
  { "mdi-page_layout_body", "\\ufbf8" },
  { "mdi-page_layout_footer", "\\ufbf9" },
  { "mdi-page_layout_header", "\\ufbfa" },
  { "mdi-page_layout_sidebar_left", "\\ufbfb" },
  { "mdi-page_layout_sidebar_right", "\\ufbfc" },
  { "mdi-palette", "\\uf8d7" },
  { "mdi-palette_advanced", "\\uf8d8" },
  { "mdi-panda", "\\uf8d9" },
  { "mdi-pandora", "\\uf8da" },
  { "mdi-panorama", "\\uf8db" },
  { "mdi-panorama_fisheye", "\\uf8dc" },
  { "mdi-panorama_horizontal", "\\uf8dd" },
  { "mdi-panorama_vertical", "\\uf8de" },
  { "mdi-panorama_wide_angle", "\\uf8df" },
  { "mdi-paper_cut_vertical", "\\uf8e0" },
  { "mdi-paperclip", "\\uf8e1" },
  { "mdi-parking", "\\uf8e2" },
  { "mdi-passport", "\\ufce1" },
  { "mdi-pause", "\\uf8e3" },
  { "mdi-pause_circle", "\\uf8e4" },
  { "mdi-pause_circle_outline", "\\uf8e5" },
  { "mdi-pause_octagon", "\\uf8e6" },
  { "mdi-pause_octagon_outline", "\\uf8e7" },
  { "mdi-paw", "\\uf8e8" },
  { "mdi-paw_off", "\\ufb56" },
  { "mdi-pen", "\\uf8e9" },
  { "mdi-pencil", "\\uf8ea" },
  { "mdi-pencil_box", "\\uf8eb" },
  { "mdi-pencil_box_outline", "\\uf8ec" },
  { "mdi-pencil_circle", "\\ufbfd" },
  { "mdi-pencil_circle_outline", "\\ufc74" },
  { "mdi-pencil_lock", "\\uf8ed" },
  { "mdi-pencil_off", "\\uf8ee" },
  { "mdi-pentagon", "\\ufbfe" },
  { "mdi-pentagon_outline", "\\ufbff" },
  { "mdi-percent", "\\uf8ef" },
  { "mdi-periodic_table_co2", "\\ufce2" },
  { "mdi-periscope", "\\ufc46" },
  { "mdi-pharmacy", "\\uf8f0" },
  { "mdi-phone", "\\uf8f1" },
  { "mdi-phone_bluetooth", "\\uf8f2" },
  { "mdi-phone_classic", "\\ufb01" },
  { "mdi-phone_forward", "\\uf8f3" },
  { "mdi-phone_hangup", "\\uf8f4" },
  { "mdi-phone_in_talk", "\\uf8f5" },
  { "mdi-phone_incoming", "\\uf8f6" },
  { "mdi-phone_locked", "\\uf8f7" },
  { "mdi-phone_log", "\\uf8f8" },
  { "mdi-phone_minus", "\\ufb57" },
  { "mdi-phone_missed", "\\uf8f9" },
  { "mdi-phone_outgoing", "\\uf8fa" },
  { "mdi-phone_paused", "\\uf8fb" },
  { "mdi-phone_plus", "\\ufb58" },
  { "mdi-phone_return", "\\ufd2d" },
  { "mdi-phone_settings", "\\uf8fc" },
  { "mdi-phone_voip", "\\uf8fd" },
  { "mdi-pi", "\\uf8fe" },
  { "mdi-pi_box", "\\uf8ff" },
  { "mdi-piano", "\\ufb7b" },
  { "mdi-pig", "\\uf900" },
  { "mdi-pill", "\\uf901" },
  { "mdi-pillar", "\\ufc00" },
  { "mdi-pin", "\\uf902" },
  { "mdi-pin_off", "\\uf903" },
  { "mdi-pine_tree", "\\uf904" },
  { "mdi-pine_tree_box", "\\uf905" },
  { "mdi-pinterest", "\\uf906" },
  { "mdi-pinterest_box", "\\uf907" },
  { "mdi-pipe", "\\ufce3" },
  { "mdi-pipe_disconnected", "\\ufce4" },
  { "mdi-pistol", "\\ufc01" },
  { "mdi-pizza", "\\uf908" },
  { "mdi-plane_shield", "\\ufbb9" },
  { "mdi-play", "\\uf909" },
  { "mdi-play_box_outline", "\\uf90a" },
  { "mdi-play_circle", "\\uf90b" },
  { "mdi-play_circle_outline", "\\uf90c" },
  { "mdi-play_pause", "\\uf90d" },
  { "mdi-play_protected_content", "\\uf90e" },
  { "mdi-playlist_check", "\\ufac6" },
  { "mdi-playlist_minus", "\\uf90f" },
  { "mdi-playlist_play", "\\uf910" },
  { "mdi-playlist_plus", "\\uf911" },
  { "mdi-playlist_remove", "\\uf912" },
  { "mdi-playstation", "\\uf913" },
  { "mdi-plex", "\\ufbb8" },
  { "mdi-plus", "\\uf914" },
  { "mdi-plus_box", "\\uf915" },
  { "mdi-plus_box_outline", "\\ufc02" },
  { "mdi-plus_circle", "\\uf916" },
  { "mdi-plus_circle_multiple_outline", "\\uf917" },
  { "mdi-plus_circle_outline", "\\uf918" },
  { "mdi-plus_network", "\\uf919" },
  { "mdi-plus_one", "\\uf91a" },
  { "mdi-plus_outline", "\\ufc03" },
  { "mdi-pocket", "\\uf91b" },
  { "mdi-pokeball", "\\uf91c" },
  { "mdi-poker_chip", "\\ufd2e" },
  { "mdi-polaroid", "\\uf91d" },
  { "mdi-poll", "\\uf91e" },
  { "mdi-poll_box", "\\uf91f" },
  { "mdi-polymer", "\\uf920" },
  { "mdi-pool", "\\ufb05" },
  { "mdi-popcorn", "\\uf921" },
  { "mdi-pot", "\\ufb59" },
  { "mdi-pot_mix", "\\ufb5a" },
  { "mdi-pound", "\\uf922" },
  { "mdi-pound_box", "\\uf923" },
  { "mdi-power", "\\uf924" },
  { "mdi-power_plug", "\\ufba3" },
  { "mdi-power_plug_off", "\\ufba4" },
  { "mdi-power_settings", "\\uf925" },
  { "mdi-power_socket", "\\uf926" },
  { "mdi-power_socket_eu", "\\ufce5" },
  { "mdi-power_socket_uk", "\\ufce6" },
  { "mdi-power_socket_us", "\\ufce7" },
  { "mdi-prescription", "\\ufc04" },
  { "mdi-presentation", "\\uf927" },
  { "mdi-presentation_play", "\\uf928" },
  { "mdi-printer", "\\uf929" },
  { "mdi-printer_3d", "\\uf92a" },
  { "mdi-printer_alert", "\\uf92b" },
  { "mdi-printer_settings", "\\ufc05" },
  { "mdi-priority_high", "\\ufb02" },
  { "mdi-priority_low", "\\ufb03" },
  { "mdi-professional_hexagon", "\\uf92c" },
  { "mdi-projector", "\\uf92d" },
  { "mdi-projector_screen", "\\uf92e" },
  { "mdi-publish", "\\ufba5" },
  { "mdi-pulse", "\\uf92f" },
  { "mdi-puzzle", "\\uf930" },
  { "mdi-qqchat", "\\ufb04" },
  { "mdi-qrcode", "\\uf931" },
  { "mdi-qrcode_scan", "\\uf932" },
  { "mdi-quadcopter", "\\uf933" },
  { "mdi-quality_high", "\\uf934" },
  { "mdi-quicktime", "\\uf935" },
  { "mdi-radar", "\\uf936" },
  { "mdi-radiator", "\\uf937" },
  { "mdi-radio", "\\uf938" },
  { "mdi-radio_handheld", "\\uf939" },
  { "mdi-radio_tower", "\\uf93a" },
  { "mdi-radioactive", "\\uf93b" },
  { "mdi-radiobox_blank", "\\uf93c" },
  { "mdi-radiobox_marked", "\\uf93d" },
  { "mdi-raspberrypi", "\\uf93e" },
  { "mdi-ray_end", "\\uf93f" },
  { "mdi-ray_end_arrow", "\\uf940" },
  { "mdi-ray_start", "\\uf941" },
  { "mdi-ray_start_arrow", "\\uf942" },
  { "mdi-ray_start_end", "\\uf943" },
  { "mdi-ray_vertex", "\\uf944" },
  { "mdi-react", "\\ufc06" },
  { "mdi-read", "\\uf946" },
  { "mdi-receipt", "\\uf948" },
  { "mdi-record", "\\uf949" },
  { "mdi-record_rec", "\\uf94a" },
  { "mdi-recycle", "\\uf94b" },
  { "mdi-reddit", "\\uf94c" },
  { "mdi-redo", "\\uf94d" },
  { "mdi-redo_variant", "\\uf94e" },
  { "mdi-refresh", "\\uf94f" },
  { "mdi-regex", "\\uf950" },
  { "mdi-relative_scale", "\\uf951" },
  { "mdi-reload", "\\uf952" },
  { "mdi-remote", "\\uf953" },
  { "mdi-rename_box", "\\uf954" },
  { "mdi-reorder_horizontal", "\\ufb86" },
  { "mdi-reorder_vertical", "\\ufb87" },
  { "mdi-repeat", "\\uf955" },
  { "mdi-repeat_off", "\\uf956" },
  { "mdi-repeat_once", "\\uf957" },
  { "mdi-replay", "\\uf958" },
  { "mdi-reply", "\\uf959" },
  { "mdi-reply_all", "\\uf95a" },
  { "mdi-reproduction", "\\uf95b" },
  { "mdi-resize_bottom_right", "\\uf95c" },
  { "mdi-responsive", "\\uf95d" },
  { "mdi-restart", "\\ufc07" },
  { "mdi-restore", "\\ufba6" },
  { "mdi-rewind", "\\uf95e" },
  { "mdi-rewind_outline", "\\ufc08" },
  { "mdi-rhombus", "\\ufc09" },
  { "mdi-rhombus_outline", "\\ufc0a" },
  { "mdi-ribbon", "\\uf95f" },
  { "mdi-rice", "\\ufce8" },
  { "mdi-ring", "\\ufce9" },
  { "mdi-road", "\\uf960" },
  { "mdi-road_variant", "\\uf961" },
  { "mdi-robot", "\\ufba7" },
  { "mdi-rocket", "\\uf962" },
  { "mdi-roomba", "\\ufc0b" },
  { "mdi-rotate_3d", "\\uf963" },
  { "mdi-rotate_left", "\\uf964" },
  { "mdi-rotate_left_variant", "\\uf965" },
  { "mdi-rotate_right", "\\uf966" },
  { "mdi-rotate_right_variant", "\\uf967" },
  { "mdi-rounded_corner", "\\ufb06" },
  { "mdi-router_wireless", "\\uf968" },
  { "mdi-routes", "\\uf969" },
  { "mdi-rowing", "\\ufb07" },
  { "mdi-rss", "\\uf96a" },
  { "mdi-rss_box", "\\uf96b" },
  { "mdi-ruler", "\\uf96c" },
  { "mdi-run", "\\ufc0c" },
  { "mdi-run_fast", "\\uf96d" },
  { "mdi-sale", "\\uf96e" },
  { "mdi-sass", "\\ufcea" },
  { "mdi-satellite", "\\uf96f" },
  { "mdi-satellite_variant", "\\uf970" },
  { "mdi-saxophone", "\\ufb08" },
  { "mdi-scale", "\\uf971" },
  { "mdi-scale_balance", "\\ufad0" },
  { "mdi-scale_bathroom", "\\uf972" },
  { "mdi-scanner", "\\ufba9" },
  { "mdi-school", "\\uf973" },
  { "mdi-screen_rotation", "\\uf974" },
  { "mdi-screen_rotation_lock", "\\uf975" },
  { "mdi-screwdriver", "\\uf976" },
  { "mdi-script", "\\uf977" },
  { "mdi-sd", "\\uf978" },
  { "mdi-seal", "\\uf979" },
  { "mdi-search_web", "\\ufc0d" },
  { "mdi-seat_flat", "\\uf97a" },
  { "mdi-seat_flat_angled", "\\uf97b" },
  { "mdi-seat_individual_suite", "\\uf97c" },
  { "mdi-seat_legroom_extra", "\\uf97d" },
  { "mdi-seat_legroom_normal", "\\uf97e" },
  { "mdi-seat_legroom_reduced", "\\uf97f" },
  { "mdi-seat_recline_extra", "\\uf980" },
  { "mdi-seat_recline_normal", "\\uf981" },
  { "mdi-security", "\\uf982" },
  { "mdi-security_home", "\\ufb88" },
  { "mdi-security_network", "\\uf983" },
  { "mdi-select", "\\uf984" },
  { "mdi-select_all", "\\uf985" },
  { "mdi-select_inverse", "\\uf986" },
  { "mdi-select_off", "\\uf987" },
  { "mdi-selection", "\\uf988" },
  { "mdi-selection_off", "\\ufc75" },
  { "mdi-send", "\\uf989" },
  { "mdi-send_secure", "\\ufceb" },
  { "mdi-serial_port", "\\ufb5b" },
  { "mdi-server", "\\uf98a" },
  { "mdi-server_minus", "\\uf98b" },
  { "mdi-server_network", "\\uf98c" },
  { "mdi-server_network_off", "\\uf98d" },
  { "mdi-server_off", "\\uf98e" },
  { "mdi-server_plus", "\\uf98f" },
  { "mdi-server_remove", "\\uf990" },
  { "mdi-server_security", "\\uf991" },
  { "mdi-set_all", "\\ufc76" },
  { "mdi-set_center", "\\ufc77" },
  { "mdi-set_center_right", "\\ufc78" },
  { "mdi-set_left", "\\ufc79" },
  { "mdi-set_left_center", "\\ufc7a" },
  { "mdi-set_left_right", "\\ufc7b" },
  { "mdi-set_none", "\\ufc7c" },
  { "mdi-set_right", "\\ufc7d" },
  { "mdi-settings", "\\uf992" },
  { "mdi-settings_box", "\\uf993" },
  { "mdi-shape", "\\ufd2f" },
  { "mdi-shape_circle_plus", "\\ufb5c" },
  { "mdi-shape_outline", "\\ufd30" },
  { "mdi-shape_plus", "\\uf994" },
  { "mdi-shape_polygon_plus", "\\ufb5d" },
  { "mdi-shape_rectangle_plus", "\\ufb5e" },
  { "mdi-shape_square_plus", "\\ufb5f" },
  { "mdi-share", "\\uf995" },
  { "mdi-share_variant", "\\uf996" },
  { "mdi-shield", "\\uf997" },
  { "mdi-shield_half_full", "\\ufc7e" },
  { "mdi-shield_outline", "\\uf998" },
  { "mdi-ship_wheel", "\\ufd31" },
  { "mdi-shopping", "\\uf999" },
  { "mdi-shopping_music", "\\uf99a" },
  { "mdi-shovel", "\\ufc0e" },
  { "mdi-shovel_off", "\\ufc0f" },
  { "mdi-shredder", "\\uf99b" },
  { "mdi-shuffle", "\\uf99c" },
  { "mdi-shuffle_disabled", "\\uf99d" },
  { "mdi-shuffle_variant", "\\uf99e" },
  { "mdi-sigma", "\\uf99f" },
  { "mdi-sigma_lower", "\\ufb2a" },
  { "mdi-sign_caution", "\\uf9a0" },
  { "mdi-sign_direction", "\\ufc7f" },
  { "mdi-sign_text", "\\ufc80" },
  { "mdi-signal", "\\uf9a1" },
  { "mdi-signal_2g", "\\ufc10" },
  { "mdi-signal_3g", "\\ufc11" },
  { "mdi-signal_4g", "\\ufc12" },
  { "mdi-signal_hspa", "\\ufc13" },
  { "mdi-signal_hspa_plus", "\\ufc14" },
  { "mdi-signal_off", "\\ufc81" },
  { "mdi-signal_variant", "\\ufb09" },
  { "mdi-silverware", "\\uf9a2" },
  { "mdi-silverware_fork", "\\uf9a3" },
  { "mdi-silverware_spoon", "\\uf9a4" },
  { "mdi-silverware_variant", "\\uf9a5" },
  { "mdi-sim", "\\uf9a6" },
  { "mdi-sim_alert", "\\uf9a7" },
  { "mdi-sim_off", "\\uf9a8" },
  { "mdi-sitemap", "\\uf9a9" },
  { "mdi-skip_backward", "\\uf9aa" },
  { "mdi-skip_forward", "\\uf9ab" },
  { "mdi-skip_next", "\\uf9ac" },
  { "mdi-skip_next_circle", "\\ufb60" },
  { "mdi-skip_next_circle_outline", "\\ufb61" },
  { "mdi-skip_previous", "\\uf9ad" },
  { "mdi-skip_previous_circle", "\\ufb62" },
  { "mdi-skip_previous_circle_outline", "\\ufb63" },
  { "mdi-skull", "\\ufb8a" },
  { "mdi-skype", "\\uf9ae" },
  { "mdi-skype_business", "\\uf9af" },
  { "mdi-slack", "\\uf9b0" },
  { "mdi-sleep", "\\uf9b1" },
  { "mdi-sleep_off", "\\uf9b2" },
  { "mdi-smoking", "\\uf9b3" },
  { "mdi-smoking_off", "\\uf9b4" },
  { "mdi-snapchat", "\\uf9b5" },
  { "mdi-snowflake", "\\ufc15" },
  { "mdi-snowman", "\\uf9b6" },
  { "mdi-soccer", "\\uf9b7" },
  { "mdi-soccer_field", "\\ufd32" },
  { "mdi-sofa", "\\uf9b8" },
  { "mdi-solid", "\\ufb8b" },
  { "mdi-sort", "\\uf9b9" },
  { "mdi-sort_alphabetical", "\\uf9ba" },
  { "mdi-sort_ascending", "\\uf9bb" },
  { "mdi-sort_descending", "\\uf9bc" },
  { "mdi-sort_numeric", "\\uf9bd" },
  { "mdi-sort_variant", "\\uf9be" },
  { "mdi-soundcloud", "\\uf9bf" },
  { "mdi-source_branch", "\\ufb2b" },
  { "mdi-source_commit", "\\ufc16" },
  { "mdi-source_commit_end", "\\ufc17" },
  { "mdi-source_commit_end_local", "\\ufc18" },
  { "mdi-source_commit_local", "\\ufc19" },
  { "mdi-source_commit_next_local", "\\ufc1a" },
  { "mdi-source_commit_start", "\\ufc1b" },
  { "mdi-source_commit_start_next_local", "\\ufc1c" },
  { "mdi-source_fork", "\\uf9c0" },
  { "mdi-source_merge", "\\ufb2c" },
  { "mdi-source_pull", "\\uf9c1" },
  { "mdi-soy_sauce", "\\ufcec" },
  { "mdi-speaker", "\\uf9c2" },
  { "mdi-speaker_off", "\\uf9c3" },
  { "mdi-speaker_wireless", "\\ufc1d" },
  { "mdi-speedometer", "\\uf9c4" },
  { "mdi-spellcheck", "\\uf9c5" },
  { "mdi-spotify", "\\uf9c6" },
  { "mdi-spotlight", "\\uf9c7" },
  { "mdi-spotlight_beam", "\\uf9c8" },
  { "mdi-spray", "\\ufb64" },
  { "mdi-square", "\\ufc62" },
  { "mdi-square_inc", "\\uf9c9" },
  { "mdi-square_inc_cash", "\\uf9ca" },
  { "mdi-square_outline", "\\ufc61" },
  { "mdi-square_root", "\\ufc82" },
  { "mdi-stack_overflow", "\\uf9cb" },
  { "mdi-stackexchange", "\\ufb0a" },
  { "mdi-stadium", "\\ufc1e" },
  { "mdi-stairs", "\\uf9cc" },
  { "mdi-standard_definition", "\\ufced" },
  { "mdi-star", "\\uf9cd" },
  { "mdi-star_circle", "\\uf9ce" },
  { "mdi-star_half", "\\uf9cf" },
  { "mdi-star_off", "\\uf9d0" },
  { "mdi-star_outline", "\\uf9d1" },
  { "mdi-steam", "\\uf9d2" },
  { "mdi-steering", "\\uf9d3" },
  { "mdi-step_backward", "\\uf9d4" },
  { "mdi-step_backward_2", "\\uf9d5" },
  { "mdi-step_forward", "\\uf9d6" },
  { "mdi-step_forward_2", "\\uf9d7" },
  { "mdi-stethoscope", "\\uf9d8" },
  { "mdi-sticker", "\\ufacf" },
  { "mdi-sticker_emoji", "\\ufc83" },
  { "mdi-stocking", "\\uf9d9" },
  { "mdi-stop", "\\uf9da" },
  { "mdi-stop_circle", "\\ufb65" },
  { "mdi-stop_circle_outline", "\\ufb66" },
  { "mdi-store", "\\uf9db" },
  { "mdi-store_24_hour", "\\uf9dc" },
  { "mdi-stove", "\\uf9dd" },
  { "mdi-subdirectory_arrow_left", "\\ufb0b" },
  { "mdi-subdirectory_arrow_right", "\\ufb0c" },
  { "mdi-subway", "\\ufbaa" },
  { "mdi-subway_variant", "\\uf9de" },
  { "mdi-summit", "\\ufc84" },
  { "mdi-sunglasses", "\\uf9df" },
  { "mdi-surround_sound", "\\ufac4" },
  { "mdi-surround_sound_2_0", "\\ufcee" },
  { "mdi-surround_sound_3_1", "\\ufcef" },
  { "mdi-surround_sound_5_1", "\\ufcf0" },
  { "mdi-surround_sound_7_1", "\\ufcf1" },
  { "mdi-svg", "\\ufc1f" },
  { "mdi-swap_horizontal", "\\uf9e0" },
  { "mdi-swap_vertical", "\\uf9e1" },
  { "mdi-swim", "\\uf9e2" },
  { "mdi-switch", "\\uf9e3" },
  { "mdi-sword", "\\uf9e4" },
  { "mdi-sword_cross", "\\ufc85" },
  { "mdi-sync", "\\uf9e5" },
  { "mdi-sync_alert", "\\uf9e6" },
  { "mdi-sync_off", "\\uf9e7" },
  { "mdi-tab", "\\uf9e8" },
  { "mdi-tab_plus", "\\ufc5a" },
  { "mdi-tab_unselected", "\\uf9e9" },
  { "mdi-table", "\\uf9ea" },
  { "mdi-table_column", "\\ufd33" },
  { "mdi-table_column_plus_after", "\\uf9eb" },
  { "mdi-table_column_plus_before", "\\uf9ec" },
  { "mdi-table_column_remove", "\\uf9ed" },
  { "mdi-table_column_width", "\\uf9ee" },
  { "mdi-table_edit", "\\uf9ef" },
  { "mdi-table_large", "\\uf9f0" },
  { "mdi-table_of_contents", "\\ufd34" },
  { "mdi-table_row", "\\ufd35" },
  { "mdi-table_row_height", "\\uf9f1" },
  { "mdi-table_row_plus_after", "\\uf9f2" },
  { "mdi-table_row_plus_before", "\\uf9f3" },
  { "mdi-table_row_remove", "\\uf9f4" },
  { "mdi-table_settings", "\\ufd36" },
  { "mdi-tablet", "\\uf9f5" },
  { "mdi-tablet_android", "\\uf9f6" },
  { "mdi-tablet_ipad", "\\uf9f7" },
  { "mdi-taco", "\\ufc60" },
  { "mdi-tag", "\\uf9f8" },
  { "mdi-tag_faces", "\\uf9f9" },
  { "mdi-tag_heart", "\\ufb89" },
  { "mdi-tag_multiple", "\\uf9fa" },
  { "mdi-tag_outline", "\\uf9fb" },
  { "mdi-tag_plus", "\\ufc20" },
  { "mdi-tag_remove", "\\ufc21" },
  { "mdi-tag_text_outline", "\\uf9fc" },
  { "mdi-target", "\\uf9fd" },
  { "mdi-taxi", "\\uf9fe" },
  { "mdi-teamviewer", "\\uf9ff" },
  { "mdi-telegram", "\\ufa00" },
  { "mdi-television", "\\ufa01" },
  { "mdi-television_box", "\\ufd37" },
  { "mdi-television_classic", "\\ufcf2" },
  { "mdi-television_classic_off", "\\ufd38" },
  { "mdi-television_guide", "\\ufa02" },
  { "mdi-television_off", "\\ufd39" },
  { "mdi-temperature_celsius", "\\ufa03" },
  { "mdi-temperature_fahrenheit", "\\ufa04" },
  { "mdi-temperature_kelvin", "\\ufa05" },
  { "mdi-tennis", "\\ufa06" },
  { "mdi-tent", "\\ufa07" },
  { "mdi-terrain", "\\ufa08" },
  { "mdi-test_tube", "\\ufb67" },
  { "mdi-text_shadow", "\\ufb68" },
  { "mdi-text_to_speech", "\\ufa09" },
  { "mdi-text_to_speech_off", "\\ufa0a" },
  { "mdi-textbox", "\\ufb0d" },
  { "mdi-textbox_password", "\\ufcf3" },
  { "mdi-texture", "\\ufa0b" },
  { "mdi-theater", "\\ufa0c" },
  { "mdi-theme_light_dark", "\\ufa0d" },
  { "mdi-thermometer", "\\ufa0e" },
  { "mdi-thermometer_lines", "\\ufa0f" },
  { "mdi-thought_bubble", "\\ufcf4" },
  { "mdi-thought_bubble_outline", "\\ufcf5" },
  { "mdi-thumb_down", "\\ufa10" },
  { "mdi-thumb_down_outline", "\\ufa11" },
  { "mdi-thumb_up", "\\ufa12" },
  { "mdi-thumb_up_outline", "\\ufa13" },
  { "mdi-thumbs_up_down", "\\ufa14" },
  { "mdi-ticket", "\\ufa15" },
  { "mdi-ticket_account", "\\ufa16" },
  { "mdi-ticket_confirmation", "\\ufa17" },
  { "mdi-ticket_percent", "\\ufc22" },
  { "mdi-tie", "\\ufa18" },
  { "mdi-tilde", "\\ufc23" },
  { "mdi-timelapse", "\\ufa19" },
  { "mdi-timer", "\\ufa1a" },
  { "mdi-timer_10", "\\ufa1b" },
  { "mdi-timer_3", "\\ufa1c" },
  { "mdi-timer_off", "\\ufa1d" },
  { "mdi-timer_sand", "\\ufa1e" },
  { "mdi-timer_sand_empty", "\\ufbab" },
  { "mdi-timer_sand_full", "\\ufc8a" },
  { "mdi-timetable", "\\ufa1f" },
  { "mdi-toggle_switch", "\\ufa20" },
  { "mdi-toggle_switch_off", "\\ufa21" },
  { "mdi-tooltip", "\\ufa22" },
  { "mdi-tooltip_edit", "\\ufa23" },
  { "mdi-tooltip_image", "\\ufa24" },
  { "mdi-tooltip_outline", "\\ufa25" },
  { "mdi-tooltip_outline_plus", "\\ufa26" },
  { "mdi-tooltip_text", "\\ufa27" },
  { "mdi-tooth", "\\ufa28" },
  { "mdi-tor", "\\ufa29" },
  { "mdi-tower_beach", "\\ufb7f" },
  { "mdi-tower_fire", "\\ufb80" },
  { "mdi-towing", "\\ufd3a" },
  { "mdi-trackpad", "\\ufcf6" },
  { "mdi-traffic_light", "\\ufa2a" },
  { "mdi-train", "\\ufa2b" },
  { "mdi-tram", "\\ufa2c" },
  { "mdi-transcribe", "\\ufa2d" },
  { "mdi-transcribe_close", "\\ufa2e" },
  { "mdi-transfer", "\\ufa2f" },
  { "mdi-transit_transfer", "\\ufbac" },
  { "mdi-translate", "\\ufac9" },
  { "mdi-treasure_chest", "\\ufc24" },
  { "mdi-tree", "\\ufa30" },
  { "mdi-trello", "\\ufa31" },
  { "mdi-trending_down", "\\ufa32" },
  { "mdi-trending_neutral", "\\ufa33" },
  { "mdi-trending_up", "\\ufa34" },
  { "mdi-triangle", "\\ufa35" },
  { "mdi-triangle_outline", "\\ufa36" },
  { "mdi-trophy", "\\ufa37" },
  { "mdi-trophy_award", "\\ufa38" },
  { "mdi-trophy_outline", "\\ufa39" },
  { "mdi-trophy_variant", "\\ufa3a" },
  { "mdi-trophy_variant_outline", "\\ufa3b" },
  { "mdi-truck", "\\ufa3c" },
  { "mdi-truck_delivery", "\\ufa3d" },
  { "mdi-truck_fast", "\\ufc86" },
  { "mdi-truck_trailer", "\\ufc25" },
  { "mdi-tshirt_crew", "\\ufa3e" },
  { "mdi-tshirt_v", "\\ufa3f" },
  { "mdi-tumblr", "\\ufa40" },
  { "mdi-tumblr_reblog", "\\ufa41" },
  { "mdi-tune", "\\ufb2d" },
  { "mdi-tune_vertical", "\\ufb69" },
  { "mdi-twitch", "\\ufa42" },
  { "mdi-twitter", "\\ufa43" },
  { "mdi-twitter_box", "\\ufa44" },
  { "mdi-twitter_circle", "\\ufa45" },
  { "mdi-twitter_retweet", "\\ufa46" },
  { "mdi-uber", "\\ufc47" },
  { "mdi-ubuntu", "\\ufa47" },
  { "mdi-ultra_high_definition", "\\ufcf7" },
  { "mdi-umbraco", "\\ufa48" },
  { "mdi-umbrella", "\\ufa49" },
  { "mdi-umbrella_outline", "\\ufa4a" },
  { "mdi-undo", "\\ufa4b" },
  { "mdi-undo_variant", "\\ufa4c" },
  { "mdi-unfold_less_horizontal", "\\ufa4d" },
  { "mdi-unfold_less_vertical", "\\ufc5e" },
  { "mdi-unfold_more_horizontal", "\\ufa4e" },
  { "mdi-unfold_more_vertical", "\\ufc5f" },
  { "mdi-ungroup", "\\ufa4f" },
  { "mdi-unity", "\\ufbad" },
  { "mdi-untappd", "\\ufa50" },
  { "mdi-update", "\\ufbae" },
  { "mdi-upload", "\\ufa51" },
  { "mdi-upload_multiple", "\\ufd3b" },
  { "mdi-upload_network", "\\ufbf4" },
  { "mdi-usb", "\\ufa52" },
  { "mdi-van_passenger", "\\ufcf8" },
  { "mdi-van_utility", "\\ufcf9" },
  { "mdi-vanish", "\\ufcfa" },
  { "mdi-vector_arrange_above", "\\ufa53" },
  { "mdi-vector_arrange_below", "\\ufa54" },
  { "mdi-vector_circle", "\\ufa55" },
  { "mdi-vector_circle_variant", "\\ufa56" },
  { "mdi-vector_combine", "\\ufa57" },
  { "mdi-vector_curve", "\\ufa58" },
  { "mdi-vector_difference", "\\ufa59" },
  { "mdi-vector_difference_ab", "\\ufa5a" },
  { "mdi-vector_difference_ba", "\\ufa5b" },
  { "mdi-vector_intersection", "\\ufa5c" },
  { "mdi-vector_line", "\\ufa5d" },
  { "mdi-vector_point", "\\ufa5e" },
  { "mdi-vector_polygon", "\\ufa5f" },
  { "mdi-vector_polyline", "\\ufa60" },
  { "mdi-vector_radius", "\\ufc48" },
  { "mdi-vector_rectangle", "\\ufac5" },
  { "mdi-vector_selection", "\\ufa61" },
  { "mdi-vector_square", "\\uf500" },
  { "mdi-vector_triangle", "\\ufa62" },
  { "mdi-vector_union", "\\ufa63" },
  { "mdi-venmo", "\\ufa77" },
  { "mdi-verified", "\\ufa64" },
  { "mdi-vibrate", "\\ufa65" },
  { "mdi-video", "\\ufa66" },
  { "mdi-video_3d", "\\ufcfb" },
  { "mdi-video_4k_box", "\\ufd3c" },
  { "mdi-video_input_antenna", "\\ufd3d" },
  { "mdi-video_input_component", "\\ufd3e" },
  { "mdi-video_input_hdmi", "\\ufd3f" },
  { "mdi-video_input_svideo", "\\ufd40" },
  { "mdi-video_off", "\\ufa67" },
  { "mdi-video_switch", "\\ufa68" },
  { "mdi-view_agenda", "\\ufa69" },
  { "mdi-view_array", "\\ufa6a" },
  { "mdi-view_carousel", "\\ufa6b" },
  { "mdi-view_column", "\\ufa6c" },
  { "mdi-view_dashboard", "\\ufa6d" },
  { "mdi-view_dashboard_variant", "\\ufd41" },
  { "mdi-view_day", "\\ufa6e" },
  { "mdi-view_grid", "\\ufa6f" },
  { "mdi-view_headline", "\\ufa70" },
  { "mdi-view_list", "\\ufa71" },
  { "mdi-view_module", "\\ufa72" },
  { "mdi-view_parallel", "\\ufc26" },
  { "mdi-view_quilt", "\\ufa73" },
  { "mdi-view_sequential", "\\ufc27" },
  { "mdi-view_stream", "\\ufa74" },
  { "mdi-view_week", "\\ufa75" },
  { "mdi-vimeo", "\\ufa76" },
  { "mdi-violin", "\\ufb0e" },
  { "mdi-visualstudio", "\\ufb0f" },
  { "mdi-vk", "\\ufa78" },
  { "mdi-vk_box", "\\ufa79" },
  { "mdi-vk_circle", "\\ufa7a" },
  { "mdi-vlc", "\\ufa7b" },
  { "mdi-voice", "\\ufaca" },
  { "mdi-voicemail", "\\ufa7c" },
  { "mdi-volume_high", "\\ufa7d" },
  { "mdi-volume_low", "\\ufa7e" },
  { "mdi-volume_medium", "\\ufa7f" },
  { "mdi-volume_minus", "\\ufc5c" },
  { "mdi-volume_mute", "\\ufc5d" },
  { "mdi-volume_off", "\\ufa80" },
  { "mdi-volume_plus", "\\ufc5b" },
  { "mdi-vpn", "\\ufa81" },
  { "mdi-vuejs", "\\ufd42" },
  { "mdi-walk", "\\ufa82" },
  { "mdi-wall", "\\ufcfc" },
  { "mdi-wallet", "\\ufa83" },
  { "mdi-wallet_giftcard", "\\ufa84" },
  { "mdi-wallet_membership", "\\ufa85" },
  { "mdi-wallet_travel", "\\ufa86" },
  { "mdi-wan", "\\ufa87" },
  { "mdi-washing_machine", "\\ufc28" },
  { "mdi-watch", "\\ufa88" },
  { "mdi-watch_export", "\\ufa89" },
  { "mdi-watch_import", "\\ufa8a" },
  { "mdi-watch_vibrate", "\\ufbaf" },
  { "mdi-water", "\\ufa8b" },
  { "mdi-water_off", "\\ufa8c" },
  { "mdi-water_percent", "\\ufa8d" },
  { "mdi-water_pump", "\\ufa8e" },
  { "mdi-watermark", "\\ufb11" },
  { "mdi-waves", "\\ufc8b" },
  { "mdi-weather_cloudy", "\\ufa8f" },
  { "mdi-weather_fog", "\\ufa90" },
  { "mdi-weather_hail", "\\ufa91" },
  { "mdi-weather_lightning", "\\ufa92" },
  { "mdi-weather_lightning_rainy", "\\ufb7c" },
  { "mdi-weather_night", "\\ufa93" },
  { "mdi-weather_partlycloudy", "\\ufa94" },
  { "mdi-weather_pouring", "\\ufa95" },
  { "mdi-weather_rainy", "\\ufa96" },
  { "mdi-weather_snowy", "\\ufa97" },
  { "mdi-weather_snowy_rainy", "\\ufb7d" },
  { "mdi-weather_sunny", "\\ufa98" },
  { "mdi-weather_sunset", "\\ufa99" },
  { "mdi-weather_sunset_down", "\\ufa9a" },
  { "mdi-weather_sunset_up", "\\ufa9b" },
  { "mdi-weather_windy", "\\ufa9c" },
  { "mdi-weather_windy_variant", "\\ufa9d" },
  { "mdi-web", "\\ufa9e" },
  { "mdi-webcam", "\\ufa9f" },
  { "mdi-webhook", "\\ufb2e" },
  { "mdi-webpack", "\\ufc29" },
  { "mdi-wechat", "\\ufb10" },
  { "mdi-weight", "\\ufaa0" },
  { "mdi-weight_kilogram", "\\ufaa1" },
  { "mdi-whatsapp", "\\ufaa2" },
  { "mdi-wheelchair_accessibility", "\\ufaa3" },
  { "mdi-white_balance_auto", "\\ufaa4" },
  { "mdi-white_balance_incandescent", "\\ufaa5" },
  { "mdi-white_balance_iridescent", "\\ufaa6" },
  { "mdi-white_balance_sunny", "\\ufaa7" },
  { "mdi-widgets", "\\ufc2a" },
  { "mdi-wifi", "\\ufaa8" },
  { "mdi-wifi_off", "\\ufaa9" },
  { "mdi-wii", "\\ufaaa" },
  { "mdi-wiiu", "\\ufc2b" },
  { "mdi-wikipedia", "\\ufaab" },
  { "mdi-window_close", "\\ufaac" },
  { "mdi-window_closed", "\\ufaad" },
  { "mdi-window_maximize", "\\ufaae" },
  { "mdi-window_minimize", "\\ufaaf" },
  { "mdi-window_open", "\\ufab0" },
  { "mdi-window_restore", "\\ufab1" },
  { "mdi-windows", "\\ufab2" },
  { "mdi-wordpress", "\\ufab3" },
  { "mdi-worker", "\\ufab4" },
  { "mdi-wrap", "\\ufab5" },
  { "mdi-wrench", "\\ufab6" },
  { "mdi-wunderlist", "\\ufab7" },
  { "mdi-xamarin", "\\ufd43" },
  { "mdi-xamarin_outline", "\\ufd44" },
  { "mdi-xaml", "\\ufb72" },
  { "mdi-xbox", "\\ufab8" },
  { "mdi-xbox_controller", "\\ufab9" },
  { "mdi-xbox_controller_battery_alert", "\\ufc49" },
  { "mdi-xbox_controller_battery_empty", "\\ufc4a" },
  { "mdi-xbox_controller_battery_full", "\\ufc4b" },
  { "mdi-xbox_controller_battery_low", "\\ufc4c" },
  { "mdi-xbox_controller_battery_medium", "\\ufc4d" },
  { "mdi-xbox_controller_battery_unknown", "\\ufc4e" },
  { "mdi-xbox_controller_off", "\\ufaba" },
  { "mdi-xda", "\\ufabb" },
  { "mdi-xing", "\\ufabc" },
  { "mdi-xing_box", "\\ufabd" },
  { "mdi-xing_circle", "\\ufabe" },
  { "mdi-xml", "\\ufabf" },
  { "mdi-xmpp", "\\ufcfd" },
  { "mdi-yammer", "\\ufc87" },
  { "mdi-yeast", "\\ufac0" },
  { "mdi-yelp", "\\ufac1" },
  { "mdi-yin_yang", "\\ufb7e" },
  { "mdi-youtube_creator_studio", "\\ufd45" },
  { "mdi-youtube_gaming", "\\ufd46" },
  { "mdi-youtube_play", "\\ufac2" },
  { "mdi-youtube_tv", "\\uf947" },
  { "mdi-zip_box", "\\ufac3" },
  { "oct-alert", "\\uf421" },
  { "oct-arrow_down", "\\uf433" },
  { "oct-arrow_left", "\\uf434" },
  { "oct-arrow_right", "\\uf432" },
  { "oct-arrow_small_down", "\\uf479" },
  { "oct-arrow_small_left", "\\uf47a" },
  { "oct-arrow_small_right", "\\uf45c" },
  { "oct-arrow_small_up", "\\uf478" },
  { "oct-arrow_up", "\\uf431" },
  { "oct-beaker", "\\uf499" },
  { "oct-bell", "\\uf49a" },
  { "oct-bold", "\\uf49d" },
  { "oct-book", "\\uf405" },
  { "oct-bookmark", "\\uf461" },
  { "oct-briefcase", "\\uf491" },
  { "oct-broadcast", "\\uf43c" },
  { "oct-browser", "\\uf488" },
  { "oct-bug", "\\uf46f" },
  { "oct-calendar", "\\uf455" },
  { "oct-check", "\\uf42e" },
  { "oct-checklist", "\\uf45e" },
  { "oct-chevron_down", "\\uf47c" },
  { "oct-chevron_left", "\\uf47d" },
  { "oct-chevron_right", "\\uf460" },
  { "oct-chevron_up", "\\uf47b" },
  { "oct-circle_slash", "\\uf468" },
  { "oct-circuit_board", "\\uf493" },
  { "oct-clippy", "\\uf429" },
  { "oct-clock", "\\uf43a" },
  { "oct-cloud_download", "\\uf409" },
  { "oct-cloud_upload", "\\uf40a" },
  { "oct-code", "\\uf44f" },
  { "oct-comment", "\\uf41f" },
  { "oct-comment_discussion", "\\uf442" },
  { "oct-credit_card", "\\uf439" },
  { "oct-dash", "\\uf48b" },
  { "oct-dashboard", "\\uf463" },
  { "oct-database", "\\uf472" },
  { "oct-desktop_download", "\\uf498" },
  { "oct-device_camera", "\\uf446" },
  { "oct-device_camera_video", "\\uf447" },
  { "oct-device_desktop", "\\uf67c" },
  { "oct-device_mobile", "\\uf42c" },
  { "oct-diff", "\\uf440" },
  { "oct-diff_added", "\\uf457" },
  { "oct-diff_ignored", "\\uf474" },
  { "oct-diff_modified", "\\uf459" },
  { "oct-diff_removed", "\\uf458" },
  { "oct-diff_renamed", "\\uf45a" },
  { "oct-ellipses", "\\uf4a4" },
  { "oct-ellipsis", "\\uf475" },
  { "oct-eye", "\\uf441" },
  { "oct-file", "\\uf4a5" },
  { "oct-file_binary", "\\uf471" },
  { "oct-file_code", "\\uf40d" },
  { "oct-file_directory", "\\uf413" },
  { "oct-file_media", "\\uf40f" },
  { "oct-file_pdf", "\\uf411" },
  { "oct-file_submodule", "\\uf414" },
  { "oct-file_symlink_directory", "\\uf482" },
  { "oct-file_symlink_file", "\\uf481" },
  { "oct-file_text", "\\uf40e" },
  { "oct-file_zip", "\\uf410" },
  { "oct-flame", "\\uf490" },
  { "oct-fold", "\\uf48c" },
  { "oct-gear", "\\uf423" },
  { "oct-gift", "\\uf436" },
  { "oct-gist", "\\uf40c" },
  { "oct-gist_secret", "\\uf46c" },
  { "oct-git_branch", "\\uf418" },
  { "oct-git_commit", "\\uf417" },
  { "oct-git_compare", "\\uf47f" },
  { "oct-git_merge", "\\uf419" },
  { "oct-git_pull_request", "\\uf407" },
  { "oct-globe", "\\uf484" },
  { "oct-grabber", "\\uf4a6" },
  { "oct-graph", "\\uf437" },
  { "oct-heart", "\\u2665" },
  { "oct-history", "\\uf464" },
  { "oct-home", "\\uf46d" },
  { "oct-horizontal_rule", "\\uf45b" },
  { "oct-hubot", "\\uf477" },
  { "oct-inbox", "\\uf48d" },
  { "oct-info", "\\uf449" },
  { "oct-issue_closed", "\\uf41d" },
  { "oct-issue_opened", "\\uf41b" },
  { "oct-issue_reopened", "\\uf41c" },
  { "oct-italic", "\\uf49f" },
  { "oct-jersey", "\\uf416" },
  { "oct-key", "\\uf43d" },
  { "oct-keyboard", "\\uf40b" },
  { "oct-law", "\\uf495" },
  { "oct-light_bulb", "\\uf400" },
  { "oct-link", "\\uf44c" },
  { "oct-link_external", "\\uf465" },
  { "oct-list_ordered", "\\uf452" },
  { "oct-list_unordered", "\\uf451" },
  { "oct-location", "\\uf450" },
  { "oct-lock", "\\uf456" },
  { "oct-logo_gist", "\\uf480" },
  { "oct-logo_github", "\\uf470" },
  { "oct-mail", "\\uf42f" },
  { "oct-mail_read", "\\uf430" },
  { "oct-mail_reply", "\\uf443" },
  { "oct-mark_github", "\\uf408" },
  { "oct-markdown", "\\uf48a" },
  { "oct-megaphone", "\\uf45f" },
  { "oct-mention", "\\uf486" },
  { "oct-milestone", "\\uf45d" },
  { "oct-mirror", "\\uf41a" },
  { "oct-mortar_board", "\\uf494" },
  { "oct-mute", "\\uf466" },
  { "oct-no_newline", "\\uf476" },
  { "oct-octoface", "\\uf406" },
  { "oct-organization", "\\uf42b" },
  { "oct-package", "\\uf487" },
  { "oct-paintcan", "\\uf48f" },
  { "oct-pencil", "\\uf448" },
  { "oct-person", "\\uf415" },
  { "oct-pin", "\\uf435" },
  { "oct-plug", "\\uf492" },
  { "oct-plus", "\\uf44d" },
  { "oct-plus_small", "\\uf4a7" },
  { "oct-primitive_dot", "\\uf444" },
  { "oct-primitive_square", "\\uf445" },
  { "oct-pulse", "\\uf469" },
  { "oct-question", "\\uf420" },
  { "oct-quote", "\\uf453" },
  { "oct-radio_tower", "\\uf424" },
  { "oct-reply", "\\uf4a8" },
  { "oct-repo", "\\uf401" },
  { "oct-repo_clone", "\\uf43f" },
  { "oct-repo_force_push", "\\uf43e" },
  { "oct-repo_forked", "\\uf402" },
  { "oct-repo_pull", "\\uf404" },
  { "oct-repo_push", "\\uf403" },
  { "oct-rocket", "\\uf427" },
  { "oct-rss", "\\uf428" },
  { "oct-ruby", "\\uf43b" },
  { "oct-search", "\\uf422" },
  { "oct-server", "\\uf473" },
  { "oct-settings", "\\uf462" },
  { "oct-shield", "\\uf49c" },
  { "oct-sign_in", "\\uf42a" },
  { "oct-sign_out", "\\uf426" },
  { "oct-smiley", "\\uf4a2" },
  { "oct-squirrel", "\\uf483" },
  { "oct-star", "\\uf41e" },
  { "oct-stop", "\\uf46e" },
  { "oct-sync", "\\uf46a" },
  { "oct-tag", "\\uf412" },
  { "oct-tasklist", "\\uf4a0" },
  { "oct-telescope", "\\uf46b" },
  { "oct-terminal", "\\uf489" },
  { "oct-text_size", "\\uf49e" },
  { "oct-three_bars", "\\uf44e" },
  { "oct-thumbsdown", "\\uf497" },
  { "oct-thumbsup", "\\uf496" },
  { "oct-tools", "\\uf425" },
  { "oct-trashcan", "\\uf48e" },
  { "oct-triangle_down", "\\uf44b" },
  { "oct-triangle_left", "\\uf438" },
  { "oct-triangle_right", "\\uf44a" },
  { "oct-triangle_up", "\\uf47e" },
  { "oct-unfold", "\\uf42d" },
  { "oct-unmute", "\\uf485" },
  { "oct-unverified", "\\uf4a3" },
  { "oct-verified", "\\uf4a1" },
  { "oct-versions", "\\uf454" },
  { "oct-watch", "\\uf49b" },
  { "oct-x", "\\uf467" },
  { "oct-zap", "\\u26a1" },
  { "pl-branch", "\\ue0a0" },
  { "pl-current_line", "\\ue0a1" },
  { "pl-hostname", "\\ue0a2" },
  { "pl-left_hard_divider", "\\ue0b0" },
  { "pl-left_soft_divider", "\\ue0b1" },
  { "pl-line_number", "\\ue0a1" },
  { "pl-readonly", "\\ue0a2" },
  { "pl-right_hard_divider", "\\ue0b2" },
  { "pl-right_soft_divider", "\\ue0b3" },
  { "ple-backslash_separator", "\\ue0b9" },
  { "ple-backslash_separator_redundant", "\\ue0bf" },
  { "ple-column_number", "\\ue0a3" },
  { "ple-current_column", "\\ue0a3" },
  { "ple-flame_thick", "\\ue0c0" },
  { "ple-flame_thick_mirrored", "\\ue0c2" },
  { "ple-flame_thin", "\\ue0c1" },
  { "ple-flame_thin_mirrored", "\\ue0c3" },
  { "ple-forwardslash_separator", "\\ue0bb" },
  { "ple-forwardslash_separator_redundant", "\\ue0bd" },
  { "ple-honeycomb", "\\ue0cc" },
  { "ple-honeycomb_outline", "\\ue0cd" },
  { "ple-ice_waveform", "\\ue0c8" },
  { "ple-ice_waveform_mirrored", "\\ue0ca" },
  { "ple-left_half_circle_thick", "\\ue0b6" },
  { "ple-left_half_circle_thin", "\\ue0b7" },
  { "ple-lego_block_facing", "\\ue0d0" },
  { "ple-lego_block_sideways", "\\ue0d1" },
  { "ple-lego_separator", "\\ue0ce" },
  { "ple-lego_separator_thin", "\\ue0cf" },
  { "ple-lower_left_triangle", "\\ue0b8" },
  { "ple-lower_right_triangle", "\\ue0ba" },
  { "ple-pixelated_squares_big", "\\ue0c6" },
  { "ple-pixelated_squares_big_mirrored", "\\ue0c7" },
  { "ple-pixelated_squares_small", "\\ue0c4" },
  { "ple-pixelated_squares_small_mirrored", "\\ue0c5" },
  { "ple-right_half_circle_thick", "\\ue0b4" },
  { "ple-right_half_circle_thin", "\\ue0b5" },
  { "ple-trapezoid_top_bottom", "\\ue0d2" },
  { "ple-trapezoid_top_bottom_mirrored", "\\ue0d4" },
  { "ple-upper_left_triangle", "\\ue0bc" },
  { "ple-upper_right_triangle", "\\ue0be" },
  { "pom-away", "\\ue007" },
  { "pom-clean_code", "\\ue000" },
  { "pom-external_interruption", "\\ue00a" },
  { "pom-internal_interruption", "\\ue009" },
  { "pom-long_pause", "\\ue006" },
  { "pom-pair_programming", "\\ue008" },
  { "pom-pomodoro_done", "\\ue001" },
  { "pom-pomodoro_estimated", "\\ue002" },
  { "pom-pomodoro_squashed", "\\ue004" },
  { "pom-pomodoro_ticking", "\\ue003" },
  { "pom-short_pause", "\\ue005" },
  { "seti-bower", "\\ue61a" },
  { "seti-cjsx", "\\ue61b" },
  { "seti-coffee", "\\ue61b" },
  { "seti-config", "\\ue615" },
  { "seti-css", "\\ue614" },
  { "seti-default", "\\ue612" },
  { "seti-ejs", "\\ue618" },
  { "seti-favicon", "\\ue623" },
  { "seti-folder", "\\ue613" },
  { "seti-go", "\\ue627" },
  { "seti-grunt", "\\ue611" },
  { "seti-gulp", "\\ue610" },
  { "seti-haskell", "\\ue61f" },
  { "seti-heroku", "\\ue607" },
  { "seti-home", "\\ue617" },
  { "seti-html", "\\ue60e" },
  { "seti-image", "\\ue60d" },
  { "seti-javascript", "\\ue60c" },
  { "seti-json", "\\ue60b" },
  { "seti-julia", "\\ue624" },
  { "seti-karma", "\\ue622" },
  { "seti-less", "\\ue60b" },
  { "seti-license", "\\ue60a" },
  { "seti-lua", "\\ue620" },
  { "seti-markdown", "\\ue609" },
  { "seti-mustache", "\\ue60f" },
  { "seti-npm", "\\ue616" },
  { "seti-php", "\\ue608" },
  { "seti-play_arrow", "\\ue602" },
  { "seti-project", "\\ue601" },
  { "seti-python", "\\ue606" },
  { "seti-rails", "\\ue604" },
  { "seti-react", "\\ue625" },
  { "seti-ruby", "\\ue605" },
  { "seti-sass", "\\ue603" },
  { "seti-stylus", "\\ue600" },
  { "seti-text", "\\ue612" },
  { "seti-twig", "\\ue61c" },
  { "seti-typescript", "\\ue628" },
  { "seti-xml", "\\ue619" },
  { "weather-alien", "\\ue36e" },
  { "weather-aliens", "\\ue345" },
  { "weather-barometer", "\\ue372" },
  { "weather-celsius", "\\ue339" },
  { "weather-cloud", "\\ue33d" },
  { "weather-cloud_down", "\\ue33a" },
  { "weather-cloud_refresh", "\\ue33b" },
  { "weather-cloud_up", "\\ue33c" },
  { "weather-cloudy", "\\ue312" },
  { "weather-cloudy_gusts", "\\ue310" },
  { "weather-cloudy_windy", "\\ue311" },
  { "weather-day_cloudy", "\\ue302" },
  { "weather-day_cloudy_gusts", "\\ue300" },
  { "weather-day_cloudy_high", "\\ue376" },
  { "weather-day_cloudy_windy", "\\ue301" },
  { "weather-day_fog", "\\ue303" },
  { "weather-day_hail", "\\ue304" },
  { "weather-day_haze", "\\ue3ae" },
  { "weather-day_light_wind", "\\ue3bc" },
  { "weather-day_lightning", "\\ue305" },
  { "weather-day_rain", "\\ue308" },
  { "weather-day_rain_mix", "\\ue306" },
  { "weather-day_rain_wind", "\\ue307" },
  { "weather-day_showers", "\\ue309" },
  { "weather-day_sleet", "\\ue3aa" },
  { "weather-day_sleet_storm", "\\ue362" },
  { "weather-day_snow", "\\ue30a" },
  { "weather-day_snow_thunderstorm", "\\ue365" },
  { "weather-day_snow_wind", "\\ue35f" },
  { "weather-day_sprinkle", "\\ue30b" },
  { "weather-day_storm_showers", "\\ue30e" },
  { "weather-day_sunny", "\\ue30d" },
  { "weather-day_sunny_overcast", "\\ue30c" },
  { "weather-day_thunderstorm", "\\ue30f" },
  { "weather-day_windy", "\\ue37d" },
  { "weather-degrees", "\\ue33e" },
  { "weather-direction_down", "\\ue340" },
  { "weather-direction_down_left", "\\ue33f" },
  { "weather-direction_down_right", "\\ue380" },
  { "weather-direction_left", "\\ue344" },
  { "weather-direction_right", "\\ue349" },
  { "weather-direction_up", "\\ue353" },
  { "weather-direction_up_left", "\\ue37f" },
  { "weather-direction_up_right", "\\ue352" },
  { "weather-dust", "\\ue35d" },
  { "weather-earthquake", "\\ue3be" },
  { "weather-fahrenheit", "\\ue341" },
  { "weather-fire", "\\ue3bf" },
  { "weather-flood", "\\ue375" },
  { "weather-fog", "\\ue313" },
  { "weather-gale_warning", "\\ue3c5" },
  { "weather-hail", "\\ue314" },
  { "weather-horizon", "\\ue343" },
  { "weather-horizon_alt", "\\ue342" },
  { "weather-hot", "\\ue36b" },
  { "weather-humidity", "\\ue373" },
  { "weather-hurricane", "\\ue36c" },
  { "weather-hurricane_warning", "\\ue3c7" },
  { "weather-lightning", "\\ue315" },
  { "weather-lunar_eclipse", "\\ue369" },
  { "weather-meteor", "\\ue36a" },
  { "weather-moon_alt_first_quarter", "\\ue3ce" },
  { "weather-moon_alt_full", "\\ue3d5" },
  { "weather-moon_alt_new", "\\ue3e3" },
  { "weather-moon_alt_third_quarter", "\\ue3dc" },
  { "weather-moon_alt_waning_crescent_1", "\\ue3dd" },
  { "weather-moon_alt_waning_crescent_2", "\\ue3de" },
  { "weather-moon_alt_waning_crescent_3", "\\ue3df" },
  { "weather-moon_alt_waning_crescent_4", "\\ue3e0" },
  { "weather-moon_alt_waning_crescent_5", "\\ue3e1" },
  { "weather-moon_alt_waning_crescent_6", "\\ue3e2" },
  { "weather-moon_alt_waning_gibbous_1", "\\ue3d6" },
  { "weather-moon_alt_waning_gibbous_2", "\\ue3d7" },
  { "weather-moon_alt_waning_gibbous_3", "\\ue3d8" },
  { "weather-moon_alt_waning_gibbous_4", "\\ue3d9" },
  { "weather-moon_alt_waning_gibbous_5", "\\ue3da" },
  { "weather-moon_alt_waning_gibbous_6", "\\ue3db" },
  { "weather-moon_alt_waxing_crescent_1", "\\ue3c8" },
  { "weather-moon_alt_waxing_crescent_2", "\\ue3c9" },
  { "weather-moon_alt_waxing_crescent_3", "\\ue3ca" },
  { "weather-moon_alt_waxing_crescent_4", "\\ue3cb" },
  { "weather-moon_alt_waxing_crescent_5", "\\ue3cc" },
  { "weather-moon_alt_waxing_crescent_6", "\\ue3cd" },
  { "weather-moon_alt_waxing_gibbous_1", "\\ue3cf" },
  { "weather-moon_alt_waxing_gibbous_2", "\\ue3d0" },
  { "weather-moon_alt_waxing_gibbous_3", "\\ue3d1" },
  { "weather-moon_alt_waxing_gibbous_4", "\\ue3d2" },
  { "weather-moon_alt_waxing_gibbous_5", "\\ue3d3" },
  { "weather-moon_alt_waxing_gibbous_6", "\\ue3d4" },
  { "weather-moon_first_quarter", "\\ue394" },
  { "weather-moon_full", "\\ue39b" },
  { "weather-moon_new", "\\ue38d" },
  { "weather-moon_third_quarter", "\\ue3a2" },
  { "weather-moon_waning_crescent_1", "\\ue3a3" },
  { "weather-moon_waning_crescent_2", "\\ue3a4" },
  { "weather-moon_waning_crescent_3", "\\ue3a5" },
  { "weather-moon_waning_crescent_4", "\\ue3a6" },
  { "weather-moon_waning_crescent_5", "\\ue3a7" },
  { "weather-moon_waning_crescent_6", "\\ue3a8" },
  { "weather-moon_waning_gibbous_1", "\\ue39c" },
  { "weather-moon_waning_gibbous_2", "\\ue39d" },
  { "weather-moon_waning_gibbous_3", "\\ue39e" },
  { "weather-moon_waning_gibbous_4", "\\ue39f" },
  { "weather-moon_waning_gibbous_5", "\\ue3a0" },
  { "weather-moon_waning_gibbous_6", "\\ue3a1" },
  { "weather-moon_waxing_crescent_1", "\\ue38e" },
  { "weather-moon_waxing_crescent_2", "\\ue38f" },
  { "weather-moon_waxing_crescent_3", "\\ue390" },
  { "weather-moon_waxing_crescent_4", "\\ue391" },
  { "weather-moon_waxing_crescent_5", "\\ue392" },
  { "weather-moon_waxing_crescent_6", "\\ue393" },
  { "weather-moon_waxing_gibbous_1", "\\ue395" },
  { "weather-moon_waxing_gibbous_2", "\\ue396" },
  { "weather-moon_waxing_gibbous_3", "\\ue397" },
  { "weather-moon_waxing_gibbous_4", "\\ue398" },
  { "weather-moon_waxing_gibbous_5", "\\ue399" },
  { "weather-moon_waxing_gibbous_6", "\\ue39a" },
  { "weather-moonrise", "\\ue3c1" },
  { "weather-moonset", "\\ue3c2" },
  { "weather-na", "\\ue374" },
  { "weather-night_alt_cloudy", "\\ue37e" },
  { "weather-night_alt_cloudy_gusts", "\\ue31f" },
  { "weather-night_alt_cloudy_high", "\\ue377" },
  { "weather-night_alt_cloudy_windy", "\\ue320" },
  { "weather-night_alt_hail", "\\ue321" },
  { "weather-night_alt_lightning", "\\ue322" },
  { "weather-night_alt_partly_cloudy", "\\ue379" },
  { "weather-night_alt_rain", "\\ue325" },
  { "weather-night_alt_rain_mix", "\\ue326" },
  { "weather-night_alt_rain_wind", "\\ue324" },
  { "weather-night_alt_sleet", "\\ue3ac" },
  { "weather-night_alt_sleet_storm", "\\ue364" },
  { "weather-night_alt_snow", "\\ue327" },
  { "weather-night_alt_snow_thunderstorm", "\\ue367" },
  { "weather-night_alt_snow_wind", "\\ue361" },
  { "weather-night_alt_sprinkle", "\\ue328" },
  { "weather-night_alt_storm_showers", "\\ue329" },
  { "weather-night_alt_thunderstorm", "\\ue32a" },
  { "weather-night_clear", "\\ue32b" },
  { "weather-night_cloudy", "\\ue32e" },
  { "weather-night_cloudy_gusts", "\\ue32c" },
  { "weather-night_cloudy_high", "\\ue378" },
  { "weather-night_cloudy_windy", "\\ue32d" },
  { "weather-night_fog", "\\ue346" },
  { "weather-night_hail", "\\ue32f" },
  { "weather-night_lightning", "\\ue330" },
  { "weather-night_partly_cloudy", "\\ue37b" },
  { "weather-night_rain", "\\ue333" },
  { "weather-night_rain_mix", "\\ue331" },
  { "weather-night_rain_wind", "\\ue332" },
  { "weather-night_showers", "\\ue334" },
  { "weather-night_sleet", "\\ue3ab" },
  { "weather-night_sleet_storm", "\\ue363" },
  { "weather-night_snow", "\\ue335" },
  { "weather-night_snow_thunderstorm", "\\ue366" },
  { "weather-night_snow_wind", "\\ue360" },
  { "weather-night_sprinkle", "\\ue336" },
  { "weather-night_storm_showers", "\\ue337" },
  { "weather-night_thunderstorm", "\\ue338" },
  { "weather-rain", "\\ue318" },
  { "weather-rain_mix", "\\ue316" },
  { "weather-rain_wind", "\\ue317" },
  { "weather-raindrop", "\\ue371" },
  { "weather-raindrops", "\\ue34a" },
  { "weather-refresh", "\\ue348" },
  { "weather-refresh_alt", "\\ue347" },
  { "weather-sandstorm", "\\ue37a" },
  { "weather-showers", "\\ue319" },
  { "weather-sleet", "\\ue3ad" },
  { "weather-small_craft_advisory", "\\ue3c4" },
  { "weather-smog", "\\ue36d" },
  { "weather-smoke", "\\ue35c" },
  { "weather-snow", "\\ue31a" },
  { "weather-snow_wind", "\\ue35e" },
  { "weather-snowflake_cold", "\\ue36f" },
  { "weather-solar_eclipse", "\\ue368" },
  { "weather-sprinkle", "\\ue31b" },
  { "weather-stars", "\\ue370" },
  { "weather-storm_showers", "\\ue31c" },
  { "weather-storm_warning", "\\ue3c6" },
  { "weather-strong_wind", "\\ue34b" },
  { "weather-sunrise", "\\ue34c" },
  { "weather-sunset", "\\ue34d" },
  { "weather-thermometer", "\\ue350" },
  { "weather-thermometer_exterior", "\\ue34e" },
  { "weather-thermometer_internal", "\\ue34f" },
  { "weather-thunderstorm", "\\ue31d" },
  { "weather-time_1", "\\ue382" },
  { "weather-time_10", "\\ue38b" },
  { "weather-time_11", "\\ue38c" },
  { "weather-time_12", "\\ue381" },
  { "weather-time_2", "\\ue383" },
  { "weather-time_3", "\\ue384" },
  { "weather-time_4", "\\ue385" },
  { "weather-time_5", "\\ue386" },
  { "weather-time_6", "\\ue387" },
  { "weather-time_7", "\\ue388" },
  { "weather-time_8", "\\ue389" },
  { "weather-time_9", "\\ue38a" },
  { "weather-tornado", "\\ue351" },
  { "weather-train", "\\ue3c3" },
  { "weather-tsunami", "\\ue3bd" },
  { "weather-umbrella", "\\ue37c" },
  { "weather-volcano", "\\ue3c0" },
  { "weather-wind_beaufort_0", "\\ue3af" },
  { "weather-wind_beaufort_1", "\\ue3b0" },
  { "weather-wind_beaufort_10", "\\ue3b9" },
  { "weather-wind_beaufort_11", "\\ue3ba" },
  { "weather-wind_beaufort_12", "\\ue3bb" },
  { "weather-wind_beaufort_2", "\\ue3b1" },
  { "weather-wind_beaufort_3", "\\ue3b2" },
  { "weather-wind_beaufort_4", "\\ue3b3" },
  { "weather-wind_beaufort_5", "\\ue3b4" },
  { "weather-wind_beaufort_6", "\\ue3b5" },
  { "weather-wind_beaufort_7", "\\ue3b6" },
  { "weather-wind_beaufort_8", "\\ue3b7" },
  { "weather-wind_beaufort_9", "\\ue3b8" },
  { "weather-wind_direction", "\\ue3a9" },
  { "weather-wind_east", "\\ue35b" },
  { "weather-wind_north", "\\ue35a" },
  { "weather-wind_north_east", "\\ue359" },
  { "weather-wind_north_west", "\\ue358" },
  { "weather-wind_south", "\\ue357" },
  { "weather-wind_south_east", "\\ue356" },
  { "weather-wind_south_west", "\\ue355" },
  { "weather-wind_west", "\\ue354" },
  { "weather-windy", "\\ue31e" }
};

char *print_utf8(char *code);
#define n_of_fonts (sizeof(fonts)/sizeof(fonts[0]))

static int sorted = 0;

static int compfont(const void *f1, const void *f2)
{
  const struct nerd_font *nf1 = f1 ;
  const struct nerd_font *nf2 = f2 ;
  return strcmp(nf1->name, nf2->name);
}

char* find_code(char *name)
{
  struct nerd_font key, *res;

  if(!sorted) {
    qsort(fonts, n_of_fonts, sizeof(fonts[0]), compfont);
  }
  key.name = name ;
  res = bsearch(&key, fonts, n_of_fonts, sizeof(fonts[0]), compfont);
  if(res == NULL)
    return NULL;
  return res->code;
}

int
find_longest_name_length()
{
  int n = 0;
  for(int i = 0; i < n_of_fonts; i++) {
    int l = strlen(fonts[i].name);
    if(strlen(fonts[i].name) > n)
      n = l ;
  }
  return n;
}

void
list_fonts(char *search)
{
  int n = find_longest_name_length();
  for(int i = 0; i < n_of_fonts; i++) {
    struct nerd_font *f = &fonts[i];
    if(!search || strstr(f->name, search))
      printf("%-*s %6s %s\n", n, f->name, f->code, print_utf8(f->code));
  }
  printf("Seaching for: %s\n", search);
}

#ifdef MAIN
char *print_utf8(const char *s);
int
main(int argc, char **argv)
{
  if(argc < 2) {
    printf("Usage: %s fontname...\n", argv[0]);
    exit(EXIT_SUCCESS);
  }

  for(int i = 1; i < argc; i++) {
      char *name = argv[i];
      char *code = find_code(name);
      if(code != NULL)
        printf("%s: %s\n", name, print_utf8(code));
      else
        printf("%s: Unknown\n", name);
  }
}
#endif
